@@ -761,6 +761,46 @@
         <source>-- End of List --</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>CounterPoint Traffic Reconciliation v2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timed(Wait)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Fill</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timed(Start), </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timed(MakeNext), </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Traffic, </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Music, </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scheduler, </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Inline Traffic, </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -1215,6 +1255,14 @@ farge</translation>
         <source>End</source>
         <translation type="unfinished">Slutten</translation>
     </message>
+    <message>
+        <source>Open Audio File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDCddbLookup</name>
@@ -1222,17 +1270,9 @@ farge</translation>
         <source>CDDB Query</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Multiple Matches Found!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>OK</source>
-        <translation type="unfinished">OK</translation>
-    </message>
-    <message>
-        <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">OK</translation>
     </message>
 </context>
 <context>
@@ -1411,6 +1451,33 @@ Cart</source>
         <translation>Su</translation>
     </message>
 </context>
+<context>
+    <name>RDDiscLookup</name>
+    <message>
+        <source>Multiple Matches Found!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to read CD.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation type="obsolete">Ukjent</translation>
+    </message>
+</context>
 <context>
     <name>RDEditAudio</name>
     <message>
@@ -2137,6 +2204,14 @@ Sjekk eksportoppsettet ditt og prøv att.</translation>
         <source>Abort</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Select Audio File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save Audio File</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDIntegerDialog</name>
@@ -2355,6 +2430,49 @@ Sjekk eksportoppsettet ditt og prøv att.</translation>
         <translation type="obsolete">Sporleggjar</translation>
     </message>
 </context>
+<context>
+    <name>RDMbLookup</name>
+    <message>
+        <source>Connection Exception</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Result</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LastHTTPCode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LastErrorMessage</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timeout Exception</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Authentication Exception</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Fetch Exception</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Request Exception</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lookup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resource Not Found</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDPanelButton</name>
     <message>
