@@ -2,7 +2,7 @@
 //
 // System-Wide Values for Rivendell
 //
-//   (C) Copyright 2002-2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,6 +21,11 @@
 #ifndef RD_H
 #define RD_H
 
+/*
+ * Copyright Notice
+ */
+#define RD_COPYRIGHT_NOTICE "© 2002-2020 Fred Gleason"
+
 /*
  * Default Configuration File
  */
@@ -35,10 +40,7 @@
 /*
  * PID File Locations
  */
-#define RD_PID_DIR "/var/run/rivendell"
-#define RD_CAED_PID "/var/run/rivendell/caed.pid"
-#define RD_RIPCD_PID "/var/run/rivendell/ripcd.pid"
-#define RD_RDCATCHD_PID "/var/run/rivendell/rdcatchd.pid"
+#define RD_PID_DIR "/var/run"
 
 /*
  * Where audio gets stored
@@ -65,17 +67,8 @@
 #define DEFAULT_MYSQL_DRIVER "QMYSQL3"
 #define DEFAULT_MYSQL_HEARTBEAT_INTERVAL 360
 #define DEFAULT_MYSQL_ENGINE "MyISAM"
-#define DEFAULT_MYSQL_CHARSET "latin1"
-#define DEFAULT_MYSQL_COLLATION "latin1_swedish_ci"
-#define MYSQL_BUILTIN_DATABASE "mysql"
-#define POSTGRESQL_BUILTIN_DATABASE "template1"
-
-/*
- * Default Logging Settings
- */
-#define DEFAULT_LOG_FACILITY "syslog"
-#define DEFAULT_LOG_CORE_DUMP_DIRECTORY "/"
-#define DEFAULT_LOG_PATTERN "%n-%Y%M%d.log"
+#define DEFAULT_MYSQL_CHARSET "utf8mb4"
+#define DEFAULT_MYSQL_COLLATION "utf8mb4_general_ci"
 
 /*
  * ALSA Settings
@@ -128,17 +121,17 @@
 /*
  * Max number of possible audio adapters
  */
-#define RD_MAX_CARDS 8
+#define RD_MAX_CARDS 24
 
 /*
  * Max number of possible audio streams/card/type
  */
-#define RD_MAX_STREAMS 16
+#define RD_MAX_STREAMS 48
 
 /*
  * Max number of possible audio ports/card/type
  */
-#define RD_MAX_PORTS 8
+#define RD_MAX_PORTS 24
 
 /*
  * Max number of possible TTYs
@@ -222,8 +215,12 @@
 /*
  * Default System Identities
  */
-#define RD_DEFAULT_AUDIO_OWNER "user"
-#define RD_DEFAULT_AUDIO_GROUP "users"
+#define RD_DEFAULT_AUDIO_OWNER "rivendell"
+#define RD_DEFAULT_AUDIO_GROUP "rivendell"
+#define RD_DEFAULT_PYPAD_OWNER "pypad"
+#define RD_DEFAULT_PYPAD_GROUP "pypad"
+#define RD_DEFAULT_RN_RML_OWNER "rivendell"
+#define RD_DEFAULT_RN_RML_GROUP "rivendell"
 #define RD_DEFAULT_LABEL "Default Configuration"
 
 /*
@@ -361,7 +358,6 @@
 #define CAE_MAX_ARGS 10
 #define CAE_MAX_LENGTH 256
 #define CAE_POLL_INTERVAL 50
-#define CAE_MAX_CONNECTIONS 128
 
 /*
  * Default Sample Rate
@@ -420,9 +416,9 @@
 /*
  * Cue Editor Colors
  */
-#define RD_CUEEDITOR_KNOB_COLOR blue
-#define RD_CUEEDITOR_PLAY_MARKER black
-#define RD_CUEEDITOR_START_MARKER red
+#define RD_CUEEDITOR_KNOB_COLOR Qt::blue
+#define RD_CUEEDITOR_PLAY_MARKER Qt::black
+#define RD_CUEEDITOR_START_MARKER Qt::red
 #define RD_CUEEDITOR_BUTTON_FLASH_PERIOD 200
 #define RD_CUEEDITOR_AUDITION_PREROLL 5000
 
@@ -435,7 +431,6 @@
  * Default Text Editors
  */
 #define RD_LINUX_EDITOR "xterm -e vi"
-#define RD_WIN32_EDITOR "notepad"
 
 /*
  * System-wide Maintenance Interval (mS)
@@ -567,4 +562,47 @@
  */
 #define RD_LOGFILTER_LIMIT_QUAN 14
 
+/*
+ * Log Locking Timeout
+ */
+#define RD_LOG_LOCK_TIMEOUT 30000
+
+/*
+ * Default multicast address for sending state updates
+ */
+#define RD_NOTIFICATION_ADDRESS "239.192.255.72"
+
+/*
+ * UDP port for sending state updates
+ */
+#define RD_NOTIFICATION_PORT 20539
+
+/*
+ * RDVAirPlay Values
+ */
+#define RD_RDVAIRPLAY_LOG_BASE 100
+#define RD_RDVAIRPLAY_LOG_QUAN 20
+
+/*
+ * GUI Style
+ * (must be one of the values returned by QStyleFactory::keys())
+ */
+#define RD_GUI_STYLE "Plastique"
+
+/*
+ * Status / Note Bubble Background Color
+ */
+#define RD_STATUS_BACKGROUND_COLOR "#AAFFFF"
+
+/*
+ * PAD Update Connection Points
+ */
+#define RD_PAD_CLIENT_TCP_PORT 34289
+#define RD_PAD_SOURCE_UNIX_ADDRESS "m4w8n8fsfddf-473fdueusurt-8954"
+
+/*
+ * Default 'ServiceTimeout=' value in rd.conf(5)
+ */
+#define RD_DEFAULT_SERVICE_TIMEOUT 30
+
 #endif  // RD_H
