@@ -5,7 +5,7 @@
 // This class creates a basic dialog requesting from the user a name and
 // corresponding service that is later used to create a new log.
 //
-//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,28 +24,20 @@
 #ifndef ADD_LOG_H
 #define ADD_LOG_H
 
-#include <qdialog.h>
 #include <qcombobox.h>
 #include <qlineedit.h>
 #include <qpushbutton.h>
 
-#include <rdstation.h>
+#include <rddialog.h>
 #include <rdlog.h>
-#include <rduser.h>
+#include <rdlogfilter.h>
 
-
-class RDAddLog : public QDialog
+class RDAddLog : public RDDialog
 {
   Q_OBJECT
  public:
-  /**
-   * Constructor for the RDAddLog object.
-   *
-   * NOTE: the presence of the optional rduser parameter is used to flag if
-   * user security should be used instead of host based security.
-   */
-  RDAddLog(QString *logname,QString *svcname,RDStation *station,
-	   QString caption,QWidget *parent=0,RDUser *rduser=0);
+  RDAddLog(QString *logname,QString *svcname,RDLogFilter::FilterMode mode,
+	   const QString &caption,QWidget *parent=0);
   ~RDAddLog();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -65,9 +57,8 @@ class RDAddLog : public QDialog
   QPushButton *add_cancel_button;
   QString *log_name;
   QString *log_svc;
-  RDStation *log_station;
 };
 
 
-#endif
+#endif  // RDADD_LOG_H
 
