@@ -2,9 +2,7 @@
 //
 // Test for the existence of a Rivendell Audio Cut.
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdaudio_exists.h,v 1.3 2007/02/14 21:48:41 fredg Exp $
+//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -26,4 +24,4 @@
 bool RDAudioExists(QString cutname);
 
 
-#endif 
+#endif  // RDAUDIO_EXISTS_H
