@@ -2,7 +2,7 @@
 //
 // Get information about a cut in the audio store.
 //
-//   (C) Copyright 2011,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2011,2016-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,10 +30,11 @@
 
 #include <qstringlist.h>
 
-#include <rd.h>
-#include <rdxport_interface.h>
-#include <rdformpost.h>
-#include <rdaudioinfo.h>
+#include "rd.h"
+#include "rdapplication.h"
+#include "rdxport_interface.h"
+#include "rdformpost.h"
+#include "rdaudioinfo.h"
 
 size_t RDAudioInfoCallback(void *ptr,size_t size,size_t nmemb,void *userdata)
 {
@@ -45,11 +46,9 @@ size_t RDAudioInfoCallback(void *ptr,size_t size,size_t nmemb,void *userdata)
 }
 
 
-RDAudioInfo::RDAudioInfo(RDStation *station,RDConfig *config,QObject *parent)
+RDAudioInfo::RDAudioInfo(QObject *parent)
   : QObject(parent)
 {
-  conv_station=station;
-  conv_config=config;
   conv_cart_number=0;
   conv_cut_number=0;
   conv_format=RDWaveFile::Pcm16;
@@ -116,31 +115,44 @@ RDAudioInfo::ErrorCode RDAudioInfo::runInfo(const QString &username,
   CURL *curl=NULL;
   char url[1024];
   CURLcode curl_err;
+  struct curl_httppost *first=NULL;
+  struct curl_httppost *last=NULL;
 
   //
   // Generate POST Data
   //
-  QString post=QString().sprintf("COMMAND=%d&LOGIN_NAME=%s&PASSWORD=%s&CART_NUMBER=%u&CUT_NUMBER=%u",
-				 RDXPORT_COMMAND_AUDIOINFO,
-				 (const char *)RDFormPost::urlEncode(username),
-				 (const char *)RDFormPost::urlEncode(password),
-				 conv_cart_number,
-				 conv_cut_number);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"COMMAND",
+	       CURLFORM_COPYCONTENTS,
+	       (const char *)QString().sprintf("%u",RDXPORT_COMMAND_AUDIOINFO),
+	       CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"LOGIN_NAME",
+	       CURLFORM_COPYCONTENTS,(const char *)username.utf8(),CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"PASSWORD",
+	       CURLFORM_COPYCONTENTS,(const char *)password.utf8(),CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"CART_NUMBER",
+	       CURLFORM_COPYCONTENTS,
+	       (const char *)QString().sprintf("%u",conv_cart_number),
+	       CURLFORM_END);
+  curl_formadd(&first,&last,CURLFORM_PTRNAME,"CUT_NUMBER",
+	       CURLFORM_COPYCONTENTS,
+	       (const char *)QString().sprintf("%u",conv_cut_number),
+	       CURLFORM_END);
   if((curl=curl_easy_init())==NULL) {
+    curl_formfree(first);
     return RDAudioInfo::ErrorInternal;
   }
-
   //
   // Write out URL as a C string before passing to curl_easy_setopt(), 
   // otherwise some versions of LibCurl will throw a 'bad/illegal format' 
   // error.
   //
-  strncpy(url,conv_station->webServiceUrl(conv_config),1024);
+  strncpy(url,rda->station()->webServiceUrl(rda->config()),1024);
   curl_easy_setopt(curl,CURLOPT_URL,url);
   curl_easy_setopt(curl,CURLOPT_WRITEFUNCTION,RDAudioInfoCallback);
   curl_easy_setopt(curl,CURLOPT_WRITEDATA,&conv_xml);
-  curl_easy_setopt(curl,CURLOPT_POST,1);
-  curl_easy_setopt(curl,CURLOPT_POSTFIELDS,(const char *)post);
+  curl_easy_setopt(curl,CURLOPT_HTTPPOST,first);
+  curl_easy_setopt(curl,CURLOPT_USERAGENT,
+		   (const char *)rda->config()->userAgent());
   curl_easy_setopt(curl,CURLOPT_TIMEOUT,RD_CURL_TIMEOUT);
 
   switch(curl_err=curl_easy_perform(curl)) {
@@ -157,6 +169,7 @@ RDAudioInfo::ErrorCode RDAudioInfo::runInfo(const QString &username,
   case CURLE_OPERATION_TIMEDOUT:
   case CURLE_HTTP_POST_ERROR:
     curl_easy_cleanup(curl);
+    curl_formfree(first);
     fprintf(stderr,"curl error: %d\n",curl_err);
     return RDAudioInfo::ErrorInternal;
 
@@ -165,14 +178,17 @@ RDAudioInfo::ErrorCode RDAudioInfo::runInfo(const QString &username,
   case CURLE_COULDNT_CONNECT:
   case 9:   // CURLE_REMOTE_ACCESS_DENIED
     curl_easy_cleanup(curl);
+    curl_formfree(first);
     return RDAudioInfo::ErrorUrlInvalid;
 
   default:
     curl_easy_cleanup(curl);
+    curl_formfree(first);
     return RDAudioInfo::ErrorService;
   }
   curl_easy_getinfo(curl,CURLINFO_RESPONSE_CODE,&response_code);
   curl_easy_cleanup(curl);
+  curl_formfree(first);
 
   switch(response_code) {
   case 200:
@@ -234,12 +250,12 @@ int RDAudioInfo::ParseInt(const QString &tag,const QString &xml)
   // FIXME: This is totally ad-hoc, but should work until we settle on
   //        a proper XML parser.
   //
-  QStringList list=list.split("\n",xml);
-  for(unsigned i=0;i<list.size();i++) {
+  QStringList list=xml.split("\n");
+  for(int i=0;i<list.size();i++) {
     if(list[i].contains(tag)) {
-      QStringList list2=list.split("<",list[i]);
+      QStringList list2=list[i].split("<");
       if(list2.size()>=2) {
-	list2=list2.split(">",list2[1]);
+	list2=list2[1].split(">");
 	if(list2.size()>=2) {
 	  return list2[1].toInt();
 	}
