@@ -2,7 +2,7 @@
 //
 // A container class for a Rivendell Base Configuration
 //
-//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,23 +18,25 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#ifndef WIN32
-#include <sys/types.h>
-#include <pwd.h>
 #include <grp.h>
+#include <pwd.h>
+#include <syslog.h>
 #include <unistd.h>
 #include <arpa/inet.h>
 #include <net/if.h>
 #include <sys/ioctl.h>
-#endif  // WIN32
+#include <sys/stat.h>
+#include <sys/types.h>
 
+#include <qdatetime.h>
 #include <qmessagebox.h>
+#include <qobject.h>
 #include <qregexp.h>
 #include <qsettings.h>
 #include <qstringlist.h>
 
-#include <rdprofile.h>
-#include <rdconfig.h>
+#include "rdconfig.h"
+#include "rdprofile.h"
 
 RDConfig *RDConfiguration(void) 
 {
@@ -84,9 +86,15 @@ void RDConfig::setModuleName(const QString &modname)
 }
 
 
-QString RDConfig::userAgent() const
+QString RDConfig::userAgent(const QString &modname) const
 {
-  return RDConfig::userAgent(conf_module_name);
+  if(!conf_http_user_agent.isEmpty()) {
+    return conf_http_user_agent;
+  }
+  if(modname.isEmpty()) {
+    return QString("Mozilla/5.0")+" rivendell/"+VERSION;
+  }
+  return QString("Mozilla/5.0 rivendell/")+VERSION+" ("+modname+")";
 }
 
 
@@ -145,6 +153,30 @@ QString RDConfig::audioStoreXportHostname() const
 }
 
 
+QString RDConfig::fontFamily() const
+{
+  return conf_font_family;
+}
+
+
+int RDConfig::fontButtonSize() const
+{
+  return conf_font_button_size;
+}
+
+
+int RDConfig::fontLabelSize() const
+{
+  return conf_font_label_size;
+}
+
+
+int RDConfig::fontDefaultSize() const
+{
+  return conf_font_default_size;
+}
+
+
 QString RDConfig::mysqlHostname() const
 {
   return conf_mysql_hostname;
@@ -186,97 +218,18 @@ QString RDConfig::mysqlEngine() const
 }
 
 
-QString RDConfig::mysqlCharset() const
-{
-  return conf_mysql_charset;
-}
-
-
-QString RDConfig::mysqlCollation() const
-{
-  return conf_mysql_collation;
-}
-
-
 QString RDConfig::createTablePostfix() const
 {
   return conf_create_table_postfix;
 }
 
 
-RDConfig::LogFacility RDConfig::logFacility() const
-{
-  return conf_log_facility;
-}
-
-
-QString RDConfig::logDirectory() const
-{
-  return conf_log_directory;
-}
-
-
-QString RDConfig::logCoreDumpDirectory() const
-{
-  return conf_log_core_dump_directory;
-}
-
-
-QString RDConfig::logPattern() const
-{
-  return conf_log_pattern;
-}
-
-
 bool RDConfig::logXloadDebugData() const
 {
   return conf_log_xload_debug_data;
 }
 
 
-void RDConfig::log(const QString &module,LogPriority prio,const QString &msg)
-{
-#ifndef WIN32
-  QDateTime dt;
-  QString filename;
-  FILE *f=NULL;
-
-  switch(conf_log_facility) {
-    case RDConfig::LogSyslog:
-      syslog((int)prio,"%s",(const char *)msg);
-      break;
-
-    case RDConfig::LogFile:
-      if(conf_log_directory.isEmpty()||conf_log_pattern.isEmpty()) {
-	return;
-      }
-      filename=QString().sprintf("%s/%s",(const char *)conf_log_directory,
-				 (const char *)conf_log_pattern);
-      dt=QDateTime(QDate::currentDate(),QTime::currentTime());
-      filename.replace("%n",module);
-      filename.replace("%d",dt.date().toString("dd"));
-      filename.replace("%M",dt.date().toString("MM"));
-      filename.replace("%Y",dt.date().toString("yyyy"));
-      filename.replace("%h",dt.time().toString("hh"));
-      filename.replace("%m",dt.time().toString("mm"));
-      filename.replace("%s",dt.time().toString("ss"));
-      if((f=fopen(filename,"a"))!=NULL) {
-	fprintf(f,"%s: %s\n",(const char *)dt.
-		toString("dd/MM/yyyy - hh:mm:ss.zzz "),
-		(const char *)msg);
-	fclose(f);
-      }
-      chmod(filename,S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH);
-      chown(filename,uid(),gid());
-      break;
-
-    case RDConfig::LogNone:
-      break;
-  }
-#endif  // WIN32
-}
-
-
 bool RDConfig::provisioningCreateHost() const
 {
   return conf_provisioning_create_host;
@@ -301,7 +254,7 @@ QString RDConfig::provisioningHostShortName(const QString &hostname) const
 
   exp.search(hostname);
   QStringList texts=exp.capturedTexts();
-  if(texts.size()<conf_provisioning_host_short_name_group) {
+  if((unsigned)texts.size()<conf_provisioning_host_short_name_group) {
     return QString();
   }
   return texts[conf_provisioning_host_short_name_group];
@@ -326,7 +279,7 @@ QString RDConfig::provisioningServiceName(const QString &hostname) const
 
   exp.search(hostname);
   QStringList texts=exp.capturedTexts();
-  if(texts.size()<conf_provisioning_service_name_group) {
+  if((unsigned)texts.size()<conf_provisioning_service_name_group) {
     return QString();
   }
   return texts[conf_provisioning_service_name_group];
@@ -375,21 +328,33 @@ QString RDConfig::audioGroup() const
 }
 
 
-QString RDConfig::ripcdLogname() const
+QString RDConfig::pypadOwner() const
 {
-  return conf_ripcd_logname;
+  return conf_pypad_owner;
 }
 
 
-QString RDConfig::airplayLogname() const
+QString RDConfig::pypadGroup() const
 {
-  return conf_airplay_logname;
+  return conf_pypad_group;
 }
 
 
-QString RDConfig::catchdLogname() const
+QString RDConfig::rnRmlOwner() const
 {
-  return conf_catchd_logname;
+  return conf_rn_rml_owner;
+}
+
+
+QString RDConfig::rnRmlGroup() const
+{
+  return conf_rn_rml_group;
+}
+
+
+int RDConfig::syslogFacility() const
+{
+  return conf_syslog_facility;
 }
 
 
@@ -405,12 +370,6 @@ QString RDConfig::jackPort(int num,int endpt) const
 }
 
 
-bool RDConfig::useStreamMeters() const
-{
-  return conf_use_stream_meters;
-}
-
-
 bool RDConfig::disableMaintChecks() const
 {
   return conf_disable_maint_checks;
@@ -423,13 +382,6 @@ bool RDConfig::lockRdairplayMemory() const
 }
 
 
-unsigned RDConfig::channels() const
-{
-  return conf_channels;
-}
-
-
-#ifndef WIN32
 uid_t RDConfig::uid() const
 {
   return conf_uid;
@@ -440,12 +392,29 @@ gid_t RDConfig::gid() const
 {
   return conf_gid;
 }
-#endif
 
 
-QString RDConfig::caeLogfile() const
+uid_t RDConfig::pypadUid() const
 {
-  return conf_cae_logfile;
+  return conf_pypad_uid;
+}
+
+
+gid_t RDConfig::pypadGid() const
+{
+  return conf_pypad_gid;
+}
+
+
+uid_t RDConfig::rnRmlUid() const
+{
+  return conf_rn_rml_uid;
+}
+
+
+gid_t RDConfig::rnRmlGid() const
+{
+  return conf_rn_rml_gid;
 }
 
 
@@ -473,12 +442,10 @@ int RDConfig::transcodingDelay() const
 }
 
 
-#ifndef WIN32
-mode_t RDConfig::tuningExportedFileMode() const
+int RDConfig::serviceTimeout() const
 {
-  return conf_tuning_exported_file_mode;
+  return conf_service_timeout;
 }
-#endif  // WIN32
 
 
 // Don't use this method in application code, use RDTempDirectory()
@@ -520,26 +487,22 @@ QString RDConfig::destination(unsigned n)
 }
 
 
-void RDConfig::load()
+bool RDConfig::load()
 {
   char sname[256];
   QString client;
   QString facility;
   QString iface;
-#ifndef WIN32
   struct passwd *user;
   struct group *groups;
-#endif 
 
   RDProfile *profile=new RDProfile();
-  profile->setSource(conf_filename);
-#ifdef WIN32
-  strcpy(sname,"windows");
-#else
+  if(!profile->setSource(conf_filename)) {
+    return false;
+  }
   gethostname(sname,255);
-  QStringList list=list.split(".",sname);  // Strip domain name parts
+  QStringList list=QString(sname).split(".");  // Strip domain name parts
   strncpy(sname,list[0],256);
-#endif
   conf_station_name=
     profile->stringValue("Identity","StationName",sname);
   conf_password=profile->stringValue("Identity","Password","");
@@ -547,7 +510,16 @@ void RDConfig::load()
     profile->stringValue("Identity","AudioOwner",RD_DEFAULT_AUDIO_OWNER);
   conf_audio_group=
     profile->stringValue("Identity","AudioGroup",RD_DEFAULT_AUDIO_GROUP);
+  conf_pypad_owner=
+    profile->stringValue("Identity","PypadOwner",RD_DEFAULT_PYPAD_OWNER);
+  conf_pypad_group=
+    profile->stringValue("Identity","PypadGroup",RD_DEFAULT_PYPAD_GROUP);
+  conf_rn_rml_owner=
+    profile->stringValue("Identity","RnRmlOwner",RD_DEFAULT_RN_RML_OWNER);
+  conf_rn_rml_group=
+    profile->stringValue("Identity","RnRmlGroup",RD_DEFAULT_RN_RML_GROUP);
   conf_label=profile->stringValue("Identity","Label",RD_DEFAULT_LABEL);
+  conf_http_user_agent=profile->stringValue("Identity","HttpUserAgent");
 
   conf_audio_store_mount_source=
     profile->stringValue("AudioStore","MountSource");
@@ -561,6 +533,11 @@ void RDConfig::load()
   conf_audio_store_xport_hostname=
     profile->stringValue("AudioStore","XportHostname","localhost");
 
+  conf_font_family=profile->stringValue("Fonts","Family");
+  conf_font_button_size=profile->intValue("Fonts","ButtonSize",-1);
+  conf_font_label_size=profile->intValue("Fonts","LabelSize",-1);
+  conf_font_default_size=profile->intValue("Fonts","DefaultSize",-1);
+
   conf_provisioning_create_host=
     profile->boolValue("Provisioning","CreateHost");
   conf_provisioning_host_template=
@@ -597,63 +574,53 @@ void RDConfig::load()
 		      DEFAULT_MYSQL_HEARTBEAT_INTERVAL);
   conf_mysql_engine=
     profile->stringValue("mySQL","Engine",DEFAULT_MYSQL_ENGINE);
-  conf_mysql_charset=
-    profile->stringValue("mySQL","Charset",DEFAULT_MYSQL_CHARSET);
-  conf_mysql_collation=
-    profile->stringValue("mySQL","Collation",DEFAULT_MYSQL_COLLATION);
-  conf_create_table_postfix=QString(" engine ")+conf_mysql_engine+" "+
-    "character set "+conf_mysql_charset+" "+
-    "collate "+conf_mysql_collation;
+  conf_create_table_postfix=
+    RDConfig::createTablePostfix(conf_mysql_engine);
 
-  facility=profile->stringValue("Logs","Facility",DEFAULT_LOG_FACILITY).lower();
-  if(facility=="syslog") {
-    conf_log_facility=RDConfig::LogSyslog;
-  }
-  if(facility=="file") {
-    conf_log_facility=RDConfig::LogFile;
-  }
-  conf_log_directory=profile->stringValue("Logs","LogDirectory","");
-  conf_log_pattern=profile->stringValue("Logs","LogPattern",
-					DEFAULT_LOG_PATTERN);
   conf_log_xload_debug_data=profile->
     boolValue("Logs","LogXloadDebugData",false);
-  conf_log_core_dump_directory=
-    profile->stringValue("Logs","CoreDumpDirectory",
-			 DEFAULT_LOG_CORE_DUMP_DIRECTORY);
 
   conf_alsa_period_quantity=
     profile->intValue("Alsa","PeriodQuantity",RD_ALSA_DEFAULT_PERIOD_QUANTITY);
   conf_alsa_period_size=
     profile->intValue("Alsa","PeriodSize",RD_ALSA_DEFAULT_PERIOD_SIZE);
   conf_alsa_channels_per_pcm=profile->intValue("Alsa","ChannelsPerPcm",-1);
-  conf_ripcd_logname=profile->stringValue("Ripcd","Logfile","");
-  conf_airplay_logname=profile->stringValue("RDAirPlay","Logfile","");
-  conf_catchd_logname=profile->stringValue("RDCatchd","Logfile","");
-  conf_use_stream_meters=profile->boolValue("Hacks","UseStreamMeters",false);
+
   conf_disable_maint_checks=
     profile->boolValue("Hacks","DisableMaintChecks",false);
   conf_lock_rdairplay_memory=
     profile->boolValue("Hacks","LockRdairplayMemory",false);
-  conf_channels=profile->intValue("Format","Channels",RD_DEFAULT_CHANNELS);
-#ifndef WIN32
   if((user=getpwnam(profile->stringValue("Identity","AudioOwner")))!=NULL) {
     conf_uid=user->pw_uid;
   }
   if((groups=getgrnam(profile->stringValue("Identity","AudioGroup")))!=NULL) {
     conf_gid=groups->gr_gid;
   }
-#endif
-  conf_cae_logfile=profile->stringValue("Caed","Logfile","");
+  if((user=getpwnam(profile->stringValue("Identity","PypadOwner",
+					 RD_DEFAULT_PYPAD_OWNER)))!=NULL) {
+    conf_pypad_uid=user->pw_uid;
+  }
+  if((groups=getgrnam(profile->stringValue("Identity","PypadGroup",
+					   RD_DEFAULT_PYPAD_GROUP)))!=NULL) {
+    conf_pypad_gid=groups->gr_gid;
+  }
+
+  if((user=getpwnam(profile->stringValue("Identity","RnRmlOwner",
+					 RD_DEFAULT_RN_RML_OWNER)))!=NULL) {
+    conf_rn_rml_uid=user->pw_uid;
+  }
+  if((groups=getgrnam(profile->stringValue("Identity","RnRmlGroup",
+					   RD_DEFAULT_RN_RML_GROUP)))!=NULL) {
+    conf_rn_rml_gid=groups->gr_gid;
+  }
+  conf_syslog_facility=profile->intValue("Identity","SyslogFacility",LOG_USER);
+
   conf_enable_mixer_logging=profile->boolValue("Caed","EnableMixerLogging");
   conf_use_realtime=profile->boolValue("Tuning","UseRealtime",false);
   conf_realtime_priority=profile->intValue("Tuning","RealtimePriority",9);
   conf_transcoding_delay=profile->intValue("Tuning","TranscodingDelay");
-#ifndef WIN32
-  conf_tuning_exported_file_mode=profile->
-    stringValue("Tuning","ExportedFileMode",
-		QString().sprintf("%o",RD_TUNING_DEFAULT_EXPORTED_FILE_MODE)).
-    toInt(NULL,8);
-#endif  // WIN32
+  conf_service_timeout=
+    profile->intValue("Tuning","ServiceTimeout",RD_DEFAULT_SERVICE_TIMEOUT);
   conf_temp_directory=profile->stringValue("Tuning","TempDirectory","");
   conf_sas_station=profile->stringValue("SASFilter","Station","");
   conf_sas_matrix=profile->intValue("SASFilter","Matrix",0);
@@ -673,9 +640,8 @@ void RDConfig::load()
   //
   int sock=-1;
 
-#ifndef WIN32
   if((sock=socket(PF_INET,SOCK_DGRAM,IPPROTO_IP))<0) {
-    return;
+    return true;
   }
   struct ifreq ifr;
   int index=0;
@@ -693,22 +659,14 @@ void RDConfig::load()
     ifr.ifr_ifindex=++index;
   }
   close(sock);
-#endif  // WIN32
+
+  return true;
 }
 
 
 void RDConfig::clear()
 {
-#ifdef WIN32
-  QSettings settings;
-  settings.insertSearchPath(QSettings::Windows,"/SalemRadioLabs");
-  conf_filename=QString().sprintf("%s\\%s",
-				  (const char *)settings.
-				  readEntry("/Rivendell/InstallDir"),
-				  (const char *)RD_WIN_CONF_FILE);  
-#else
   conf_filename=RD_CONF_FILE;
-#endif
   conf_module_name="";
   conf_mysql_hostname="";
   conf_mysql_username="";
@@ -717,13 +675,7 @@ void RDConfig::clear()
   conf_mysql_driver="";
   conf_mysql_heartbeat_interval=DEFAULT_MYSQL_HEARTBEAT_INTERVAL;
   conf_mysql_engine=DEFAULT_MYSQL_ENGINE;
-  conf_mysql_charset=DEFAULT_MYSQL_CHARSET;
-  conf_mysql_collation=DEFAULT_MYSQL_COLLATION;
   conf_create_table_postfix="";
-  conf_log_facility=RDConfig::LogSyslog;
-  conf_log_directory="";
-  conf_log_core_dump_directory=DEFAULT_LOG_CORE_DUMP_DIRECTORY;
-  conf_log_pattern=DEFAULT_LOG_PATTERN;
   conf_log_xload_debug_data=false;
   conf_provisioning_create_host=false;
   conf_provisioning_host_template="";
@@ -737,8 +689,14 @@ void RDConfig::clear()
   conf_alsa_channels_per_pcm=-1;
   conf_station_name="";
   conf_password="";
+  conf_http_user_agent="";
   conf_audio_owner="";
   conf_audio_group="";
+  conf_pypad_owner="";
+  conf_pypad_group="";
+  conf_rn_rml_owner="";
+  conf_rn_rml_group="";
+  conf_syslog_facility=LOG_USER;
   conf_audio_root=RD_AUDIO_ROOT;
   conf_audio_extension=RD_AUDIO_EXTENSION;
   conf_label=RD_DEFAULT_LABEL;
@@ -746,28 +704,26 @@ void RDConfig::clear()
   conf_audio_store_mount_type="";
   conf_audio_store_mount_options=RD_DEFAULT_AUDIO_STORE_MOUNT_OPTIONS;
   conf_audio_store_xport_hostname="";
+  conf_font_family="";
+  conf_font_button_size=-1;
+  conf_font_label_size=-1;
+  conf_font_default_size=-1;
   conf_audio_store_cae_hostname="";
-  conf_ripcd_logname="";
-  conf_airplay_logname="";
-  conf_catchd_logname="";
   conf_jack_ports[0].clear();
   conf_jack_ports[1].clear();
-  conf_use_stream_meters=false;
   conf_disable_maint_checks=false;
   conf_lock_rdairplay_memory=false;
-  conf_channels=RD_DEFAULT_CHANNELS;
-#ifndef WIN32
   conf_uid=65535;
   conf_gid=65535;
-#endif
-  conf_cae_logfile="";
+  conf_pypad_uid=65535;
+  conf_pypad_gid=65535;
+  conf_rn_rml_uid=65535;
+  conf_rn_rml_gid=65535;
   conf_enable_mixer_logging=false;
   conf_use_realtime=false;
   conf_realtime_priority=9;
-#ifndef WIN32
-  conf_tuning_exported_file_mode=RD_TUNING_DEFAULT_EXPORTED_FILE_MODE;
-#endif  // WIN32
   conf_transcoding_delay=0;
+  conf_service_timeout=RD_DEFAULT_SERVICE_TIMEOUT;
   conf_temp_directory="";
   conf_sas_station="";
   conf_sas_matrix=-1;
@@ -777,10 +733,80 @@ void RDConfig::clear()
 }
 
 
-QString RDConfig::userAgent(const QString &modname)
+QString RDConfig::createTablePostfix(const QString &engine)
 {
-  if(modname.isEmpty()) {
-    return QString("Mozilla/5.0")+" rivendell/"+VERSION;
+  return QString(" engine ")+engine+" ";
+}
+
+
+QString RDConfig::rdselectExitCodeText(RDSelectExitCode code)
+{
+  QString ret=QObject::tr("Unknown error")+QString().sprintf(" [%d]",code);
+
+  switch(code) {
+  case RDConfig::RDSelectOk:
+    ret=QObject::tr("OK");
+    break;
+
+  case RDConfig::RDSelectInvalidArguments:
+    ret=QObject::tr("Invalid arguments specified");
+    break;
+
+  case RDConfig::RDSelectNoSuchConfiguration:
+    ret=QObject::tr("Specified configuration was not found");
+    break;
+
+  case RDConfig::RDSelectModulesActive:
+    ret=QObject::tr("One or more Rivendell modules are active");
+    break;
+
+  case RDConfig::RDSelectNotRoot:
+    ret=QObject::tr("No running as root");
+    break;
+
+  case RDConfig::RDSelectSystemctlCrashed:
+    ret=QObject::tr("systemctl(8) crashed");
+    break;
+
+  case RDConfig::RDSelectRivendellShutdownFailed:
+    ret=QObject::tr("Rivendell service shutdown failed");
+    break;
+
+  case RDConfig::RDSelectAudioUnmountFailed:
+    ret=QObject::tr("Audio store unmount failed");
+    break;
+
+  case RDConfig::RDSelectAudioMountFailed:
+    ret=QObject::tr("Audio store mount failed");
+    break;
+
+  case RDConfig::RDSelectRivendellStartupFailed:
+    ret=QObject::tr("Rivendell service startup failed");
+    break;
+
+  case RDConfig::RDSelectNoCurrentConfig:
+    ret=QObject::tr("Current configuration was not found");
+    break;
+
+  case RDConfig::RDSelectSymlinkFailed:
+    ret=QObject::tr("Synlink creation failed");
+    break;
+
+  case RDConfig::RDSelectInvalidName:
+    ret=QObject::tr("Invalid configuration name");
+    break;
+
+  case RDConfig::RDSelectMountCrashed:
+    ret=QObject::tr("mount(8) crashed");
+    break;
+
+  case RDConfig::RDSelectCantAccessAutomount:
+    ret=QObject::tr("Unable to update automounter configuration");
+    break;
+
+  case RDConfig::RDSelectLast:
+    break;
   }
-  return QString("Mozilla/5.0 rivendell/")+VERSION+" ("+modname+")";
+
+  return ret;
 }
