@@ -2,7 +2,7 @@
 //
 // A container class for a Rivendell Base Configuration
 //
-//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,12 +21,7 @@
 #ifndef RDCONFIG_H
 #define RDCONFIG_H
 
-#ifndef WIN32
-#include <syslog.h>
 #include <unistd.h>
-#endif  // WIN32
-
-#include <sys/stat.h>
 
 #include <vector>
 
@@ -38,24 +33,28 @@
 class RDConfig
 {
  public:
-  enum LogFacility {LogNone=0,LogSyslog=1,LogFile=2};
-#ifdef WIN32
-  enum LogPriority {LogEmerg=0,LogAlert=1,LogCrit=2,
-		    LogErr=3,LogWarning=4,LogNotice=5,
-		    LogInfo=6,LogDebug=7};
-#else
-  enum LogPriority {LogEmerg=LOG_EMERG,LogAlert=LOG_ALERT,LogCrit=LOG_CRIT,
-		    LogErr=LOG_ERR,LogWarning=LOG_WARNING,LogNotice=LOG_NOTICE,
-		    LogInfo=LOG_INFO,LogDebug=LOG_DEBUG};
-
-#endif  // WIN32
+  enum RDSelectExitCode {RDSelectOk=0,RDSelectInvalidArguments=1,
+			 RDSelectNoSuchConfiguration=2,
+			 RDSelectModulesActive=3,
+			 RDSelectNotRoot=4,
+			 RDSelectSystemctlCrashed=5,
+			 RDSelectRivendellShutdownFailed=6,
+			 RDSelectAudioUnmountFailed=7,
+			 RDSelectAudioMountFailed=8,
+			 RDSelectRivendellStartupFailed=9,
+			 RDSelectNoCurrentConfig=10,
+			 RDSelectSymlinkFailed=11,
+			 RDSelectInvalidName=12,
+			 RDSelectMountCrashed=13,
+			 RDSelectCantAccessAutomount=14,
+			 RDSelectLast=15};
   RDConfig();
   RDConfig(const QString &filename);
   QString filename() const;
   void setFilename(QString filename);
   QString moduleName() const;
   void setModuleName(const QString &modname);
-  QString userAgent() const;
+  QString userAgent(const QString &modname="") const;
   QString mysqlHostname() const;
   QString mysqlUsername() const;
   QString mysqlDbname() const;
@@ -63,15 +62,8 @@ class RDConfig
   QString mysqlDriver() const;
   int mysqlHeartbeatInterval() const;
   QString mysqlEngine() const;
-  QString mysqlCharset() const;
-  QString mysqlCollation() const;
   QString createTablePostfix() const;
-  RDConfig::LogFacility logFacility() const;
-  QString logDirectory() const;
-  QString logCoreDumpDirectory() const;
-  QString logPattern() const;
   bool logXloadDebugData() const;
-  void log(const QString &module,LogPriority prio,const QString &msg);
   bool provisioningCreateHost() const;
   QString provisioningHostTemplate() const;
   QHostAddress provisioningHostIpAddress() const;
@@ -86,6 +78,11 @@ class RDConfig
   QString password() const;
   QString audioOwner() const;
   QString audioGroup() const;
+  QString pypadOwner() const;
+  QString pypadGroup() const;
+  QString rnRmlOwner() const;
+  QString rnRmlGroup() const;
+  int syslogFacility() const;
   QString audioRoot() const;
   QString audioExtension() const;
   QString audioFileName (QString cutname);
@@ -95,36 +92,35 @@ class RDConfig
   QString audioStoreMountOptions() const;
   QString audioStoreCaeHostname() const;
   QString audioStoreXportHostname() const;
-  QString ripcdLogname() const;
-  QString airplayLogname() const;
-  QString catchdLogname() const;
+  QString fontFamily() const;
+  int fontButtonSize() const;
+  int fontLabelSize() const;
+  int fontDefaultSize() const;
   int jackConnections() const;
   QString jackPort(int num,int endpt) const;
-  bool useStreamMeters() const;
   bool disableMaintChecks() const;
   bool lockRdairplayMemory() const;
-  QString caeLogfile() const;
   bool enableMixerLogging() const;
-  unsigned channels() const;
-#ifndef WIN32
   uid_t uid() const;
   gid_t gid() const;
-#endif
+  uid_t pypadUid() const;
+  gid_t pypadGid() const;
+  uid_t rnRmlUid() const;
+  gid_t rnRmlGid() const;
   bool useRealtime();
   int realtimePriority();
   int transcodingDelay() const;
-#ifndef WIN32
-  mode_t tuningExportedFileMode() const;
-#endif  // WIN32
+  int serviceTimeout() const;
   QString tempDirectory();
   QString sasStation() const;
   int sasMatrix() const;
   unsigned sasBaseCart() const;
   QString sasTtyDevice() const;
   QString destination(unsigned n);
-  void load();
+  bool load();
   void clear();
-  static QString userAgent(const QString &modname);
+  static QString createTablePostfix(const QString &engine);
+  static QString rdselectExitCodeText(RDSelectExitCode code);
 
  private:
   QString conf_filename;
@@ -135,14 +131,8 @@ class RDConfig
   QString conf_mysql_password;
   QString conf_mysql_driver;
   QString conf_mysql_engine;
-  QString conf_mysql_charset;
-  QString conf_mysql_collation;
   QString conf_create_table_postfix;
   int conf_mysql_heartbeat_interval;
-  RDConfig::LogFacility conf_log_facility;
-  QString conf_log_directory;
-  QString conf_log_core_dump_directory;
-  QString conf_log_pattern;
   bool conf_provisioning_create_host;
   QString conf_provisioning_host_template;
   QHostAddress conf_provisioning_host_ip_address;
@@ -160,6 +150,11 @@ class RDConfig
   QString conf_password;
   QString conf_audio_owner;
   QString conf_audio_group;
+  QString conf_pypad_owner;
+  QString conf_pypad_group;
+  QString conf_rn_rml_owner;
+  QString conf_rn_rml_group;
+  int conf_syslog_facility;
   QString conf_audio_root;
   QString conf_audio_extension;
   QString conf_label;
@@ -168,24 +163,25 @@ class RDConfig
   QString conf_audio_store_mount_options;
   QString conf_audio_store_xport_hostname;
   QString conf_audio_store_cae_hostname;
-  QString conf_ripcd_logname;
-  QString conf_airplay_logname;
-  QString conf_catchd_logname;
-  bool conf_use_stream_meters;
+  QString conf_font_family;
+  int conf_font_button_size;
+  int conf_font_label_size;
+  int conf_font_default_size;
+  QString conf_http_user_agent;
   bool conf_disable_maint_checks;
   bool conf_lock_rdairplay_memory;
   std::vector<QString> conf_jack_ports[2];
-  unsigned conf_channels;
-#ifndef WIN32
   uid_t conf_uid;
   gid_t conf_gid;
-  mode_t conf_tuning_exported_file_mode;
-#endif
-  QString conf_cae_logfile;
+  uid_t conf_pypad_uid;
+  gid_t conf_pypad_gid;
+  uid_t conf_rn_rml_uid;
+  gid_t conf_rn_rml_gid;
   bool conf_enable_mixer_logging;
   bool conf_use_realtime;
   int conf_transcoding_delay;
   int conf_realtime_priority;
+  int conf_service_timeout;
   QString conf_temp_directory;
   QString conf_sas_station;
   int conf_sas_matrix;
