@@ -22,7 +22,9 @@
 #define RDDELETE_H
 
 #include <qobject.h>
-#include <qurl.h>
+#include <q3url.h>
+
+#include <rdconfig.h>
 
 class RDDelete : public QObject
 {
@@ -34,7 +36,7 @@ class RDDelete : public QObject
 		  ErrorUnspecified=8,ErrorInvalidUser=9,
 		  ErrorInvalidLogin=11,ErrorRemoteAccess=12,
 		  ErrorRemoteConnection=13,ErrorUnknown=14};
-  RDDelete(QObject *parent=0);
+  RDDelete(RDConfig *config,QObject *parent=0);
   void setTargetUrl(const QString &url);
   RDDelete::ErrorCode runDelete(const QString &username,
 				const QString &password,
@@ -42,7 +44,8 @@ class RDDelete : public QObject
   static QString errorText(RDDelete::ErrorCode err);
 
  private:
-  QUrl conv_target_url;
+  Q3Url conv_target_url;
+  RDConfig *conv_config;
 };
 
 
