@@ -2,9 +2,7 @@
 //
 // Abstract a Rivendell Log Manager Grid
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdgrid.h,v 1.5 2010/07/29 19:32:33 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,18 +18,18 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-
 #ifndef RDGRID_H
 #define RDGRID_H
 
 #include <qsqldatabase.h>
 
 #include <rdclock.h>
+#include <rdstation.h>
 
 class RDGrid
 {
   public:
-   RDGrid(QString svc_name);
+  RDGrid(QString svc_name,RDStation *station);
    QString serviceName() const;
    void setServiceName(QString name);
    RDClock *clock(int dayofweek,int hour);
@@ -43,6 +41,7 @@ class RDGrid
   private:
    QString grid_name;
    RDClock *grid_clocks[7][24];
+   RDStation *grid_station;
 };
 
 
