@@ -2,9 +2,7 @@
 //
 // Abstract a Rivendell Podcast
 //
-//   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdpodcast.cpp,v 1.11 2010/11/24 16:57:38 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,13 +18,18 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <syslog.h>
+
 #include <curl/curl.h>
 
-#include <rddb.h>
-#include <rdpodcast.h>
-#include <rdconf.h>
-#include <rdescape_string.h>
-#include <rdurl.h>
+#include <qurl.h>
+
+#include "rdapplication.h"
+#include "rddb.h"
+#include "rdpodcast.h"
+#include "rdconf.h"
+#include "rdescape_string.h"
+#include "rdurl.h"
 
 //
 // CURL Callbacks
@@ -44,13 +47,15 @@ int PodcastErrorCallback(CURL *curl,curl_infotype type,char *msg,size_t size,
   }
   memset(&str,0,size+1);
   memcpy(str,msg,size);
-  syslog(LOG_DEBUG,"CURL MSG: %s",str);
+  rda->syslog(LOG_DEBUG,"CURL MSG: %s",str);
   return 0;
 }
 
 
-RDPodcast::RDPodcast(unsigned id)
+RDPodcast::RDPodcast(RDConfig *config,unsigned id)
 {
+  podcast_config=config;
+
   RDSqlQuery *q;
   QString sql;
 
@@ -211,7 +216,7 @@ QDateTime RDPodcast::originDateTime() const
 
 void RDPodcast::setOriginDateTime(const QDateTime &datetime) const
 {
-  SetRow("ORIGIN_DATETIME",datetime.toString("yyyy-MM-dd hh:mm:ss"));
+  SetRow("ORIGIN_DATETIME",datetime,"yyyy-MM-dd hh:mm:ss");
 }
 
 
@@ -224,7 +229,7 @@ QDateTime RDPodcast::effectiveDateTime() const
 
 void RDPodcast::setEffectiveDateTime(const QDateTime &datetime) const
 {
-  SetRow("EFFECTIVE_DATETIME",datetime.toString("yyyy-MM-dd hh:mm:ss"));
+  SetRow("EFFECTIVE_DATETIME",datetime,"yyyy-MM-dd hh:mm:ss");
 }
 
 
@@ -305,34 +310,48 @@ bool RDPodcast::removeAudio(RDFeed *feed,QString *err_text,bool log_debug) const
   char userpwd[256];
 
   if((curl=curl_easy_init())==NULL) {
-    syslog(LOG_ERR,"unable to initialize curl library\n");
+    rda->syslog(LOG_ERR,"unable to initialize curl library\n");
     return false;
   }
   url=new QUrl(feed->purgeUrl());
-  strncpy(urlstr,(const char *)(url->protocol()+"://"+url->host()+"/"),1024);
+  strncpy(urlstr,(const char *)(url->protocol()+"://"+url->host()+"/").utf8(),
+	  1024);
   curl_easy_setopt(curl,CURLOPT_URL,urlstr);
-  strncpy(userpwd,(const char *)QString().
-		   sprintf("%s:%s",(const char *)feed->purgeUsername(),
-			   (const char *)feed->purgePassword()),256);
+  strncpy(userpwd,(feed->purgeUsername()+":"+feed->purgePassword()).utf8(),256);
   curl_easy_setopt(curl,CURLOPT_USERPWD,userpwd);
   curl_easy_setopt(curl,CURLOPT_HTTPAUTH,CURLAUTH_ANY);
+  curl_easy_setopt(curl,CURLOPT_USERAGENT,
+		   (const char *)podcast_config->userAgent().utf8());
   if(log_debug) {
     curl_easy_setopt(curl,CURLOPT_VERBOSE,1);
     curl_easy_setopt(curl,CURLOPT_DEBUGFUNCTION,PodcastErrorCallback);
   }
-  currentdir="";
-  if(!url->dirPath().right(url->dirPath().length()-1).isEmpty()) {
-    currentdir=url->dirPath().right(url->dirPath().length()-1)+"/";
+  if(url->scheme()=="ftp") {
+    currentdir="";
+    if(!url->dirPath().right(url->dirPath().length()-1).isEmpty()) {
+      currentdir=url->dirPath().right(url->dirPath().length()-1)+"/";
+    }
+    if(!url->fileName().isEmpty()) {
+      currentdir+=url->fileName()+"/";
+    }
+    if(!currentdir.isEmpty()) {
+      cmds=curl_slist_append(cmds,QString().sprintf("cwd %s",
+						    (const char *)currentdir));
+    }
+    cmds=curl_slist_append(cmds, QString().sprintf("dele %s",
+						   (const char *)audioFilename()));
   }
-  if(!url->fileName().isEmpty()) {
-    currentdir+=url->fileName()+"/";
+  if(url->scheme()=="sftp") {
+    cmds=curl_slist_append(cmds,("rm "+url->path()+"/"+audioFilename()).toUtf8());
   }
-  if(!currentdir.isEmpty()) {
-    cmds=curl_slist_append(cmds,QString().sprintf("cwd %s",
-						  (const char *)currentdir));
+  if(cmds==NULL) {
+    if(err_text!=NULL) {
+      *err_text="\""+url->scheme()+"\" scheme does not support remote deletion";
+      delete url;
+      curl_easy_cleanup(curl);
+      return false;
+    }
   }
-  cmds=curl_slist_append(cmds, QString().sprintf("dele %s",
-	    (const char *)audioFilename()));
   curl_easy_setopt(curl,CURLOPT_QUOTE,cmds);
   switch((err=curl_easy_perform(curl))) {
   case CURLE_OK:
@@ -360,17 +379,14 @@ bool RDPodcast::removeAudio(RDFeed *feed,QString *err_text,bool log_debug) const
 QString RDPodcast::guid(const QString &url,const QString &filename,
 			unsigned feed_id,unsigned cast_id)
 {
-  return QString().sprintf("%s/%s_%06u_%06u",
-			   (const char *)url,(const char *)filename,
-			   feed_id,cast_id);
+  return url+"/"+filename+QString().sprintf("_%06u_%06u",feed_id,cast_id);
 }
 
 
 QString RDPodcast::guid(const QString &full_url,unsigned feed_id,
 			unsigned cast_id)
 {
-  return QString().sprintf("%s_%06u_%06u",
-			   (const char *)full_url,feed_id,cast_id);
+  return full_url+QString().sprintf("_%06u_%06u",feed_id,cast_id);
 }
 
 
@@ -379,10 +395,9 @@ void RDPodcast::SetRow(const QString &param,int value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE PODCASTS SET %s=%d WHERE ID=%u",
-			(const char *)param,
-			value,
-			podcast_id);
+  sql=QString("update PODCASTS set ")+
+    param+QString().sprintf("=%d where ",value)+
+    QString().sprintf("ID=%u",podcast_id);
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -393,10 +408,23 @@ void RDPodcast::SetRow(const QString &param,const QString &value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE PODCASTS SET %s=\"%s\" WHERE ID=%u",
-			(const char *)param,
-			(const char *)RDEscapeString(value),
-			podcast_id);
+  sql=QString("update PODCASTS set ")+
+    param+"=\""+RDEscapeString(value)+"\" where "+
+    QString().sprintf("ID=%u",podcast_id);
+  q=new RDSqlQuery(sql);
+  delete q;
+}
+
+
+void RDPodcast::SetRow(const QString &param,const QDateTime &value,
+                       const QString &format) const
+{
+  RDSqlQuery *q;
+  QString sql;
+
+  sql=QString("update PODCASTS set ")+
+    param+"="+RDCheckDateTime(value, format)+" where "+
+    QString().sprintf("ID=%u",podcast_id);
   q=new RDSqlQuery(sql);
   delete q;
 }
