@@ -610,7 +610,7 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
     break;
 
   case RDReport::RadioTraffic:
-    ret=ExportRadioTraffic(filename,startdate,enddate,mixname);
+    ret=ExportRadioTraffic(filename,startdate,enddate,mixname,0);
     break;
 
   case RDReport::VisualTraffic:
@@ -619,11 +619,15 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
 
   case RDReport::CounterPoint:
   case RDReport::WideOrbit:
-    ret=ExportRadioTraffic(filename,startdate,enddate,mixname);
+    ret=ExportRadioTraffic(filename,startdate,enddate,mixname,0);
+    break;
+
+  case RDReport::CounterPoint2:
+    ret=ExportRadioTraffic(filename,startdate,enddate,mixname,1);
     break;
 
   case RDReport::Music1:
-    ret=ExportRadioTraffic(filename,startdate,enddate,mixname);
+    ret=ExportRadioTraffic(filename,startdate,enddate,mixname,0);
     break;
 
   case RDReport::MusicClassical:
@@ -697,6 +701,9 @@ QString RDReport::filterText(RDReport::ExportFilter filter)
   case RDReport::CounterPoint:
     return QObject::tr("CounterPoint Traffic Reconciliation");
 
+  case RDReport::CounterPoint2:
+    return QObject::tr("CounterPoint Traffic Reconciliation v2");
+
   case RDReport::MrMaster:
     return QObject::tr("Mr. Master Reconciliation");
 
@@ -724,9 +731,10 @@ QString RDReport::filterText(RDReport::ExportFilter filter)
   case RDReport::CutLog:
     return QObject::tr("Cut Log");
 
-  default:
-    return QObject::tr("Unknown");
+  case RDReport::LastFilter:
+    break;
   }
+
   return QObject::tr("Unknown");
 }
 
@@ -758,6 +766,7 @@ bool RDReport::multipleDaysAllowed(RDReport::ExportFilter filter)
   case RDReport::RadioTraffic:
   case RDReport::VisualTraffic:
   case RDReport::CounterPoint:
+  case RDReport::CounterPoint2:
   case RDReport::LastFilter:
   case RDReport::MrMaster:
   case RDReport::Music1:
@@ -789,6 +798,7 @@ bool RDReport::multipleMonthsAllowed(RDReport::ExportFilter filter)
   case RDReport::RadioTraffic:
   case RDReport::VisualTraffic:
   case RDReport::CounterPoint:
+  case RDReport::CounterPoint2:
   case RDReport::LastFilter:
   case RDReport::MrMaster:
   case RDReport::Music1:
