@@ -2,9 +2,7 @@
 //
 // A naively simple player for Rivendell Carts.
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdsimpleplayer.h,v 1.4.2.1 2009/03/26 20:27:57 cvs Exp $
+//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -32,16 +30,17 @@
 #ifndef RDSIMPLEPLAYER_H
 #define RDSIMPLEPLAYER_H
 
-
 class RDSimplePlayer : public QWidget
 {
   Q_OBJECT
  public:
   RDSimplePlayer(RDCae *cae,RDRipc *ripc,int card,int port,
-		 unsigned start_cart,unsigned end_cart,
-		 QWidget *parent=0,const char *name=0);
+		 unsigned start_cart,unsigned end_cart,QWidget *parent=0);
   ~RDSimplePlayer();
   void setCart(unsigned cart);
+  void setCart(QString cart);
+  void setCut(QString cart);
+  bool isPlaying();
   RDTransportButton *playButton() const;
   RDTransportButton *stopButton() const;
 
@@ -66,6 +65,7 @@ class RDSimplePlayer : public QWidget
   int play_port;
   std::queue<int> play_handles;
   unsigned play_cart;
+  QString play_cut;
   unsigned play_start_cart;
   unsigned play_end_cart;
   bool play_is_playing;
