@@ -2,7 +2,7 @@
 //
 // Abstract a Rivendell Workstation.
 //
-//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -270,6 +270,19 @@ void RDStation::setReportEditorPath(const QString &cmd)
 }
 
 
+QString RDStation::browserPath() const
+{
+  return RDGetSqlValue("STATIONS","NAME",station_name,"BROWSER_PATH").
+    toString();
+}
+
+
+void RDStation::setBrowserPath(const QString &cmd) const
+{
+  SetRow("BROWSER_PATH",cmd);
+}
+
+
 RDStation::FilterMode RDStation::filterMode() const
 {
   return (RDStation::FilterMode)RDGetSqlValue("STATIONS","NAME",station_name,
@@ -463,38 +476,38 @@ void RDStation::setScanned(bool state) const
 bool RDStation::haveCapability(Capability cap) const
 {
   switch(cap) {
-      case RDStation::HaveOggenc:
-	return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
-				  "HAVE_OGGENC").toString());
-	break;
-
-      case RDStation::HaveOgg123:
-	return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
+  case RDStation::HaveOggenc:
+    return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
+				"HAVE_OGGENC").toString());
+    break;
+ 
+  case RDStation::HaveOgg123:
+    return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
 				  "HAVE_OGG123").toString());
-	break;
+    break;
 
-      case RDStation::HaveFlac:
-	return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
+  case RDStation::HaveFlac:
+    return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
 				  "HAVE_FLAC").toString());
-	break;
+    break;
 
-      case RDStation::HaveLame:
-	return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
+  case RDStation::HaveLame:
+    return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
 				  "HAVE_LAME").toString());
-	break;
+    break;
 
-      case RDStation::HaveMp4Decode:
-	return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
-				  "HAVE_MP4_DECODE").toString());
+  case RDStation::HaveMp4Decode:
+    return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
+				"HAVE_MP4_DECODE").toString());
 
-      case RDStation::HaveMpg321:
-	return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
-				  "HAVE_MPG321").toString());
+  case RDStation::HaveMpg321:
+    return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
+				"HAVE_MPG321").toString());
 
-      case RDStation::HaveTwoLame:
-	return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
-				  "HAVE_TWOLAME").toString());
-	break;
+  case RDStation::HaveTwoLame:
+    return RDBool(RDGetSqlValue("STATIONS","NAME",station_name,
+				"HAVE_TWOLAME").toString());
+    break;
   }
   return false;
 }
@@ -503,33 +516,33 @@ bool RDStation::haveCapability(Capability cap) const
 void RDStation::setHaveCapability(Capability cap,bool state) const
 {
   switch(cap) {
-      case RDStation::HaveOggenc:
-	SetRow("HAVE_OGGENC",state);
-	break;
+  case RDStation::HaveOggenc:
+    SetRow("HAVE_OGGENC",state);
+    break;
 
-      case RDStation::HaveOgg123:
-	SetRow("HAVE_OGG123",state);
-	break;
+  case RDStation::HaveOgg123:
+    SetRow("HAVE_OGG123",state);
+    break;
 
-      case RDStation::HaveFlac:
-	SetRow("HAVE_FLAC",state);
-	break;
+  case RDStation::HaveFlac:
+    SetRow("HAVE_FLAC",state);
+    break;
 
-      case RDStation::HaveLame:
-	SetRow("HAVE_LAME",state);
-	break;
+  case RDStation::HaveLame:
+    SetRow("HAVE_LAME",state);
+    break;
 
-      case RDStation::HaveMp4Decode:
-	SetRow("HAVE_MP4_DECODE",state);
-	break;
+  case RDStation::HaveMp4Decode:
+    SetRow("HAVE_MP4_DECODE",state);
+    break;
 
-      case RDStation::HaveMpg321:
-	SetRow("HAVE_MPG321",state);
-	break;
+  case RDStation::HaveMpg321:
+    SetRow("HAVE_MPG321",state);
+    break;
 
-      case RDStation::HaveTwoLame:
-	SetRow("HAVE_TWOLAME",state);
-	break;
+  case RDStation::HaveTwoLame:
+    SetRow("HAVE_TWOLAME",state);
+    break;
   }
 }
 
@@ -582,20 +595,20 @@ void RDStation::setCardDriver(int cardnum,AudioDriver driver) const
 QString RDStation::driverVersion(AudioDriver driver) const
 {
   switch(driver) {
-      case RDStation::None:
-	return QString();
+  case RDStation::None:
+    return QString();
 
-      case RDStation::Hpi:
-	return RDGetSqlValue("STATIONS","NAME",station_name,"HPI_VERSION").
-	  toString();
+  case RDStation::Hpi:
+    return RDGetSqlValue("STATIONS","NAME",station_name,"HPI_VERSION").
+      toString();
 
-      case RDStation::Jack:
-	return RDGetSqlValue("STATIONS","NAME",station_name,"JACK_VERSION").
-	  toString();
+  case RDStation::Jack:
+    return RDGetSqlValue("STATIONS","NAME",station_name,"JACK_VERSION").
+      toString();
 
-      case RDStation::Alsa:
-	return RDGetSqlValue("STATIONS","NAME",station_name,"ALSA_VERSION").
-	  toString();
+  case RDStation::Alsa:
+    return RDGetSqlValue("STATIONS","NAME",station_name,"ALSA_VERSION").
+      toString();
   }
   return QString();
 }
@@ -604,20 +617,20 @@ QString RDStation::driverVersion(AudioDriver driver) const
 void RDStation::setDriverVersion(AudioDriver driver,QString ver) const
 {
   switch(driver) {
-      case RDStation::None:
-	break;
+  case RDStation::None:
+    break;
 
-      case RDStation::Hpi:
-	SetRow("HPI_VERSION",ver);
-	break;
+  case RDStation::Hpi:
+    SetRow("HPI_VERSION",ver);
+    break;
 
-      case RDStation::Jack:
-	SetRow("JACK_VERSION",ver);
-	break;
+  case RDStation::Jack:
+    SetRow("JACK_VERSION",ver);
+    break;
 
-      case RDStation::Alsa:
-	SetRow("ALSA_VERSION",ver);
-	break;
+  case RDStation::Alsa:
+    SetRow("ALSA_VERSION",ver);
+    break;
   }
 }
 
@@ -872,7 +885,8 @@ bool RDStation::create(const QString &name,QString *err_msg,
       "CARTSLOT_ROWS,"+       // 20
       "ENABLE_DRAGDROP,"+     // 21
       "ENFORCE_PANEL_SETUP,"+ // 22
-      "REPORT_EDITOR_PATH "+  // 23
+      "REPORT_EDITOR_PATH,"+  // 23
+      "BROWSER_PATH "+        // 24
       "from STATIONS where "+
       "NAME=\""+RDEscapeString(exemplar)+"\"";
     q=new RDSqlQuery(sql);
@@ -906,7 +920,8 @@ bool RDStation::create(const QString &name,QString *err_msg,
 	QString().sprintf("CARTSLOT_ROWS=%d,",q->value(20).toInt())+
 	"ENABLE_DRAGDROP=\""+RDEscapeString(q->value(21).toString())+"\","+
 	"ENFORCE_PANEL_SETUP=\""+RDEscapeString(q->value(22).toString())+"\","+
-	"REPORT_EDITOR_PATH=\""+RDEscapeString(q->value(23).toString())+"\"";
+	"REPORT_EDITOR_PATH=\""+RDEscapeString(q->value(23).toString())+"\","+
+	"BROWSER_PATH=\""+RDEscapeString(q->value(24).toString())+"\"";
       q1=new RDSqlQuery(sql);
       if(!q1->isActive()) {
 	*err_msg=QObject::tr("host already exists");
