@@ -21,6 +21,7 @@
 #ifndef RDSYSTEM_H
 #define RDSYSTEM_H
 
+#include <qhostaddress.h>
 #include <qvariant.h>
 
 class RDSystem
@@ -31,12 +32,18 @@ class RDSystem
   void setSampleRate(unsigned rate) const;
   bool allowDuplicateCartTitles() const;
   void setAllowDuplicateCartTitles(bool state) const;
+  bool fixDuplicateCartTitles() const;
+  void setFixDuplicateCartTitles(bool state) const;
   unsigned maxPostLength() const;
   void setMaxPostLength(unsigned bytes) const;
   QString isciXreferencePath() const;
   void setIsciXreferencePath(const QString &str) const;
   QString tempCartGroup() const;
   void setTempCartGroup(const QString &str) const;
+  bool showUserList() const;
+  void setShowUserList(bool state) const;
+  QHostAddress notificationAddress() const;
+  void setNotificationAddress(const QHostAddress &addr);
   QString xml() const;
 
  private:
