@@ -2,7 +2,7 @@
 //
 // Upload a File
 //
-//   (C) Copyright 2010,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2010-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -34,7 +34,7 @@ class RDUpload : public QObject
 		  ErrorUnspecified=8,ErrorInvalidUser=9,ErrorAborted=10,
 		  ErrorInvalidLogin=11,ErrorRemoteAccess=12,
 		  ErrorRemoteConnection=13};
-  RDUpload(const QString &station_name,QObject *parent=0);
+  RDUpload(QObject *parent=0);
   void setSourceFile(const QString &filename);
   void setDestinationUrl(const QString &url);
   int totalSteps() const;
