@@ -2,7 +2,7 @@
 //
 //   A class for handling Microsoft WAV files.
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -25,9 +25,7 @@
 #include <vector>
 #include <sys/types.h>
 #include <sys/stat.h>
-#ifndef WIN32
 #include <unistd.h>
-#endif  // WIN32
 #include <qobject.h>
 #include <qstring.h>
 #include <qdatetime.h>
@@ -77,6 +75,7 @@
 #define AV10_CHUNK_SIZE 512
 #define AIR1_CHUNK_SIZE 2048
 #define COMM_CHUNK_SIZE 18
+#define RDXL_CHUNK_SIZE 4
 
 //
 // Maximum Header Size for ATX Files
@@ -1005,9 +1004,20 @@ class RDWaveFile
 
    bool getAIR1Chunk() const;
 
+   /**
+    * Returns true if the WAV file contains an RDXL chunk, otherwise false.
+    **/
+   bool getRdxlChunk() const;
+   QString getRdxlContents() const;
+   void setRdxlContents(const QString &xml);
+
    double getNormalizeLevel() const;
    void setNormalizeLevel(double level);
 
+   static QString formatText(Format fmt);
+   static QString typeText(Type type);
+
+
   private:
    RDWaveFile::Type GetType(int fd);
    bool IsWav(int fd);
@@ -1024,6 +1034,7 @@ class RDWaveFile
 		 unsigned char *chunk,size_t size,bool big_end=false);
    void WriteChunk(int fd,const char *cname,unsigned char *buf,unsigned size,
 		   bool big_end=false);
+   void WriteChunk(int fd,const char *cname,const QString &contents);
    bool GetFmt(int fd);
    bool GetFact(int fd);
    bool GetCart(int fd);
@@ -1034,6 +1045,7 @@ class RDWaveFile
    bool GetScot(int fd);
    bool GetAv10(int fd);
    bool GetAir1(int fd);
+   bool GetRdxl(int fd);
    bool GetComm(int fd);
    bool ReadListElement(unsigned char *buffer,unsigned *offset,unsigned size);
    bool ReadTmcMetadata(int fd);
@@ -1064,6 +1076,7 @@ class RDWaveFile
 #endif  // HAVE_VORBIS
    int WriteOggBuffer(char *buf,int size);
    unsigned FrameOffset(int msecs) const;
+   QString wave_file_name;
    QFile wave_file;
    RDWaveData *wave_data;
    bool recordable;                // Allow DATA chunk writes?
@@ -1199,6 +1212,9 @@ class RDWaveFile
    bool AIR1_chunk;
    unsigned char AIR1_chunk_data[AIR1_CHUNK_SIZE];
 
+   bool rdxl_chunk;
+   QString rdxl_contents;
+
    double normalize_level; 
    
    bool av10_chunk;
