@@ -55,6 +55,8 @@
 #define RDXPORT_COMMAND_REHASH 32
 #define RDXPORT_COMMAND_LISTSYSTEMSETTINGS 33
 #define RDXPORT_COMMAND_LOCKLOG 34
+#define RDXPORT_COMMAND_SAVESTRING 35
+#define RDXPORT_COMMAND_SAVEFILE 36
 
 
 #endif  // RDXPORT_INTERFACE_H
