@@ -2,7 +2,7 @@
 //
 // Add a Rivendell Matrix
 //
-//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,14 +21,13 @@
 #ifndef ADD_MATRIX_H
 #define ADD_MATRIX_H
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
 #include <qcombobox.h>
 #include <qspinbox.h>
 
+#include <rddialog.h>
 #include <rduser.h>
 
-class AddMatrix : public QDialog
+class AddMatrix : public RDDialog
 {
  Q_OBJECT
  public:
