@@ -2,7 +2,7 @@
 //
 // Edit a Rivendell Feed
 //
-//   (C) Copyright 2002-2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -26,17 +26,19 @@
 #include <qmessagebox.h>
 #include <qpainter.h>
 #include <qdatetime.h>
-#include <qurl.h>
+#include <q3url.h>
 
+#include <rdapplication.h>
 #include <rdexport_settings_dialog.h>
 
-#include <edit_feed.h>
-#include <list_aux_fields.h>
-#include <globals.h>
+#include "edit_feed.h"
+#include "globals.h"
 
 EditFeed::EditFeed(const QString &feed,QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   //
   // Fix the Window Size
   //
@@ -45,17 +47,9 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   setMinimumHeight(sizeHint().height());
   setMaximumHeight(sizeHint().height());
 
-  feed_feed=new RDFeed(feed,admin_config,this);
+  feed_feed=new RDFeed(feed,rda->config(),this);
 
-  setCaption(tr("Feed: ")+feed);
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-  QFont small_font=QFont("Helvetica",12,QFont::Normal);
-  small_font.setPixelSize(12);
+  setWindowTitle("RDAdmin - "+tr("Feed: ")+feed);
 
   //
   // Feed Name
@@ -66,16 +60,15 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_keyname_edit->setReadOnly(true);
   QLabel *feed_keyname_label=new QLabel(feed_keyname_edit,tr("Key Name:"),this);
   feed_keyname_label->setGeometry(10,11,100,19);
-  feed_keyname_label->setFont(font);
-  feed_keyname_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_keyname_label->setFont(labelFont());
+  feed_keyname_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Channel Section
   //
-  feed_channel_section_label=new QLabel(tr("CHANNEL VALUES"),this);
-  feed_channel_section_label->setGeometry(30,41,130,20);
-  feed_channel_section_label->setAlignment(AlignCenter);
-  feed_channel_section_label->setFont(font);
+  feed_channel_section_groupbox=new QGroupBox(tr("Channel Values"),this);
+  feed_channel_section_groupbox->setFont(labelFont());
+  feed_channel_section_groupbox->setGeometry(10,45,sizeHint().width()/2-10,227);
 
   //
   // Channel Title
@@ -86,8 +79,8 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_channel_title_label=
     new QLabel(feed_channel_title_edit,tr("Title:"),this);
   feed_channel_title_label->setGeometry(20,60,90,19);
-  feed_channel_title_label->setFont(font);
-  feed_channel_title_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_channel_title_label->setFont(labelFont());
+  feed_channel_title_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Channel Category
@@ -98,9 +91,9 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_channel_category_label=
     new QLabel(feed_channel_category_edit,tr("Category:"),this);
   feed_channel_category_label->setGeometry(20,82,90,19);
-  feed_channel_category_label->setFont(font);
+  feed_channel_category_label->setFont(labelFont());
   feed_channel_category_label->
-    setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Channel Link
@@ -111,8 +104,8 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_channel_link_label=
     new QLabel(feed_channel_link_edit,tr("Link:"),this);
   feed_channel_link_label->setGeometry(20,104,90,19);
-  feed_channel_link_label->setFont(font);
-  feed_channel_link_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_channel_link_label->setFont(labelFont());
+  feed_channel_link_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Channel Copyright
@@ -123,9 +116,9 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_channel_copyright_label=
     new QLabel(feed_channel_copyright_edit,tr("Copyright:"),this);
   feed_channel_copyright_label->setGeometry(20,126,90,19);
-  feed_channel_copyright_label->setFont(font);
+  feed_channel_copyright_label->setFont(labelFont());
   feed_channel_copyright_label->
-    setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Channel Webmaster
@@ -136,9 +129,9 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_channel_webmaster_label=
     new QLabel(feed_channel_webmaster_edit,tr("Webmaster:"),this);
   feed_channel_webmaster_label->setGeometry(20,148,90,19);
-  feed_channel_webmaster_label->setFont(font);
+  feed_channel_webmaster_label->setFont(labelFont());
   feed_channel_webmaster_label->
-    setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Channel Language
@@ -150,22 +143,19 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_channel_language_label=
     new QLabel(feed_channel_language_edit,tr("Language:"),this);
   feed_channel_language_label->setGeometry(20,170,90,19);
-  feed_channel_language_label->setFont(font);
-  feed_channel_language_label->
-    setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_channel_language_label->setFont(labelFont());
+  feed_channel_language_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Channel Description
   //
-  feed_channel_description_edit=new QTextEdit(this);
-  feed_channel_description_edit->
-    setGeometry(115,192,375,76);
+  feed_channel_description_edit=new Q3TextEdit(this);
+  feed_channel_description_edit->setGeometry(115,192,375,76);
   feed_channel_description_label=
     new QLabel(feed_channel_description_edit,tr("Description:"),this);
   feed_channel_description_label->setGeometry(20,192,90,19);
-  feed_channel_description_label->setFont(font);
-  feed_channel_description_label->
-    setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_channel_description_label->setFont(labelFont());
+  feed_channel_description_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Purge Audio URL
@@ -178,8 +168,8 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_purge_url_label=
     new QLabel(feed_purge_url_edit,tr("Audio Upload URL:"),this);
   feed_purge_url_label->setGeometry(20,280,130,19);
-  feed_purge_url_label->setFont(font);
-  feed_purge_url_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_purge_url_label->setFont(labelFont());
+  feed_purge_url_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Purge Username
@@ -192,8 +182,8 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_purge_username_label=
     new QLabel(feed_purge_username_edit,tr("Username:"),this);
   feed_purge_username_label->setGeometry(40,302,180,19);
-  feed_purge_username_label->setFont(font);
-  feed_purge_username_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_purge_username_label->setFont(labelFont());
+  feed_purge_username_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Purge Password
@@ -205,8 +195,8 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_purge_password_label=
     new QLabel(feed_purge_password_edit,tr("Password:"),this);
   feed_purge_password_label->setGeometry(320,302,70,19);
-  feed_purge_password_label->setFont(font);
-  feed_purge_password_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_purge_password_label->setFont(labelFont());
+  feed_purge_password_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Audio Format
@@ -216,11 +206,11 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_format_edit->setReadOnly(true);
   feed_format_label=new QLabel(feed_format_edit,tr("Upload Format:"),this);
   feed_format_label->setGeometry(5,324,145,20);
-  feed_format_label->setFont(font);
-  feed_format_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_format_label->setFont(labelFont());
+  feed_format_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   feed_format_button=new QPushButton(this);
   feed_format_button->setGeometry(450,324,40,24);
-  feed_format_button->setFont(small_font);
+  feed_format_button->setFont(subButtonFont());
   feed_format_button->setText(tr("S&et"));
   connect(feed_format_button,SIGNAL(clicked()),this,SLOT(setFormatData()));
 
@@ -233,8 +223,8 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_normalize_check_label=
     new QLabel(feed_normalize_box,tr("Normalize"),this);
   feed_normalize_check_label->setGeometry(175,346,83,20);
-  feed_normalize_check_label->setFont(font);
-  feed_normalize_check_label->setAlignment(AlignLeft|AlignVCenter);
+  feed_normalize_check_label->setFont(labelFont());
+  feed_normalize_check_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
   connect(feed_normalize_box,SIGNAL(toggled(bool)),
 	  this,SLOT(normalizeCheckData(bool)));
 
@@ -246,12 +236,12 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_normalize_spin->setRange(-30,-1);
   feed_normalize_label=new QLabel(feed_normalize_spin,tr("Level:"),this);
   feed_normalize_label->setGeometry(245,346,45,20);
-  feed_normalize_label->setFont(font);
-  feed_normalize_label->setAlignment(AlignRight|AlignVCenter);
+  feed_normalize_label->setFont(labelFont());
+  feed_normalize_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   feed_normalize_unit_label=new QLabel(tr("dBFS"),this);
   feed_normalize_unit_label->setGeometry(340,346,40,20);
-  feed_normalize_unit_label->setFont(font);
-  feed_normalize_unit_label->setAlignment(AlignLeft|AlignVCenter);
+  feed_normalize_unit_label->setFont(labelFont());
+  feed_normalize_unit_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Base Audio URL
@@ -262,8 +252,8 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_base_url_label=
     new QLabel(feed_base_url_edit,tr("Audio Download URL:"),this);
   feed_base_url_label->setGeometry(20,368,130,19);
-  feed_base_url_label->setFont(font);
-  feed_base_url_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_base_url_label->setFont(labelFont());
+  feed_base_url_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Keep Expired Metadata Checkbox
@@ -273,8 +263,8 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_keep_metadata_label=
     new QLabel(feed_keep_metadata_box,tr("Keep Expired Metadata"),this);
   feed_keep_metadata_label->setGeometry(175,390,180,19);
-  feed_keep_metadata_label->setFont(font);
-  feed_keep_metadata_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  feed_keep_metadata_label->setFont(labelFont());
+  feed_keep_metadata_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
  
   //
   // AutoPost Checkbox
@@ -284,8 +274,8 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_autopost_label=
     new QLabel(feed_autopost_box,tr("Enable AutoPost"),this);
   feed_autopost_label->setGeometry(385,390,200,19);
-  feed_autopost_label->setFont(font);
-  feed_autopost_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  feed_autopost_label->setFont(labelFont());
+  feed_autopost_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
  
   //
   // Enclosure Preamble
@@ -296,8 +286,8 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_base_preamble_label=
     new QLabel(feed_base_preamble_edit,tr("Enclosure Preamble:"),this);
   feed_base_preamble_label->setGeometry(20,412,130,19);
-  feed_base_preamble_label->setFont(font);
-  feed_base_preamble_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_base_preamble_label->setFont(labelFont());
+  feed_base_preamble_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Audio File Extension
@@ -308,8 +298,8 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_extension_label=
     new QLabel(feed_extension_edit,tr("Audio Extension:"),this);
   feed_extension_label->setGeometry(20,434,130,19);
-  feed_extension_label->setFont(font);
-  feed_extension_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_extension_label->setFont(labelFont());
+  feed_extension_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Maximum Shelf Life
@@ -321,15 +311,15 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_max_shelf_life_label=
     new QLabel(feed_max_shelf_life_spin,tr("Maximum Shelf Life:"),this);
   feed_max_shelf_life_label->setGeometry(20,456,130,19);
-  feed_max_shelf_life_label->setFont(font);
+  feed_max_shelf_life_label->setFont(labelFont());
   feed_max_shelf_life_label->
-    setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+    setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   feed_max_shelf_life_unit_label=
     new QLabel(feed_max_shelf_life_spin,tr("days"),this);
   feed_max_shelf_life_unit_label->setGeometry(220,456,50,19);
-  feed_max_shelf_life_unit_label->setFont(font);
+  feed_max_shelf_life_unit_label->setFont(labelFont());
   feed_max_shelf_life_unit_label->
-    setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+    setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Episode Order
@@ -341,8 +331,8 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_castorder_label=
     new QLabel(feed_castorder_box,tr("Episode Sort Order:"),this);
   feed_castorder_label->setGeometry(20,478,130,19);
-  feed_castorder_label->setFont(font);
-  feed_castorder_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_castorder_label->setFont(labelFont());
+  feed_castorder_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Media Link Mode
@@ -355,8 +345,8 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   feed_media_link_mode_label=
     new QLabel(feed_media_link_mode_box,tr("Media Link Mode:"),this);
   feed_media_link_mode_label->setGeometry(20,500,130,19);
-  feed_media_link_mode_label->setFont(font);
-  feed_media_link_mode_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_media_link_mode_label->setFont(labelFont());
+  feed_media_link_mode_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Feed Redirection
@@ -366,62 +356,46 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   QLabel *label=
     new QLabel(feed_redirect_check,tr("Enable Feed Redirection"),this);
   label->setGeometry(40,532,200,19);
-  label->setFont(font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   feed_redirect_edit=new QLineEdit(this);
   feed_redirect_edit->setGeometry(85,552,405,20);
   feed_redirect_label=new QLabel(feed_redirect_edit,tr("URL:"),this);
   feed_redirect_label->setGeometry(40,552,40,19);
-  feed_redirect_label->setFont(font);
-  feed_redirect_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_redirect_label->setFont(labelFont());
+  feed_redirect_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Header XML
   //
-  feed_header_xml_edit=new QTextEdit(this);
-  feed_header_xml_edit->
-    setGeometry(615,10,365,76);
+  feed_header_xml_edit=new Q3TextEdit(this);
+  feed_header_xml_edit->setGeometry(615,10,365,76);
   feed_header_xml_label=new QLabel(feed_header_xml_edit,tr("Header XML:"),this);
   feed_header_xml_label->setGeometry(520,10,90,19);
-  feed_header_xml_label->setFont(font);
-  feed_header_xml_label->
-    setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_header_xml_label->setFont(labelFont());
+  feed_header_xml_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Channel XML
   //
-  feed_channel_xml_edit=new QTextEdit(this);
-  feed_channel_xml_edit->
-    setGeometry(615,88,365,176);
+  feed_channel_xml_edit=new Q3TextEdit(this);
+  feed_channel_xml_edit->setGeometry(615,88,365,176);
   feed_channel_xml_label=
     new QLabel(feed_channel_xml_edit,tr("Channel XML:"),this);
   feed_channel_xml_label->setGeometry(520,88,90,19);
-  feed_channel_xml_label->setFont(font);
-  feed_channel_xml_label->
-    setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_channel_xml_label->setFont(labelFont());
+  feed_channel_xml_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Item XML
   //
-  feed_item_xml_edit=new QTextEdit(this);
-  feed_item_xml_edit->
-    setGeometry(615,270,365,176);
+  feed_item_xml_edit=new Q3TextEdit(this);
+  feed_item_xml_edit->setGeometry(615,270,365,250);
   feed_item_xml_label=new QLabel(feed_item_xml_edit,tr("Item XML:"),this);
   feed_item_xml_label->setGeometry(520,270,90,19);
-  feed_item_xml_label->setFont(font);
-  feed_item_xml_label->
-    setAlignment(AlignRight|AlignVCenter|ShowPrefix);
-
-  //
-  //  Metadata Button
-  //
-  feed_metadata_button=new QPushButton(this);
-  feed_metadata_button->setGeometry(615,460,150,50);
-  feed_metadata_button->setDefault(true);
-  feed_metadata_button->setFont(font);
-  feed_metadata_button->setText(tr("&Define Auxiliary\nMetadata Fields"));
-  connect(feed_metadata_button,SIGNAL(clicked()),this,SLOT(editData()));
+  feed_item_xml_label->setFont(labelFont());
+  feed_item_xml_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   //  Ok Button
@@ -429,7 +403,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   QPushButton *ok_button=new QPushButton(this);
   ok_button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   ok_button->setDefault(true);
-  ok_button->setFont(font);
+  ok_button->setFont(buttonFont());
   ok_button->setText(tr("&OK"));
   connect(ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -437,9 +411,9 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent)
   //  Cancel Button
   //
   QPushButton *cancel_button=new QPushButton(this);
-  cancel_button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
-			     80,50);
-  cancel_button->setFont(font);
+  cancel_button->
+    setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
+  cancel_button->setFont(buttonFont());
   cancel_button->setText(tr("&Cancel"));
   connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
@@ -505,9 +479,9 @@ QSizePolicy EditFeed::sizePolicy() const
 
 void EditFeed::purgeUrlChangedData(const QString &str)
 {
-  QUrl url(str);
+  Q3Url url(str);
   QString protocol=url.protocol();
-  if(((protocol=="ftp")||(protocol=="smb"))&&
+  if(((protocol=="ftp")||(protocol=="sftp"))&&
      (!feed_redirect_check->isChecked())) {
     feed_purge_username_label->setEnabled(true);
     feed_purge_username_edit->setEnabled(true);
@@ -533,12 +507,10 @@ void EditFeed::purgeUsernameChangedData(const QString &username)
 
 void EditFeed::setFormatData()
 {
-  RDStation *station=new RDStation(admin_config->stationName());
   RDExportSettingsDialog *dialog=
-    new RDExportSettingsDialog(&feed_settings,station,this);
+    new RDExportSettingsDialog(&feed_settings,this);
   dialog->exec();
   delete dialog;
-  delete station;
   feed_format_edit->setText(feed_settings.description());
 }
 
@@ -550,15 +522,6 @@ void EditFeed::normalizeCheckData(bool state)
   feed_normalize_unit_label->setEnabled(state);
 }
 
-
-void EditFeed::editData()
-{
-  ListAuxFields *lf=new ListAuxFields(feed_feed->id(),this);
-  lf->exec();
-  delete lf;
-}
-
-
 void EditFeed::redirectToggledData(bool state)
 {
   if(state) {
@@ -630,18 +593,6 @@ void EditFeed::cancelData()
 }
 
 
-void EditFeed::paintEvent(QPaintEvent *e)
-{
-  QPainter *p=new QPainter(this);
-  p->moveTo(10,50);
-  p->lineTo(sizeHint().width()/2,50);
-  p->lineTo(sizeHint().width()/2,272);
-  p->lineTo(10,272);
-  p->lineTo(10,50);
-  delete p;
-}
-
-
 void EditFeed::RedirectChanged(bool state)
 {
   feed_redirect_label->setEnabled(state);
@@ -670,7 +621,6 @@ void EditFeed::RedirectChanged(bool state)
   feed_extension_edit->setDisabled(state);
   feed_castorder_box->setDisabled(state);
   feed_format_button->setDisabled(state);
-  feed_metadata_button->setDisabled(state);
   feed_channel_title_label->setDisabled(state);
   feed_channel_category_label->setDisabled(state);
   feed_channel_link_label->setDisabled(state);
@@ -690,7 +640,7 @@ void EditFeed::RedirectChanged(bool state)
   feed_normalize_unit_label->setDisabled(state);
   feed_castorder_label->setDisabled(state);
   feed_extension_label->setDisabled(state);
-  feed_channel_section_label->setDisabled(state);
+  feed_channel_section_groupbox->setDisabled(state);
   feed_header_xml_label->setDisabled(state);
   feed_channel_xml_label->setDisabled(state);
   feed_item_xml_label->setDisabled(state);
