@@ -2,9 +2,7 @@
 //
 // List Rivendell Groups
 //
-//   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: list_groups.cpp,v 1.27.6.1 2013/11/13 23:36:34 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,104 +20,86 @@
 
 #include <math.h>
 
-#include <qdialog.h>
-#include <qstring.h>
-#include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qlabel.h>
-#include <qpainter.h>
-#include <qevent.h>
 #include <qmessagebox.h>
-#include <qbuttongroup.h>
-#include <rddb.h>
 
+#include <rdapplication.h>
 #include <rdcart.h>
-#include <rdtextfile.h>
+#include <rddb.h>
 #include <rdescape_string.h>
+#include <rdreport.h>
+#include <rdtextfile.h>
 
-#include <globals.h>
-#include <list_groups.h>
-#include <edit_group.h>
-#include <add_group.h>
-#include <rename_group.h>
+#include "add_group.h"
+#include "globals.h"
+#include "edit_group.h"
+#include "list_groups.h"
+#include "rename_group.h"
 
-
-ListGroups::ListGroups(QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+ListGroups::ListGroups(QWidget *parent)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
+  setMinimumSize(sizeHint());
 
-  setCaption(tr("Rivendell Group List"));
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-  QFont list_font=QFont("Helvetica",12,QFont::Normal);
-  list_font.setPixelSize(12);
-  QFont small_font=QFont("Helvetica",10,QFont::Normal);
-  small_font.setPixelSize(10);
+  setWindowTitle("RDAdmin - "+tr("Rivendell Group List"));
 
   //
   //  Add Button
   //
-  list_add_button=new QPushButton(this,"list_add_button");
-  list_add_button->setFont(font);
+  list_add_button=new QPushButton(this);
+  list_add_button->setFont(buttonFont());
   list_add_button->setText(tr("&Add"));
   connect(list_add_button,SIGNAL(clicked()),this,SLOT(addData()));
 
   //
   //  Edit Button
   //
-  list_edit_button=new QPushButton(this,"list_edit_button");
-  list_edit_button->setFont(font);
+  list_edit_button=new QPushButton(this);
+  list_edit_button->setFont(buttonFont());
   list_edit_button->setText(tr("&Edit"));
   connect(list_edit_button,SIGNAL(clicked()),this,SLOT(editData()));
 
   //
   //  Rename Button
   //
-  list_rename_button=new QPushButton(this,"list_rename_button");
-  list_rename_button->setFont(font);
+  list_rename_button=new QPushButton(this);
+  list_rename_button->setFont(buttonFont());
   list_rename_button->setText(tr("&Rename"));
   connect(list_rename_button,SIGNAL(clicked()),this,SLOT(renameData()));
 
   //
   //  Delete Button
   //
-  list_delete_button=new QPushButton(this,"list_delete_button");
-  list_delete_button->setFont(font);
+  list_delete_button=new QPushButton(this);
+  list_delete_button->setFont(buttonFont());
   list_delete_button->setText(tr("&Delete"));
   connect(list_delete_button,SIGNAL(clicked()),this,SLOT(deleteData()));
 
   //
   //  Report Button
   //
-  list_report_button=new QPushButton(this,"list_report_button");
-  list_report_button->setFont(font);
+  list_report_button=new QPushButton(this);
+  list_report_button->setFont(buttonFont());
   list_report_button->setText(tr("Generate\n&Report"));
   connect(list_report_button,SIGNAL(clicked()),this,SLOT(reportData()));
 
   //
   //  Close Button
   //
-  list_close_button=new QPushButton(this,"list_close_button");
+  list_close_button=new QPushButton(this);
   list_close_button->setDefault(true);
-  list_close_button->setFont(font);
+  list_close_button->setFont(buttonFont());
   list_close_button->setText(tr("&Close"));
   connect(list_close_button,SIGNAL(clicked()),this,SLOT(closeData()));
 
   //
   // Group List
   //
-  list_groups_view=new RDListView(this,"list_groups_view");
-  list_groups_view->setFont(list_font);
+  list_groups_view=new RDListView(this);
   list_groups_view->setAllColumnsShowFocus(true);
   list_groups_view->addColumn(tr("NAME"));
   list_groups_view->addColumn(tr("DESCRIPTION"));
@@ -137,14 +117,13 @@ ListGroups::ListGroups(QWidget *parent,const char *name)
   list_groups_view->setColumnAlignment(7,Qt::AlignHCenter);
   list_groups_view->addColumn(tr("NOW & NEXT"));
   list_groups_view->setColumnAlignment(8,Qt::AlignHCenter);
-  QLabel *list_box_label=new QLabel(list_groups_view,tr("&Groups:"),
-				    this,"list_box_label");
-  list_box_label->setFont(font);
+  QLabel *list_box_label=new QLabel(list_groups_view,tr("&Groups:"),this);
+  list_box_label->setFont(labelFont());
   list_box_label->setGeometry(14,11,85,19);
   connect(list_groups_view,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
+	  SIGNAL(doubleClicked(Q3ListViewItem *,const QPoint &,int)),
 	  this,
-	  SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
+	  SLOT(doubleClickedData(Q3ListViewItem *,const QPoint &,int)));
 
   RefreshList();
 }
@@ -171,7 +150,7 @@ void ListGroups::addData()
 {
   QString group;
 
-  AddGroup *add_group=new AddGroup(&group,this,"add_group");
+  AddGroup *add_group=new AddGroup(&group,this);
   if(add_group->exec()<0) {
     delete add_group;
     return;
@@ -193,7 +172,7 @@ void ListGroups::editData()
   if(item==NULL) {
     return;
   }
-  EditGroup *edit_group=new EditGroup(item->text(0),this,"edit_group");
+  EditGroup *edit_group=new EditGroup(item->text(0),this);
   edit_group->exec();
   delete edit_group;
   edit_group=NULL;
@@ -209,7 +188,7 @@ void ListGroups::renameData()
   }
 
   QString groupname=item->text(0);
-  RenameGroup *rename_group=new RenameGroup(groupname,this,"rename_group");
+  RenameGroup *rename_group=new RenameGroup(groupname,this);
   rename_group->exec();
   delete rename_group;
   rename_group=NULL;
@@ -228,33 +207,27 @@ void ListGroups::deleteData()
   RDSqlQuery *q;
   QString warning;
   int carts=0;
-  QString str;
 
   QString groupname=item->text(0);
   if(groupname.isEmpty()) {
     return;
   }
-  sql=QString().sprintf("select NUMBER from CART where GROUP_NAME=\"%s\"",
-			(const char *)groupname);
+  sql=QString("select NUMBER from CART where ")+
+    "GROUP_NAME=\""+RDEscapeString(groupname)+"\"";
   q=new RDSqlQuery(sql);
   if((carts=q->size())>0) {
-    str=QString(tr("member carts will be deleted along with group"));
-    warning=QString().
-      sprintf("%d %s %s!\n",
-	      carts,(const char *)str,(const char *)groupname);
+    warning=QString().sprintf("%d ",carts)+tr("member carts will be deleted along with group")+" \""+groupname+"\"!";
   }
-  str=QString(tr("Are you sure you want to delete group"));
-  warning+=QString().sprintf("%s %s?",(const char *)str,
-			     (const char *)groupname);
+  warning+=tr("Are you sure you want to delete group")+" \""+groupname+"\"?";
   switch(QMessageBox::warning(this,tr("Delete Group"),warning,
 			      QMessageBox::Yes,QMessageBox::No)) {
-      case QMessageBox::No:
-      case QMessageBox::NoButton:
-	delete q;
-	return;
+  case QMessageBox::No:
+  case QMessageBox::NoButton:
+    delete q;
+    return;
 
-      default:
-	break;
+  default:
+    break;
   }
 
   //
@@ -263,7 +236,7 @@ void ListGroups::deleteData()
   RDCart *cart;
   while(q->next()) {
     cart=new RDCart(q->value(0).toUInt());
-    cart->remove(admin_station,admin_user,admin_config);
+    cart->remove(rda->station(),rda->user(),rda->config());
     delete cart;
   }
   delete q;
@@ -271,32 +244,32 @@ void ListGroups::deleteData()
   //
   // Delete Member Audio Perms
   //
-  sql=QString().sprintf("delete from AUDIO_PERMS where GROUP_NAME=\"%s\"",
-			(const char *)RDEscapeString(groupname));
+  sql=QString("delete from AUDIO_PERMS where ")+
+    "GROUP_NAME=\""+RDEscapeString(groupname)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
   
   //
   // Delete Member User Perms
   //
-  sql=QString().sprintf("delete from USER_PERMS where GROUP_NAME=\"%s\"",
-			(const char *)RDEscapeString(groupname));
+  sql=QString("delete from USER_PERMS where ")+
+    "GROUP_NAME=\""+RDEscapeString(groupname)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
   
   //
   // Delete Replicator Map Records
   //
-  sql=QString().sprintf("delete from REPLICATOR_MAP where GROUP_NAME=\"%s\"",
-			(const char *)RDEscapeString(groupname));
+  sql=QString("delete from REPLICATOR_MAP where ")+
+    "GROUP_NAME=\""+RDEscapeString(groupname)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
   
   //
   // Delete from Group List
   //
-  sql=QString().sprintf("delete from GROUPS where NAME=\"%s\"",
-			(const char *)RDEscapeString(groupname));
+  sql=QString("delete from GROUPS where ")+
+    "NAME=\""+RDEscapeString(groupname)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
   item->setSelected(false);
@@ -313,31 +286,37 @@ void ListGroups::reportData()
   //
   // Generate Header
   //
-  report="                                  Rivendell Group Report\n";
-  report+=QString().sprintf("Generated: %s\n",
-			    (const char *)QDateTime(QDate::currentDate(),
-						    QTime::currentTime()).
-			    toString("MM/dd/yyyy - hh:mm:ss"));
+  report=RDReport::center("Rivendell Group Report",94)+"\n";
+  report+=QString("Generated: ")+
+    QDateTime::currentDateTime().toString("MM/dd/yyyy - hh:mm:ss")+"\n";
   report+="\n";
   report+="-Name----- -Description-------------------------------- -Cart Range---- Enf DefType Mus Tfc N&N\n";
 
   //
   // Generate Body
   //
-  sql="select NAME,DESCRIPTION,DEFAULT_LOW_CART,DEFAULT_HIGH_CART,\
-       ENFORCE_CART_RANGE,DEFAULT_CART_TYPE,REPORT_MUS,REPORT_TFC,\
-       ENABLE_NOW_NEXT from GROUPS order by NAME";
+  sql=QString("select ")+
+    "NAME,"+                // 00
+    "DESCRIPTION,"+         // 01
+    "DEFAULT_LOW_CART,"+    // 02
+    "DEFAULT_HIGH_CART,"+   // 03
+    "ENFORCE_CART_RANGE,"+  // 04
+    "DEFAULT_CART_TYPE,"+   // 05
+    "REPORT_MUS,"+          // 06
+    "REPORT_TFC,"+          // 07
+    "ENABLE_NOW_NEXT "+     // 08
+    "from GROUPS order by NAME";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     //
     // Group Name
     //
-    report+=QString().sprintf("%-10s ",(const char *)q->value(0).toString());
+    report+=RDReport::leftJustify(q->value(0).toString(),10)+" ";
 
     //
     // Group Description
     //
-    report+=QString().sprintf("%-44s ",(const char *)q->value(1).toString());
+    report+=RDReport::leftJustify(q->value(1).toString(),44)+" ";
 
     //
     // Cart Range
@@ -353,39 +332,39 @@ void ListGroups::reportData()
     //
     // Enforce Range
     //
-    report+=QString().sprintf(" %s  ",(const char *)q->value(4).toString());
+    report+=QString(" ")+q->value(4).toString()+"  ";
 
     //
     // Default Cart Type
     //
     switch((RDCart::Type)q->value(5).toInt()) {
-	case RDCart::Audio:
-	  report+="Audio   ";
-	  break;
+    case RDCart::Audio:
+      report+="Audio   ";
+      break;
 
-	case RDCart::Macro:
-	  report+="Macro   ";
-	  break;
+    case RDCart::Macro:
+      report+="Macro   ";
+      break;
 
-	default:
-	  report+="Unknown ";
-	  break;
+    default:
+      report+="Unknown ";
+      break;
     }
 
     //
     // Music Reports
     //
-    report+=QString().sprintf(" %s  ",(const char *)q->value(6).toString());
+    report+=QString(" ")+q->value(6).toString()+"  ";
     
     //
     // Traffic Reports
     //
-    report+=QString().sprintf(" %s  ",(const char *)q->value(7).toString());
+    report+=QString(" ")+q->value(7).toString()+"  ";
     
     //
     // Now & Next
     //
-    report+=QString().sprintf(" %s",(const char *)q->value(8).toString());
+    report+=QString(" ")+q->value(8).toString();
 
     //
     // End of Line
@@ -401,7 +380,7 @@ void ListGroups::reportData()
 }
 
 
-void ListGroups::doubleClickedData(QListViewItem *item,const QPoint &pt,
+void ListGroups::doubleClickedData(Q3ListViewItem *item,const QPoint &pt,
 				   int col)
 {
   editData();
@@ -433,10 +412,19 @@ void ListGroups::RefreshList()
   RDListViewItem *item;
 
   list_groups_view->clear();
-  q=new RDSqlQuery("select NAME,DESCRIPTION,DEFAULT_LOW_CART,DEFAULT_HIGH_CART,\
-                   ENFORCE_CART_RANGE,DEFAULT_CART_TYPE,REPORT_TFC,REPORT_MUS,\
-                   ENABLE_NOW_NEXT,COLOR from GROUPS",
-		  0);
+  sql=QString("select ")+
+    "NAME,"+                // 00
+    "DESCRIPTION,"+         // 01
+    "DEFAULT_LOW_CART,"+    // 02
+    "DEFAULT_HIGH_CART,"+   // 03
+    "ENFORCE_CART_RANGE,"+  // 04
+    "DEFAULT_CART_TYPE,"+   // 05
+    "REPORT_TFC,"+          // 06
+    "REPORT_MUS,"+          // 07
+    "ENABLE_NOW_NEXT,"+     // 08
+    "COLOR "+               // 09
+    "from GROUPS";
+  q=new RDSqlQuery(sql);
   while (q->next()) {
     item=new RDListViewItem(list_groups_view);
     WriteItem(item,q);
@@ -450,11 +438,19 @@ void ListGroups::RefreshItem(RDListViewItem *item)
   QString sql;
   RDSqlQuery *q;
 
-  sql=QString().sprintf("select NAME,DESCRIPTION,DEFAULT_LOW_CART,\
-                         DEFAULT_HIGH_CART,ENFORCE_CART_RANGE,\
-                         DEFAULT_CART_TYPE,REPORT_TFC,REPORT_MUS,\
-                         ENABLE_NOW_NEXT,COLOR from GROUPS where NAME=\"%s\"",
-			(const char *)item->text(0));
+  sql=QString("select ")+
+    "NAME,"+                // 00
+    "DESCRIPTION,"+         // 01
+    "DEFAULT_LOW_CART,"+    // 02
+    "DEFAULT_HIGH_CART,"+   // 03
+    "ENFORCE_CART_RANGE,"+  // 04
+    "DEFAULT_CART_TYPE,"+   // 05
+    "REPORT_TFC,"+          // 06
+    "REPORT_MUS,"+          // 07
+    "ENABLE_NOW_NEXT,"+     // 08
+    "COLOR "+               // 09
+    "from GROUPS where "+
+    "NAME=\""+RDEscapeString(item->text(0))+"\"";
   q=new RDSqlQuery(sql);
   if(q->next()) {
     WriteItem(item,q);
@@ -478,17 +474,17 @@ void ListGroups::WriteItem(RDListViewItem *item,RDSqlQuery *q)
   }
   item->setText(4,q->value(4).toString());
   switch((RDCart::Type)q->value(5).toUInt()) {
-      case RDCart::Audio:
-	item->setText(5,"Audio");
-	break;
+  case RDCart::Audio:
+    item->setText(5,"Audio");
+    break;
 	
-      case RDCart::Macro:
-	item->setText(5,"Macro");
-	break;
+  case RDCart::Macro:
+    item->setText(5,"Macro");
+    break;
 	
-      default:	
-	item->setText(5,"[none]");
-	break;
+  default:	
+    item->setText(5,"[none]");
+    break;
   }
   item->setText(6,q->value(6).toString());
   item->setText(7,q->value(7).toString());
