@@ -2,9 +2,7 @@
 //
 // List Rivendell Users
 //
-//   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: list_users.cpp,v 1.21.2.1 2008/12/09 15:45:22 fredg Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,25 +20,15 @@
 
 #include <math.h>
 
-#include <qdialog.h>
-#include <qstring.h>
-#include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qlabel.h>
-#include <qpainter.h>
-#include <qevent.h>
 #include <qmessagebox.h>
-#include <qbuttongroup.h>
-#include <rddb.h>
 
 #include <rdcart.h>
-#include <rdtextfile.h>
 #include <rdescape_string.h>
+#include <rdtextfile.h>
 
-#include <list_users.h>
-#include <edit_user.h>
-#include <add_user.h>
+#include "add_user.h"
+#include "edit_user.h"
+#include "list_users.h"
 
 //
 // Icons
@@ -48,9 +36,10 @@
 #include "../icons/admin.xpm"
 #include "../icons/user.xpm"
 
-ListUsers::ListUsers(const QString &admin_name,QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+ListUsers::ListUsers(const QString &admin_name,QWidget *parent)
+  : RDDialog(parent)
 {
+  setModal(true);
   list_admin_name=admin_name;
 
   //
@@ -59,17 +48,7 @@ ListUsers::ListUsers(const QString &admin_name,QWidget *parent,const char *name)
   setMinimumWidth(sizeHint().width());
   setMinimumHeight(sizeHint().height());
 
-  setCaption(tr("Rivendell User List"));
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-  QFont list_font=QFont("Helvetica",12,QFont::Normal);
-  list_font.setPixelSize(12);
-  QFont small_font=QFont("Helvetica",10,QFont::Normal);
-  small_font.setPixelSize(10);
+  setWindowTitle("RDAdmin - "+tr("Rivendell User List"));
 
   //
   // Create Icons
@@ -80,55 +59,53 @@ ListUsers::ListUsers(const QString &admin_name,QWidget *parent,const char *name)
   //
   //  Add Button
   //
-  list_add_button=new QPushButton(this,"list_add_button");
-  list_add_button->setFont(font);
+  list_add_button=new QPushButton(this);
+  list_add_button->setFont(buttonFont());
   list_add_button->setText(tr("&Add"));
   connect(list_add_button,SIGNAL(clicked()),this,SLOT(addData()));
 
   //
   //  Edit Button
   //
-  list_edit_button=new QPushButton(this,"list_edit_button");
-  list_edit_button->setFont(font);
+  list_edit_button=new QPushButton(this);
+  list_edit_button->setFont(buttonFont());
   list_edit_button->setText(tr("&Edit"));
   connect(list_edit_button,SIGNAL(clicked()),this,SLOT(editData()));
 
   //
   //  Delete Button
   //
-  list_delete_button=new QPushButton(this,"list_delete_button");
-  list_delete_button->setFont(font);
+  list_delete_button=new QPushButton(this);
+  list_delete_button->setFont(buttonFont());
   list_delete_button->setText(tr("&Delete"));
   connect(list_delete_button,SIGNAL(clicked()),this,SLOT(deleteData()));
 
   //
   //  Close Button
   //
-  list_close_button=new QPushButton(this,"list_close_button");
+  list_close_button=new QPushButton(this);
   list_close_button->setDefault(true);
-  list_close_button->setFont(font);
+  list_close_button->setFont(buttonFont());
   list_close_button->setText(tr("&Close"));
   connect(list_close_button,SIGNAL(clicked()),this,SLOT(closeData()));
 
   //
   // User List
   //
-  list_users_view=new RDListView(this,"list_users_view");
-  list_users_view->setFont(list_font);
+  list_users_view=new RDListView(this);
   list_users_view->setAllColumnsShowFocus(true);
   list_users_view->setItemMargin(5);
   list_users_view->addColumn("");
   list_users_view->addColumn(tr("USER NAME"));
   list_users_view->addColumn(tr("FULL NAME"));
   list_users_view->addColumn(tr("DESCRIPTION"));
-  QLabel *list_box_label=new QLabel(list_users_view,tr("&Users:"),
-				    this,"list_box_label");
-  list_box_label->setFont(font);
+  QLabel *list_box_label=new QLabel(list_users_view,tr("&Users:"),this);
+  list_box_label->setFont(labelFont());
   list_box_label->setGeometry(14,11,85,19);
   connect(list_users_view,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
+	  SIGNAL(doubleClicked(Q3ListViewItem *,const QPoint &,int)),
 	  this,
-	  SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
+	  SLOT(doubleClickedData(Q3ListViewItem *,const QPoint &,int)));
 
   RefreshList();
 }
@@ -155,7 +132,7 @@ void ListUsers::addData()
 {
   QString user;
 
-  AddUser *add_user=new AddUser(&user,this,"add_user");
+  AddUser *add_user=new AddUser(&user,this);
   if(add_user->exec()<0) {
     delete add_user;
     return;
@@ -177,7 +154,7 @@ void ListUsers::editData()
   if(item==NULL) {
     return;
   }
-  EditUser *edit_user=new EditUser(item->text(1),this,"edit_user");
+  EditUser *edit_user=new EditUser(item->text(1),this);
   if(edit_user->exec()==0) {
     RefreshItem(item);
   }
@@ -208,8 +185,8 @@ void ListUsers::deleteData()
   //
   // Check for default user assignments
   //
-  sql=QString().sprintf("select NAME from STATIONS where DEFAULT_NAME=\"%s\"",
-			(const char *)username);
+  sql=QString("select NAME from STATIONS where ")+
+    "DEFAULT_NAME=\""+RDEscapeString(username)+"\"";
   q=new RDSqlQuery(sql);
   if(q->size()>0) {
     str=tr("This user is set as the default user for the following hosts:\n\n");
@@ -225,47 +202,46 @@ void ListUsers::deleteData()
   delete q;
 
   str=QString(tr("Are you sure you want to delete user"));
-  warning+=QString().sprintf("%s \"%s\"?",(const char *)str,
-			     (const char *)item->text(1));
-  switch(QMessageBox::warning(this,tr("Delete User"),warning,
+  warning+=str+" \""+item->text(1)+"\"?";
+  switch(QMessageBox::warning(this,"RDAdmin - "+tr("Delete User"),warning,
 			      QMessageBox::Yes,QMessageBox::No)) {
-      case QMessageBox::No:
-      case QMessageBox::NoButton:
-	return;
+  case QMessageBox::No:
+  case Qt::NoButton:
+    return;
 
-      default:
-	break;
+  default:
+    break;
   }
 
   //
   // Delete RSS Feed Perms
   //
-  sql=QString().sprintf("delete from FEED_PERMS where USER_NAME=\"%s\"",
-			(const char *)username);
+  sql=QString("delete from FEED_PERMS where ")+
+    "USER_NAME=\""+RDEscapeString(username)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
   
   //
   // Delete Member User Perms
   //
-  sql=QString().sprintf("delete from USER_PERMS where USER_NAME=\"%s\"",
-			(const char *)username);
+  sql=QString("delete from USER_PERMS where ")+
+    "USER_NAME=\""+RDEscapeString(username)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
   
   //
   // Delete from User List
   //
-  sql=QString().sprintf("delete from USERS where LOGIN_NAME=\"%s\"",
-			(const char *)username);
+  sql=QString("delete from USERS where ")+
+    "LOGIN_NAME=\""+RDEscapeString(username)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 
   //
   // Delete from Cached Web Connections
   //
-  sql=QString().sprintf("delete from WEB_CONNECTIONS where LOGIN_NAME=\"%s\"",
-			(const char *)username);
+  sql=QString("delete from WEB_CONNECTIONS where ")+
+    "LOGIN_NAME=\""+RDEscapeString(username)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 
@@ -274,7 +250,7 @@ void ListUsers::deleteData()
 }
 
 
-void ListUsers::doubleClickedData(QListViewItem *item,const QPoint &pt,
+void ListUsers::doubleClickedData(Q3ListViewItem *item,const QPoint &pt,
 				   int col)
 {
   editData();
@@ -327,9 +303,12 @@ void ListUsers::RefreshItem(RDListViewItem *item)
   QString sql;
   RDSqlQuery *q;
 
-  sql=QString().sprintf("select ADMIN_CONFIG_PRIV,FULL_NAME,DESCRIPTION \
-                         from USERS where LOGIN_NAME=\"%s\"",
-			(const char *)RDEscapeString(item->text(1)));
+  sql=QString("select ")+
+    "ADMIN_CONFIG_PRIV,"+  // 00
+    "FULL_NAME,"+          // 01
+    "DESCRIPTION "+        // 02
+    "from USERS where "+
+    "LOGIN_NAME=\""+RDEscapeString(item->text(1))+"\"";
   q=new RDSqlQuery(sql);
   if(q->first()) {
     if(q->value(0).toString()=="Y") {
