@@ -2,9 +2,7 @@
 //
 // Event Editor for RDAirPlay
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_event.h,v 1.25.8.2.2.1 2014/05/20 01:45:17 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,33 +21,22 @@
 #ifndef EDIT_EVENT_H
 #define EDIT_EVENT_H
 
-#include <qdialog.h>
-#include <qcombobox.h>
-#include <qlabel.h>
-#include <qdatetimeedit.h>
-#include <qradiobutton.h>
 #include <qbuttongroup.h>
 #include <qcheckbox.h>
-#include <qspinbox.h>
+#include <qcombobox.h>
+#include <qgroupbox.h>
+#include <qradiobutton.h>
 #include <qtextedit.h>
-#include <qtimer.h>
 
-#include <rdtransportbutton.h>
-#include <rdslider.h>
-#include <rdcae.h>
-#include <rdplay_deck.h>
-#include <rdmarker_edit.h>
-#include <rdpushbutton.h>
-#include <rdtimeedit.h>
 #include <rdcueedit.h>
+#include <rddialog.h>
+#include <rdlogplay.h>
 
-#include <log_play.h>
-
-class EditEvent : public QDialog
+class EditEvent : public RDDialog
 {
   Q_OBJECT
  public:
-  EditEvent(LogPlay *log,RDCae *cae,QWidget *parent=0,const char *name=0);
+  EditEvent(RDLogPlay *log,RDCae *cae,QWidget *parent=0);
   ~EditEvent();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -69,18 +56,18 @@ class EditEvent : public QDialog
   void closeEvent(QCloseEvent *e);
 
  private:
-  LogPlay *edit_log;
+  RDLogPlay *edit_log;
   RDLogLine *edit_logline;
   int edit_line;
   RDTimeEdit *edit_time_edit;
   bool edit_time_changed;
   QCheckBox *edit_timetype_box;
   QLabel *edit_timetype_label;
-  QButtonGroup *edit_grace_group;
+  QGroupBox *edit_grace_group;
+  QButtonGroup *edit_grace_bgroup;
   RDTimeEdit *edit_grace_edit;
-  QLabel *edit_time_label;
-  QComboBox *edit_transtype_box;
   QLabel *edit_transtype_label;
+  QComboBox *edit_transtype_box;
   QCheckBox *edit_overlap_box;
   QLabel *edit_overlap_label;
   RDCueEdit *edit_cue_edit;
