@@ -2,9 +2,7 @@
 //
 // The post counter widget for Rivendell
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: post_counter.cpp,v 1.22.6.1 2012/11/26 20:19:40 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,12 +21,14 @@
 #include <qpixmap.h>
 #include <qpainter.h>
 
-#include <post_counter.h>
-#include <colors.h>
-#include <globals.h>
+#include <rdapplication.h>
 
-PostCounter::PostCounter(QWidget *parent,const char *name)
-  : QPushButton(parent,name)
+#include "colors.h"
+#include "globals.h"
+#include "post_counter.h"
+
+PostCounter::PostCounter(QWidget *parent)
+  : RDPushButton(parent)
 {
   post_running=false;
   post_time_format="hh:mm:ss";
@@ -36,14 +36,6 @@ PostCounter::PostCounter(QWidget *parent,const char *name)
   post_offset=0;
   post_offset_valid=false;
 
-  //
-  // Generate Fonts
-  //
-  post_small_font=QFont("Helvetica",12,QFont::Normal);
-  post_small_font.setPixelSize(12);
-  post_large_font=QFont("Helvetica",26,QFont::Normal);
-  post_large_font.setPixelSize(26);
-
   //
   // Generate Palettes
   //
@@ -62,13 +54,13 @@ PostCounter::PostCounter(QWidget *parent,const char *name)
 void PostCounter::setTimeMode(RDAirPlayConf::TimeMode mode)
 {
   switch(mode) {
-      case RDAirPlayConf::TwentyFourHour:
-	post_time_format="hh:mm:ss";
-	break;
+  case RDAirPlayConf::TwentyFourHour:
+    post_time_format="hh:mm:ss";
+    break;
 
-      case RDAirPlayConf::TwelveHour:
-	post_time_format="h:mm:ss ap";
-	break;
+  case RDAirPlayConf::TwelveHour:
+    post_time_format="h:mm:ss ap";
+    break;
   }
   UpdateDisplay();
 }
@@ -127,11 +119,12 @@ void PostCounter::keyPressEvent(QKeyEvent *e)
 void PostCounter::UpdateDisplay()
 {
   QColor color=backgroundColor();
+  QColor system_button_text_color=palette().active().buttonText();
   QString str;
   QString point;
   QString state;
   QTime current_time=
-    QTime::currentTime().addMSecs(rdstation_conf->timeOffset());
+    QTime::currentTime().addMSecs(rda->station()->timeOffset());
   int offset=post_offset;
   if(!post_running) {
     offset-=current_time.msecsTo(post_set_time);
@@ -142,15 +135,13 @@ void PostCounter::UpdateDisplay()
 
     if(post_offset_valid) {
       if(offset<-POST_COUNTER_MARGIN) {
-	state=QString().sprintf("-%s",(const char *)
-				QTime().addMSecs(-offset).toString());
+	state="-"+QTime().addMSecs(-offset).toString();
 	setPalette(post_early_palette);
 	color=POSTPOINT_EARLY_COLOR;
       }
       else {
 	if(offset>POST_COUNTER_MARGIN) {
-	  state=QString().sprintf("+%s",(const char *)
-				  QTime().addMSecs(offset).toString());
+	  state="+"+QTime().addMSecs(offset).toString();
 	  setPalette(post_late_palette);
 	  color=POSTPOINT_LATE_COLOR;
 	}
@@ -160,6 +151,7 @@ void PostCounter::UpdateDisplay()
 	  color=POSTPOINT_ONTIME_COLOR;
 	}
       }
+      system_button_text_color=Qt::color1;
     }
     else {
       state="--------";
@@ -171,16 +163,15 @@ void PostCounter::UpdateDisplay()
     state="--------";
     setPalette(post_idle_palette);
   }
-  QPixmap pix(sizeHint().width(),sizeHint().height());
+  QPixmap pix(size().width()-2,size().height()-2);
   QPainter *p=new QPainter(&pix);
-  p->fillRect(0,0,sizeHint().width(),sizeHint().height(),color);
-  //  p->eraseRect(0,0,sizeHint().width(),sizeHint().height());
-  p->setPen(color1);
-  p->setFont(post_small_font);
-  p->drawText((sizeHint().width()-p->
+  p->fillRect(0,0,size().width()-2,size().height()-2,color);
+  p->setPen(QColor(system_button_text_color));
+  p->setFont(subLabelFont());
+  p->drawText((size().width()-2-p->
 	       fontMetrics().width(point))/2,22,point);
-  p->setFont(post_large_font);
-  p->drawText((sizeHint().width()-p->
+  p->setFont(bannerFont());
+  p->drawText((size().width()-2-p->
 	       fontMetrics().width(state))/2,48,state);
   p->end();
   delete p;
