@@ -2,7 +2,7 @@
 //
 // A Dedicated Cart Slot Utility for Rivendell.
 //
-//   (C) Copyright 2012,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2012-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,24 +21,8 @@
 #ifndef RDCARTSLOTS_H
 #define RDCARTSLOTS_H
 
-#include <vector>
-
-#include <qwidget.h>
-#include <qtimer.h>
-#include <qpixmap.h>
-
-#include <rdstereometer.h>
-#include <rdcae.h>
-#include <rdsystem.h>
-#include <rdmacro.h>
-#include <rdconfig.h>
-#include <rdevent_player.h>
 #include <rdcartslot.h>
-#include <rdcart_dialog.h>
-#include <rdslotdialog.h>
-#include <rdcueeditdialog.h>
-#include <rdlistsvcs.h>
-#include <rdairplay_conf.h>
+#include <rdwidget.h>
 
 //
 // Settings
@@ -47,15 +31,16 @@
 #define METER_INTERVAL 50
 #define RDCARTSLOTS_USAGE "\n"
 
-class MainWidget : public QWidget
+class MainWidget : public RDWidget
 {
   Q_OBJECT
  public:
-  MainWidget(QWidget *parent=0);
+  MainWidget(RDConfig *c,QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
 
  private slots:
+  void caeConnectedData(bool state);
   void userData();
   void rmlReceivedData(RDMacro *rml);
 
@@ -66,12 +51,6 @@ class MainWidget : public QWidget
  private:
   void RunLocalMacros(RDMacro *rml);
   void SetCaption();
-  RDConfig *panel_config;
-  RDCae *panel_cae;
-  RDRipc *panel_ripc;
-  RDUser *panel_user;
-  RDStation *panel_station;
-  RDSystem *panel_system;
   RDEventPlayer *panel_player;
   QPixmap *lib_rivendell_map;
   QString panel_filter;
@@ -82,7 +61,7 @@ class MainWidget : public QWidget
   RDSlotDialog *panel_slot_dialog;
   RDCueEditDialog *panel_cue_dialog;
   RDListSvcs *panel_svcs_dialog;
-  RDAirPlayConf *panel_airplay_conf;
+  //  RDAirPlayConf *panel_airplay_conf;
 };
 
 
