@@ -2,7 +2,7 @@
 //
 // List Rivendell Casts
 //
-//   (C) Copyright 2002-2007,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,20 +21,14 @@
 #ifndef LIST_CASTS_H
 #define LIST_CASTS_H
 
-#include <qdialog.h>
-#include <qpixmap.h>
-#include <qradiobutton.h>
-#include <qsqldatabase.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
 #include <qcheckbox.h>
-#include <qlabel.h>
 #include <qprogressdialog.h>
 
+#include <rddialog.h>
 #include <rdfeed.h>
 #include <rdlistviewitem.h>
 
-class ListCasts : public QDialog
+class ListCasts : public RDDialog
 {
   Q_OBJECT
  public:
@@ -49,7 +43,7 @@ class ListCasts : public QDialog
   void editData();
   void deleteData();
   void reportData();
-  void doubleClickedData(QListViewItem *item,const QPoint &pt,int col);
+  void doubleClickedData(Q3ListViewItem *item,const QPoint &pt,int col);
   void userChangedData();
   void filterChangedData(const QString &str);
   void notexpiredToggledData(bool state);
