@@ -2,9 +2,7 @@
 //
 // Select a Set of Dates for a Rivendell Podcast Report
 //
-//   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: pick_report_dates.h,v 1.3 2010/07/29 19:32:36 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,18 +21,15 @@
 #ifndef PICK_REPORT_DATE_H
 #define PICK_REPORT_DATE_H
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
-#include <qcombobox.h>
 #include <qdatetimeedit.h>
 
+#include <rddialog.h>
 
-class PickReportDates : public QDialog
+class PickReportDates : public RDDialog
 {
   Q_OBJECT
  public:
-  PickReportDates(unsigned feed_id,unsigned cast_id,
-		  QWidget *parent=0,const char *name=0);
+  PickReportDates(unsigned feed_id,unsigned cast_id,QWidget *parent=0);
   ~PickReportDates();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
