@@ -2,9 +2,7 @@
 //
 // Edit a Rivendell Upload Event
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_upload.cpp,v 1.22 2011/06/21 18:31:33 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,65 +18,43 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
-#include <qstring.h>
-#include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qpainter.h>
-#include <qevent.h>
+#include <qgroupbox.h>
 #include <qmessagebox.h>
-#include <qcheckbox.h>
+#include <qurl.h>
 
-#include <rddb.h>
-#include <rdurl.h>
-#include <rd.h>
 #include <rdcut_dialog.h>
 #include <rdcut_path.h>
-#include <rdtextvalidator.h>
-#include <rdexport_settings_dialog.h>
 #include <rdescape_string.h>
+#include <rdexport_settings_dialog.h>
+#include <rdtextvalidator.h>
 
-#include <edit_upload.h>
-#include <globals.h>
-
+#include "edit_upload.h"
+#include "globals.h"
 
 EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
-		       QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+		       QWidget *parent)
+  : RDDialog(parent)
 {
   QString sql;
   RDSqlQuery *q;
   QString temp;
 
-  //
-  // Fix the Window Size
-  //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
-
-  //
-  // Generate Fonts
-  //
-  QFont button_font=QFont("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
-  QFont label_font=QFont("Helvetica",12,QFont::Bold);
-  label_font.setPixelSize(12);
-  QFont day_font=QFont("Helvetica",10,QFont::Normal);
-  day_font.setPixelSize(10);
-
   edit_deck=NULL;
   edit_added_events=adds;
   edit_filter=filter;
 
-  setCaption(tr("Edit Upload"));
+  setWindowTitle("RDCatch - "+tr("Edit Upload"));
+
+  //
+  // Fix the Window Size
+  //
+  setMinimumSize(sizeHint());
+  setMaximumSize(sizeHint());
 
   //
   // Text Validator
   //
-  RDTextValidator *validator=new RDTextValidator(this,"validator");
+  RDTextValidator *validator=new RDTextValidator(this);
 
   //
   // The Recording Record
@@ -88,297 +64,275 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   //
   // Active Button
   //
-  edit_active_button=new QCheckBox(this,"edit_active_button");
+  edit_active_button=new QCheckBox(this);
   edit_active_button->setGeometry(10,11,20,20);
-  QLabel *label=new QLabel(edit_active_button,
-		   tr("Event Active"),this,"edit_active_label");
+  QLabel *label=new QLabel(edit_active_button,tr("Event Active"),this);
   label->setGeometry(30,11,125,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Station
   //
-  edit_station_box=new QComboBox(this,"edit_station_box");
+  edit_station_box=new QComboBox(this);
   edit_station_box->setGeometry(200,10,140,23);
   connect(edit_station_box,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(stationChangedData(const QString &)));
-  label=new QLabel(edit_station_box,tr("Location:"),this,
-				       "edit_station_label");
+  label=new QLabel(edit_station_box,tr("Location:"),this);
   label->setGeometry(125,10,70,23);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Start Time
   //
-  edit_starttime_edit=new QTimeEdit(this,"edit_starttime_edit");
+  edit_starttime_edit=new QTimeEdit(this);
   edit_starttime_edit->setGeometry(sizeHint().width()-90,12,80,20);
-  label=new QLabel(edit_starttime_edit,
-		   tr("Start Time:"),this,"edit_starttime_label");
+  edit_starttime_edit->setDisplayFormat("hh:mm:ss");
+  label=new QLabel(edit_starttime_edit,tr("Start Time:"),this);
   label->setGeometry(sizeHint().width()-175,12,80,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // RSS Feed
   //
-  edit_feed_box=new QComboBox(this,"edit_feed_box");
+  edit_feed_box=new QComboBox(this);
   edit_feed_box->setGeometry(115,43,100,20);
   edit_feed_box->insertItem(tr("[none]"));
-  label=new QLabel(edit_feed_box,
-		   tr("RSS Feed:"),this,"edit_feed_label");
+  label=new QLabel(edit_feed_box,tr("RSS Feed:"),this);
   label->setGeometry(10,43,100,19);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Source
   //
-  edit_destination_edit=new QLineEdit(this,"edit_destination_edit");
+  edit_destination_edit=new QLineEdit(this);
   edit_destination_edit->setGeometry(115,70,sizeHint().width()-195,20);
   edit_destination_edit->setReadOnly(true);
-  label=new QLabel(edit_destination_edit,
-		   tr("Source:"),this,"edit_destination_label");
+  label=new QLabel(edit_destination_edit,tr("Source:"),this);
   label->setGeometry(10,70,100,19);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
-  QPushButton *button=new QPushButton(this,"destination_button");
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
+  QPushButton *button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-70,68,60,24);
-  button->setFont(day_font);
+  button->setFont(subButtonFont());
   button->setText(tr("&Select"));
   connect(button,SIGNAL(clicked()),this,SLOT(selectCartData()));
 
   //
   // Description
   //
-  edit_description_edit=new QLineEdit(this,"edit_description_edit");
+  edit_description_edit=new QLineEdit(this);
   edit_description_edit->setGeometry(115,97,sizeHint().width()-125,20);
   edit_description_edit->setValidator(validator);
-  label=new QLabel(edit_description_edit,
-		   tr("Description:"),this,"edit_description_label");
+  label=new QLabel(edit_description_edit,tr("Description:"),this);
   label->setGeometry(10,97,100,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Url
   //
-  edit_url_edit=new QLineEdit(this,"edit_url_edit");
+  edit_url_edit=new QLineEdit(this);
   edit_url_edit->setGeometry(115,124,sizeHint().width()-125,20);
   edit_url_edit->setMaxLength(255);
   edit_url_edit->setValidator(validator);
   connect(edit_url_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(urlChangedData(const QString &)));
-  label=new QLabel(edit_url_edit,tr("Url:"),this,"edit_url_label");
+  label=new QLabel(edit_url_edit,tr("Url:"),this);
   label->setGeometry(10,124,100,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Username
   //
-  edit_username_edit=new QLineEdit(this,"edit_username_edit");
+  edit_username_edit=new QLineEdit(this);
   edit_username_edit->setGeometry(115,151,150,20);
   edit_username_edit->setMaxLength(64);
   edit_username_edit->setValidator(validator);
-  edit_username_label=new QLabel(edit_username_edit,
-		   tr("Username:"),this,"edit_username_label");
+  edit_username_label=new QLabel(edit_username_edit,tr("Username:"),this);
   edit_username_label->setGeometry(10,151,100,20);
-  edit_username_label->setFont(label_font);
-  edit_username_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  edit_username_label->setFont(labelFont());
+  edit_username_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Password
   //
-  edit_password_edit=new QLineEdit(this,"edit_password_edit");
+  edit_password_edit=new QLineEdit(this);
   edit_password_edit->setGeometry(360,151,sizeHint().width()-370,20);
   edit_password_edit->setEchoMode(QLineEdit::Password);
   edit_password_edit->setMaxLength(64);
   edit_username_edit->setValidator(validator);
-  edit_password_label=new QLabel(edit_password_edit,
-		   tr("Password:"),this,"edit_password_label");
+  edit_password_label=new QLabel(edit_password_edit,tr("Password:"),this);
   edit_password_label->setGeometry(275,151,80,20);
-  edit_password_label->setFont(label_font);
-  edit_password_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  edit_password_label->setFont(labelFont());
+  edit_password_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Audio Format
   //
-  edit_format_edit=new QLineEdit(this,"edit_format_edit");
+  edit_format_edit=new QLineEdit(this);
   edit_format_edit->setGeometry(115,178,sizeHint().width()-195,20);
   edit_format_edit->setReadOnly(true);
-  label=new QLabel(edit_format_edit,
-		   tr("Export Format:"),this,"edit_format_label");
+  label=new QLabel(edit_format_edit,tr("Export Format:"),this);
   label->setGeometry(5,178,105,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
-  button=new QPushButton(this,"format_button");
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
+  button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-70,176,60,24);
-  button->setFont(day_font);
+  button->setFont(subButtonFont());
   button->setText(tr("S&et"));
   connect(button,SIGNAL(clicked()),this,SLOT(setFormatData()));
 
   //
   // Normalize Check Box
   //
-  edit_normalize_box=new QCheckBox(this,"edit_normalize_box");
+  edit_normalize_box=new QCheckBox(this);
   edit_normalize_box->setGeometry(115,208,15,15);
   edit_normalize_box->setChecked(true);
-  label=new QLabel(edit_normalize_box,tr("Normalize"),
-		   this,"normalize_check_label");
+  label=new QLabel(edit_normalize_box,tr("Normalize"),this);
   label->setGeometry(135,206,83,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignLeft|AlignVCenter);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
   connect(edit_normalize_box,SIGNAL(toggled(bool)),
 	  this,SLOT(normalizeCheckData(bool)));
 
   //
   // Normalize Level
   //
-  edit_normalize_spin=new QSpinBox(this,"edit_normalize_spin");
+  edit_normalize_spin=new QSpinBox(this);
   edit_normalize_spin->setGeometry(265,206,40,20);
   edit_normalize_spin->setRange(-30,0);
-  edit_normalize_label=new QLabel(edit_normalize_spin,tr("Level:"),
-				 this,"normalize_spin_label");
+  edit_normalize_label=new QLabel(edit_normalize_spin,tr("Level:"),this);
   edit_normalize_label->setGeometry(215,206,45,20);
-  edit_normalize_label->setFont(label_font);
-  edit_normalize_label->setAlignment(AlignRight|AlignVCenter);
-  edit_normalize_unit=new QLabel(tr("dBFS"),this,"normalize_unit_label");
+  edit_normalize_label->setFont(labelFont());
+  edit_normalize_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
+  edit_normalize_unit=new QLabel(tr("dBFS"),this);
   edit_normalize_unit->setGeometry(310,206,40,20);
-  edit_normalize_unit->setFont(label_font);
-  edit_normalize_unit->setAlignment(AlignLeft|AlignVCenter);
+  edit_normalize_unit->setFont(labelFont());
+  edit_normalize_unit->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Export Metadata Box
   //
-  edit_metadata_box=new QCheckBox(this,"edit_metadata_box");
+  edit_metadata_box=new QCheckBox(this);
   edit_metadata_box->setGeometry(115,231,15,15);
-  label=new QLabel(edit_metadata_box,tr("Export Library Metadata"),
-		   this,"metadata_check_label");
+  label=new QLabel(edit_metadata_box,tr("Export Library Metadata"),this);
   label->setGeometry(135,231,160,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignLeft|AlignVCenter);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Button Label
   //
-  label=new QLabel(tr("Active Days"),this,"active_days_label");
-  label->setGeometry(47,263,90,19);
-  label->setFont(label_font);
-  label->setAlignment(AlignHCenter|ShowPrefix);
+  QGroupBox *groupbox=new QGroupBox(tr("Active Days"),this);
+  groupbox->setFont(labelFont());
+  groupbox->setGeometry(10,266,sizeHint().width()-20,62);
 
   //
   // Monday Button
   //
-  edit_mon_button=new QCheckBox(this,"edit_mon_button");
+  edit_mon_button=new QCheckBox(this);
   edit_mon_button->setGeometry(20,282,20,20);
-  label=new QLabel(edit_mon_button,
-		   tr("Monday"),this,"edit_mon_label");
+  label=new QLabel(edit_mon_button,tr("Monday"),this);
   label->setGeometry(40,282,115,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Tuesday Button
   //
-  edit_tue_button=new QCheckBox(this,"edit_tue_button");
+  edit_tue_button=new QCheckBox(this);
   edit_tue_button->setGeometry(115,282,20,20);
-  label=new QLabel(edit_tue_button,
-		   tr("Tuesday"),this,"edit_tue_label");
+  label=new QLabel(edit_tue_button,tr("Tuesday"),this);
   label->setGeometry(135,282,115,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Wednesday Button
   //
-  edit_wed_button=new QCheckBox(this,"edit_wed_button");
+  edit_wed_button=new QCheckBox(this);
   edit_wed_button->setGeometry(215,282,20,20);
-  label=new QLabel(edit_wed_button,
-		   tr("Wednesday"),this,"edit_wed_label");
+  label=new QLabel(edit_wed_button,tr("Wednesday"),this);
   label->setGeometry(235,282,115,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Thursday Button
   //
-  edit_thu_button=new QCheckBox(this,"edit_thu_button");
+  edit_thu_button=new QCheckBox(this);
   edit_thu_button->setGeometry(335,282,20,20);
-  label=new QLabel(edit_thu_button,
-		   tr("Thursday"),this,"edit_thu_label");
+  label=new QLabel(edit_thu_button,tr("Thursday"),this);
   label->setGeometry(355,282,115,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Friday Button
   //
-  edit_fri_button=new QCheckBox(this,"edit_fri_button");
+  edit_fri_button=new QCheckBox(this);
   edit_fri_button->setGeometry(440,282,20,20);
-  label=new QLabel(edit_fri_button,
-		   tr("Friday"),this,"edit_fri_label");
+  label=new QLabel(edit_fri_button,tr("Friday"),this);
   label->setGeometry(460,282,40,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Saturday Button
   //
-  edit_sat_button=new QCheckBox(this,"edit_sat_button");
+  edit_sat_button=new QCheckBox(this);
   edit_sat_button->setGeometry(130,307,20,20);
-  label=new QLabel(edit_sat_button,
-		   tr("Saturday"),this,"edit_sat_label");
+  label=new QLabel(edit_sat_button,tr("Saturday"),this);
   label->setGeometry(150,307,60,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Sunday Button
   //
-  edit_sun_button=new QCheckBox(this,"edit_sun_button");
+  edit_sun_button=new QCheckBox(this);
   edit_sun_button->setGeometry(300,307,20,20);
-  label=new QLabel(edit_sun_button,
-		   tr("Sunday"),this,"edit_sun_label");
+  label=new QLabel(edit_sun_button,tr("Sunday"),this);
   label->setGeometry(320,307,60,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // OneShot Button
   //
-  edit_oneshot_box=new QCheckBox(this,"edit_oneshot_box");
+  edit_oneshot_box=new QCheckBox(this);
   edit_oneshot_box->setGeometry(20,342,15,15);
-  label=new QLabel(edit_oneshot_box,
-		   tr("Make OneShot"),this,"edit_oneshot_label");
-  label->setGeometry(40,343,115,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label=new QLabel(edit_oneshot_box,tr("Make OneShot"),this);
+  label->setGeometry(40,340,115,20);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Event Offset
   //
-  edit_eventoffset_spin=new QSpinBox(this,"edit_eventoffset_spin");
+  edit_eventoffset_spin=new QSpinBox(this);
   edit_eventoffset_spin->setGeometry(245,340,45,20);
   edit_eventoffset_spin->setRange(-30,30);
-  label=new QLabel(edit_eventoffset_spin,tr("Event Offset:"),
-		   this,"edit_eventoffset_label");
+  label=new QLabel(edit_eventoffset_spin,tr("Event Offset:"),this);
   label->setGeometry(140,340,100,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignVCenter|AlignRight);
-  label=new QLabel(edit_eventoffset_spin,tr("days"),
-		   this,"edit_eventoffset_unit");
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
+  label=new QLabel(edit_eventoffset_spin,tr("days"),this);
   label->setGeometry(295,335,40,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignVCenter|AlignLeft);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignLeft);
 
   //
   //  Save As Button
   //
-  button=new QPushButton(this,"saveas_button");
+  button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-300,sizeHint().height()-60,80,50);
-  button->setFont(button_font);
+  button->setFont(buttonFont());
   button->setText(tr("&Save As\nNew"));
   connect(button,SIGNAL(clicked()),this,SLOT(saveasData()));
   if(adds==NULL) {
@@ -388,19 +342,19 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   //
   //  Ok Button
   //
-  button=new QPushButton(this,"ok_button");
+  button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   button->setDefault(true);
-  button->setFont(button_font);
+  button->setFont(buttonFont());
   button->setText(tr("&OK"));
   connect(button,SIGNAL(clicked()),this,SLOT(okData()));
 
   //
   //  Cancel Button
   //
-  button=new QPushButton(this,"cancel_button");
+  button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
-  button->setFont(button_font);
+  button->setFont(buttonFont());
   button->setText(tr("&Cancel"));
   connect(button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
@@ -495,7 +449,8 @@ void EditUpload::urlChangedData(const QString &str)
 {
   QUrl url(str);
   QString protocol=url.protocol().lower();
-  if((protocol=="ftp")||(protocol=="file")) {
+  if((protocol=="ftp")||(protocol=="file")||
+     (protocol=="scp")||(protocol=="sftp")) {
     edit_username_label->setEnabled(true);
     edit_username_edit->setEnabled(true);
     edit_password_label->setEnabled(true);
@@ -514,16 +469,13 @@ void EditUpload::selectCartData()
 {
   QString str;
 
-  RDCutDialog *cut=new RDCutDialog(&edit_cutname,rdstation_conf,catch_system,
-				   edit_filter);
+  RDCutDialog *cut=new RDCutDialog(&edit_cutname,"RDCatch",edit_filter);
   switch(cut->exec()) {
-      case 0:
-	edit_description_edit->setText(RDCutPath(edit_cutname));
-	str=QString(tr("Cut"));
-	edit_destination_edit->
-	  setText(QString().sprintf("%s %s",(const char *)str,
-				    (const char *)edit_cutname));
-	break;
+  case 0:
+    edit_description_edit->setText(RDCutPath(edit_cutname));
+    str=QString(tr("Cut"));
+    edit_destination_edit->setText(tr("Cut")+" "+edit_cutname);
+    break;
   }
   delete cut;
 }
@@ -531,12 +483,10 @@ void EditUpload::selectCartData()
 
 void EditUpload::setFormatData()
 {
-  RDStation *station=new RDStation(edit_station_box->currentText());
   RDExportSettingsDialog *dialog=
-    new RDExportSettingsDialog(&edit_settings,station,this,"dialog");
+    new RDExportSettingsDialog(&edit_settings,this);
   dialog->exec();
   delete dialog;
-  delete station;
   edit_format_edit->setText(edit_settings.description());
 }
 
@@ -575,9 +525,10 @@ void EditUpload::okData()
     QMessageBox::warning(this,tr("Invalid URL"),tr("The URL is invalid!"));
     return;
   }
-  RDUrl url(edit_url_edit->text());
+  QUrl url(edit_url_edit->text());
   QString protocol=url.protocol();
-  if((protocol!="ftp")&&(protocol!="file")) {
+  if((protocol!="ftp")&&(protocol!="file")&&
+     (protocol!="scp")&&(protocol!="sftp")) {
     QMessageBox::warning(this,
 			 tr("Invalid URL"),tr("Unsupported URL protocol!"));
     return;
@@ -593,36 +544,27 @@ void EditUpload::okData()
     return;
   }
   Save();
-  done(0);
+  done(true);
 }
 
 
 void EditUpload::cancelData()
 {
-  done(-1);
-}
-
-
-void EditUpload::paintEvent(QPaintEvent *e)
-{
-  QPainter *p=new QPainter(this);
-  p->setPen(QColor(black));
-  p->drawRect(10,271,sizeHint().width()-20,62);
-  p->end();
+  done(false);
 }
 
 
 void EditUpload::keyPressEvent(QKeyEvent *e)
 {
   switch(e->key()) {
-      case Qt::Key_Escape:
-	e->accept();
-	cancelData();
-	break;
+  case Qt::Key_Escape:
+    e->accept();
+    cancelData();
+    break;
 
-      default:
-	QDialog::keyPressEvent(e);
-	break;
+  default:
+    QDialog::keyPressEvent(e);
+    break;
   }
 }
 
@@ -640,6 +582,7 @@ bool EditUpload::CheckFormat()
   RDStation *station=new RDStation(edit_station_box->currentText());
   switch(edit_settings.format()) {
       case RDSettings::Pcm16:
+      case RDSettings::Pcm24:
       case RDSettings::MpegL2:
       case RDSettings::MpegL2Wav:
 	res=true;
@@ -671,12 +614,9 @@ bool EditUpload::CheckFormat()
 
   QString sql;
   RDSqlQuery *q;
-  sql=QString().sprintf("select STATION_NAME from ENCODERS \
-                         where (NAME=\"%s\")&&(STATION_NAME=\"%s\")",
-			(const char *)RDEscapeString(edit_settings.
-						     formatName()),
-			(const char *)RDEscapeString(edit_station_box->
-						     currentText()));
+  sql=QString("select STATION_NAME from ENCODERS where ")+
+    "(NAME=\""+RDEscapeString(edit_settings.formatName())+"\")&&"+
+    "(STATION_NAME=\""+RDEscapeString(edit_station_box->currentText())+"\")";
   q=new RDSqlQuery(sql);
   if(q->first()) {
     res=true;
@@ -725,17 +665,13 @@ void EditUpload::Save()
 
 bool EditUpload::CheckEvent(bool include_myself)
 {
-  QString sql=
-    QString().sprintf("select ID from RECORDINGS \
-                       where (STATION_NAME=\"%s\")&&\
-                       (TYPE=%d)&&(START_TIME=\"%s\")&&\
-                       (URL=\"%s\")&&(CUT_NAME=\"%s\")",
-		      (const char *)edit_station_box->currentText(),
-		      RDRecording::Upload,
-		      (const char *)edit_starttime_edit->time().
-		      toString("hh:mm:ss"),
-		      (const char *)edit_url_edit->text(),
-		      (const char *)edit_destination_edit->text().right(10));
+  QString sql=QString("select ID from RECORDINGS where ")+
+    "(STATION_NAME=\""+RDEscapeString(edit_station_box->currentText())+"\")&&"+
+    QString().sprintf("(TYPE=%d)&&",RDRecording::Upload)+
+    "(START_TIME=\""+edit_starttime_edit->time().toString("hh:mm:ss")+"\")&&"+
+    "(URL=\""+RDEscapeString(edit_url_edit->text())+"\")&&"+
+    "(CUT_NAME=\""+RDEscapeString(edit_destination_edit->text().right(10))+
+    "\")";
   if(edit_sun_button->isChecked()) {
     sql+="&&(SUN=\"Y\")";
   }
