@@ -2,7 +2,7 @@
 //
 // Batch Routines for the Rivendell netcatcher daemon
 //
-//   (C) Copyright 2002-2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,6 +22,7 @@
 #include <stdio.h>
 #include <signal.h>
 #include <string.h>
+#include <syslog.h>
 #include <math.h>
 #include <netdb.h>
 #include <ctype.h>
@@ -38,47 +39,55 @@
 #include <qtimer.h>
 #include <qsignalmapper.h>
 #include <qsessionmanager.h>
+#include <qurl.h>
 
-#include <rddb.h>
+#include <rdapplication.h>
+#include <rdaudioconvert.h>
 #include <rdconf.h>
+#include <rdcut.h>
+#include <rddb.h>
+#include <rddatedecode.h>
+#include <rddebug.h>
+#include <rddownload.h>
+#include <rdescape_string.h>
+#include <rdsettings.h>
+#include <rdtempdirectory.h>
+#include <rdupload.h>
 #include <rdurl.h>
 #include <rdwavefile.h>
-#include <rdcut.h>
-#include <rdcatchd_socket.h>
-#include <rdcatchd.h>
-#include <rdrecording.h>
-#include <rdttyout.h>
-#include <rdmixer.h>
-#include <rdcheck_daemons.h>
-#include <rddebug.h>
-#include <rddatedecode.h>
-#include <rdcmd_switch.h>
-#include <rdescape_string.h>
-#include <rdpodcast.h>
-#include <rdsettings.h>
-#include <rdlibrary_conf.h>
-#include <rdaudioconvert.h>
-#include <rdupload.h>
 #include <rdweb.h>
-#include <rddownload.h>
+
+#include "rdcatchd.h"
 
 void MainObject::catchConnectedData(int serial,bool state)
 {
   if(!state) {
-    LogLine(RDConfig::LogErr,"unable to connect to rdcatchd(8) daemon");
+    rda->syslog(LOG_ERR,"unable to connect to rdcatchd(8) daemon");
     exit(256);
   }
 
+  connect(rda,SIGNAL(userChanged()),this,SLOT(userChangedData()));
+  rda->ripc()->
+    connectHost("localhost",RIPCD_TCP_PORT,rda->config()->password());
+}
+
+
+void MainObject::userChangedData()
+{
   //
   // Dispatch Handler
   //
   switch(batch_event->type()) {
   case RDRecording::Recording:
     RunImport(batch_event);
+    SendNotification(RDNotification::CartType,RDNotification::ModifyAction,
+		     RDCut::cartNumber(batch_event->cutName()));
     break;
 
   case RDRecording::Download:
     RunDownload(batch_event);
+    SendNotification(RDNotification::CartType,RDNotification::ModifyAction,
+		     RDCut::cartNumber(batch_event->cutName()));
     break;
 
   case RDRecording::Upload:
@@ -90,6 +99,15 @@ void MainObject::catchConnectedData(int serial,bool state)
     exit(256);
   }
 
+  QTimer *timer=new QTimer(this);
+  timer->setSingleShot(true);
+  connect(timer,SIGNAL(timeout()),this,SLOT(exitData()));
+  timer->start(5000);  // So notifications have a chance to propagate
+}
+
+
+void MainObject::exitData()
+{
   exit(0);
 }
 
@@ -98,7 +116,6 @@ void MainObject::RunBatch(RDCmdSwitch *cmd)
 {
   bool ok=false;
   int id=-1;
-  unsigned schema=0;
 
   //
   // Set Process Priority
@@ -106,9 +123,8 @@ void MainObject::RunBatch(RDCmdSwitch *cmd)
   struct sched_param sp;
   memset(&sp,0,sizeof(sp));
   if(sched_setscheduler(getpid(),SCHED_BATCH,&sp)!=0) {
-    LogLine(RDConfig::LogWarning,
-	    QString().sprintf("unable to set batch permissions, %s",
-			      strerror(errno)));
+    rda->syslog(LOG_DEBUG,"unable to set batch permissions, %s",
+		strerror(errno));
   }
 
   //
@@ -131,20 +147,7 @@ void MainObject::RunBatch(RDCmdSwitch *cmd)
   //
   // Calculate Temporary Directory
   //
-  catch_temp_dir=RDTempDir();
-
-  //
-  // Open Database
-  //
-  QString err (tr("ERROR rdcatchd aborting - "));
-
-  catch_db=RDInitDb (&schema,&err);
-  if(!catch_db) {
-    printf(err.ascii());
-    exit(1);
-  }
-  connect (RDDbStatus(),SIGNAL(logText(RDConfig::LogPriority,const QString &)),
-	   this,SLOT(log(RDConfig::LogPriority,const QString &)));
+  catch_temp_dir=RDTempDirectory::basePath();
 
   //
   // Load Event
@@ -156,7 +159,7 @@ void MainObject::RunBatch(RDCmdSwitch *cmd)
     fprintf(stderr,"rdcatchd: id %d not found\n",id);
     exit(256);
   }
-  batch_event=new CatchEvent();
+  batch_event=new CatchEvent(rda->station(),RDConfiguration());
   LoadEvent(q,batch_event,false);
   delete q;
 
@@ -167,7 +170,7 @@ void MainObject::RunBatch(RDCmdSwitch *cmd)
   connect(catch_connect,SIGNAL(connected(int,bool)),
 	  this,SLOT(catchConnectedData(int,bool)));
   catch_connect->
-    connectHost("localhost",RDCATCHD_TCP_PORT,catch_config->password());
+    connectHost("localhost",RDCATCHD_TCP_PORT,rda->config()->password());
 }
 
 
@@ -186,7 +189,7 @@ void MainObject::RunDownload(CatchEvent *evt)
   //
   // Resolve Wildcards
   //
-  RDStation *station=new RDStation(catch_config->stationName());
+  RDStation *station=new RDStation(rda->config()->stationName());
   evt->resolveUrl(station->timeOffset());
   delete station;
 
@@ -194,41 +197,38 @@ void MainObject::RunDownload(CatchEvent *evt)
   // Execute Download
   //
   evt->setTempName(BuildTempName(evt,"download"));
-  LogLine(RDConfig::LogInfo,QString().
-	  sprintf("starting download of %s to %s, id=%d",
-		  (const char *)evt->resolvedUrl(),
-		  (const char *)evt->tempName(),
-		  evt->id()));
-  RDDownload *conv=new RDDownload(catch_config->stationName(),this);
+  rda->syslog(LOG_INFO,"starting download of %s to %s, id=%d",
+	      (const char *)evt->resolvedUrl().toUtf8(),
+	      (const char *)evt->tempName().toUtf8(),
+	      evt->id());
+  RDDownload *conv=new RDDownload(rda->config(),this);
   
   conv->setSourceUrl(RDUrlEscape(evt->resolvedUrl()));
   conv->setDestinationFile(evt->tempName());
   QString url_username=evt->urlUsername();
   QString url_password=evt->urlPassword();
   if(url_username.isEmpty()&&
-     (QUrl(evt->resolvedUrl()).protocol().lower()=="ftp")) {
+     (QUrl(evt->resolvedUrl()).scheme().lower()=="ftp")) {
     url_username=RD_ANON_FTP_USERNAME;
     url_password=QString(RD_ANON_FTP_PASSWORD)+"-"+VERSION;
   }
   switch((conv_err=conv->runDownload(url_username,url_password,
-				     catch_config->logXloadDebugData()))) {
+				     rda->config()->logXloadDebugData()))) {
   case RDDownload::ErrorOk:
-    LogLine(RDConfig::LogInfo,QString().
-	    sprintf("finished download of %s to %s, id=%d",
-		    (const char *)evt->tempName(),
-		    (const char *)evt->resolvedUrl(),
-		    evt->id()));
+    rda->syslog(LOG_INFO,"finished download of %s to %s, id=%d",
+		(const char *)evt->tempName().toUtf8(),
+		(const char *)evt->resolvedUrl().toUtf8(),
+		evt->id());
     break;
 
   case RDDownload::ErrorInternal:
     catch_connect->setExitCode(evt->id(),RDRecording::InternalError,
 			       RDDownload::errorText(conv_err));
     qApp->processEvents();
-    LogLine(RDConfig::LogWarning,QString().
-	    sprintf("download of %s returned an error: \"%s\", id=%d",
-		    (const char *)evt->tempName(),
-		    (const char *)RDDownload::errorText(conv_err),
-		    evt->id()));
+    rda->syslog(LOG_WARNING,"download of %s returned an error: \"%s\", id=%d",
+		(const char *)evt->tempName().toUtf8(),
+		(const char *)RDDownload::errorText(conv_err).toUtf8(),
+		evt->id());
     delete conv;
     unlink(evt->tempName());
     exit(0);
@@ -237,11 +237,10 @@ void MainObject::RunDownload(CatchEvent *evt)
     catch_connect->setExitCode(evt->id(),RDRecording::ServerError,
 			       RDDownload::errorText(conv_err));
     qApp->processEvents();
-    LogLine(RDConfig::LogWarning,QString().
-	    sprintf("download of %s returned an error: \"%s\", id=%d",
-		    (const char *)evt->tempName(),
-		    (const char *)RDDownload::errorText(conv_err),
-		    evt->id()));
+    rda->syslog(LOG_WARNING,"download of %s returned an error: \"%s\", id=%d",
+		(const char *)evt->tempName().toUtf8(),
+		(const char *)RDDownload::errorText(conv_err).toUtf8(),
+		evt->id());
     delete conv;
     unlink(evt->tempName());
     exit(0);
@@ -255,12 +254,13 @@ void MainObject::RunDownload(CatchEvent *evt)
     catch_connect->setExitCode(evt->id(),RDRecording::Ok,tr("OK"));
     qApp->processEvents();
   }
-  LogLine(RDConfig::LogInfo,QString().sprintf("deleting file %s, id=%d",
-					      (const char *)evt->tempName(),
-					      evt->id()));
+  rda->syslog(LOG_INFO,"deleting file %s, id=%d",
+	      (const char *)evt->tempName().toUtf8(),evt->id());
   unlink(evt->tempName());
+  catch_connect->setExitCode(evt->id(),RDRecording::Ok,"OK");
 }
 
+
 void MainObject::RunUpload(CatchEvent *evt)
 {
   RDUpload::ErrorCode conv_err;
@@ -268,7 +268,7 @@ void MainObject::RunUpload(CatchEvent *evt)
   //
   // Resolve Wildcards
   //
-  RDStation *station=new RDStation(catch_config->stationName());
+  RDStation *station=new RDStation(rda->config()->stationName());
   evt->resolveUrl(station->timeOffset());
   delete station;
 
@@ -277,26 +277,21 @@ void MainObject::RunUpload(CatchEvent *evt)
   //
   evt->setTempName(BuildTempName(evt,"upload"));
   evt->setDeleteTempFile(true);
-  LogLine(RDConfig::LogInfo,QString().
-	  sprintf("started export of cut %s to %s, id=%d",
-		  (const char *)evt->cutName(),
-		  (const char *)evt->tempName(),
-		  evt->id()));
+  rda->syslog(LOG_INFO,"started export of cut %s to %s, id=%d",
+	      (const char *)evt->cutName().toUtf8(),
+	      (const char *)evt->tempName().toUtf8(),evt->id());
   if(!Export(evt)) {
-    LogLine(RDConfig::LogWarning,QString().
-	    sprintf("export of cut %s returned an error, id=%d",
-		    (const char *)evt->cutName(),
-		    evt->id()));
+    rda->syslog(LOG_WARNING,"export of cut %s returned an error, id=%d",
+		(const char *)evt->cutName().toUtf8(),
+		evt->id());
     catch_connect->setExitCode(evt->id(),RDRecording::InternalError,
 			       tr("Export Error"));
     qApp->processEvents();
     return;
   }
-  LogLine(RDConfig::LogInfo,QString().
-	  sprintf("finished export of cut %s to %s, id=%d",
-		  (const char *)evt->cutName(),
-		  (const char *)evt->tempName(),
-		  evt->id()));
+  rda->syslog(LOG_INFO,"finished export of cut %s to %s, id=%d",
+	      (const char *)evt->cutName().toUtf8(),
+	      (const char *)evt->tempName().toUtf8(),evt->id());
 
   //
   // Load Podcast Parameters
@@ -315,54 +310,49 @@ void MainObject::RunUpload(CatchEvent *evt)
   //
   // Execute Upload
   //
-  LogLine(RDConfig::LogInfo,QString().
-	  sprintf("starting upload of %s to %s, id=%d",
-		  (const char *)evt->tempName(),
-		  (const char *)evt->
-		  resolvedUrl(),
-		  evt->id()));
-  RDUpload *conv=new RDUpload(catch_config->stationName(),this);
+  rda->syslog(LOG_INFO,"starting upload of %s to %s, id=%d",
+	      (const char *)evt->tempName().toUtf8(),
+	      (const char *)evt->resolvedUrl().toUtf8(),
+	      evt->id());
+  RDUpload *conv=new RDUpload(this);
   conv->setSourceFile(evt->tempName());
   conv->setDestinationUrl(evt->resolvedUrl());
   QString url_username=evt->urlUsername();
   QString url_password=evt->urlPassword();
   if(url_username.isEmpty()&&
-     (QUrl(evt->resolvedUrl()).protocol().lower()=="ftp")) {
+     (QUrl(evt->resolvedUrl()).scheme().lower()=="ftp")) {
     url_username=RD_ANON_FTP_USERNAME;
     url_password=QString(RD_ANON_FTP_PASSWORD)+"-"+VERSION;
   }
   switch((conv_err=conv->runUpload(url_username,url_password,
-				   catch_config->logXloadDebugData()))) {
+				   rda->config()->logXloadDebugData()))) {
   case RDUpload::ErrorOk:
     catch_connect->setExitCode(evt->id(),RDRecording::Ok,tr("Ok"));
     qApp->processEvents();
-    LogLine(RDConfig::LogInfo,QString().
-	    sprintf("finished upload of %s to %s, id=%d",
-		    (const char *)evt->tempName(),
-		    (const char *)evt->resolvedUrl(),
-		    evt->id()));
+    rda->syslog(LOG_INFO,"finished upload of %s to %s, id=%d",
+		(const char *)evt->tempName().toUtf8(),
+		(const char *)evt->resolvedUrl().toUtf8(),
+		evt->id());
     break;
 
   case RDUpload::ErrorInternal:
     catch_connect->setExitCode(evt->id(),RDRecording::InternalError,
 			       RDUpload::errorText(conv_err));
     qApp->processEvents();
-    LogLine(RDConfig::LogWarning,QString().
-	    sprintf("upload of %s returned an error: \"%s\", id=%d",
-		    (const char *)evt->tempName(),
-		    (const char *)RDUpload::errorText(conv_err),
-		    evt->id()));
+    rda->syslog(LOG_WARNING,"upload of %s returned an error: \"%s\", id=%d",
+		(const char *)evt->tempName().toUtf8(),
+		(const char *)RDUpload::errorText(conv_err).toUtf8(),
+		evt->id());
     break;
 
   default:
     catch_connect->setExitCode(evt->id(),RDRecording::ServerError,
 			       RDUpload::errorText(conv_err));
     qApp->processEvents();
-    LogLine(RDConfig::LogWarning,QString().
-	    sprintf("upload of %s returned an error: \"%s\", id=%d",
-		    (const char *)evt->tempName(),
-		    (const char *)RDUpload::errorText(conv_err),
-		    evt->id()));
+    rda->syslog(LOG_WARNING,"upload of %s returned an error: \"%s\", id=%d",
+		(const char *)evt->tempName().toUtf8(),
+		(const char *)RDUpload::errorText(conv_err).toUtf8(),
+		evt->id());
     break;
   }
   delete conv;
@@ -375,12 +365,11 @@ void MainObject::RunUpload(CatchEvent *evt)
   }
   if(evt->deleteTempFile()) {
     unlink(evt->tempName());
-    LogLine(RDConfig::LogDebug,QString().sprintf("deleted file %s",
-						 (const char *)evt->tempName()));
+    rda->syslog(LOG_INFO,"deleted file %s",
+		(const char *)evt->tempName().toUtf8());
   }
   else {
-    chown(evt->tempName(),catch_config->uid(),
-	  catch_config->gid());
+    chown(evt->tempName(),rda->config()->uid(),rda->config()->gid());
   }
 }
 
@@ -392,14 +381,13 @@ bool MainObject::Export(CatchEvent *evt)
 
   RDCut *cut=new RDCut(evt->cutName());
   if(!cut->exists()) {
-    LogLine(RDConfig::LogErr,QString().sprintf("Cut not found: %s, id: %d",
-					       (const char *)evt->cutName(),
-					       evt->id()));
+    rda->syslog(LOG_WARNING,"cut not found: %s, id: %d",
+		(const char *)evt->cutName().toUtf8(),evt->id());
     delete cut;
     return false;
   }
   RDCart *cart=new RDCart(cut->cartNumber());
-  RDAudioConvert *conv=new RDAudioConvert(catch_config->stationName(),this);
+  RDAudioConvert *conv=new RDAudioConvert(this);
   conv->setSourceFile(RDCut::pathName(evt->cutName()));
   conv->setRange(cut->startPoint(),cut->endPoint());
   conv->setDestinationFile(RDEscapeString(evt->tempName()));
@@ -424,10 +412,9 @@ bool MainObject::Export(CatchEvent *evt)
     break;
 
   default:
-    LogLine(RDConfig::LogErr,
-	    QString().sprintf("Export error: %s, id: %d",
-			      (const char *)RDAudioConvert::errorText(conv_err),
-			      evt->id()));
+    rda->syslog(LOG_WARNING,"export error: %s, id: %d",
+		(const char *)RDAudioConvert::errorText(conv_err).toUtf8(),
+		evt->id());
     ret=false;
     break;
   }
@@ -449,9 +436,8 @@ bool MainObject::Import(CatchEvent *evt)
 
   RDCut *cut=new RDCut(evt->cutName());
   if(!cut->exists()) {
-    LogLine(RDConfig::LogErr,
-	    QString().sprintf("Cut not found: %s, id: %d",
-			      (const char *)evt->cutName(),evt->id()));
+    rda->syslog(LOG_WARNING,"cut not found: %s, id: %d",
+		(const char *)evt->cutName().toUtf8(),evt->id());
     catch_connect->setExitCode(evt->id(),RDRecording::NoCut,tr("No such cut"));
     qApp->processEvents();
     delete cut;
@@ -459,9 +445,8 @@ bool MainObject::Import(CatchEvent *evt)
   }
   RDWaveFile *wave=new RDWaveFile(evt->tempName());
   if(!wave->openWave()) {
-    LogLine(RDConfig::LogErr,
-	    QString().sprintf("Unknown file format: %s, id: %d",
-			      (const char *)evt->cutName(),evt->id()));
+    rda->syslog(LOG_ERR,"unknown file format: %s, id: %d",
+		(const char *)evt->cutName().toUtf8(),evt->id());
     catch_connect->setExitCode(evt->id(),RDRecording::UnknownFormat,
 			       tr("Unknown Format"));
     qApp->processEvents();
@@ -471,7 +456,7 @@ bool MainObject::Import(CatchEvent *evt)
   unsigned msecs=wave->getExtTimeLength();
   delete wave;
   RDCart *cart=new RDCart(cut->cartNumber());
-  RDAudioConvert *conv=new RDAudioConvert(catch_config->stationName(),this);
+  RDAudioConvert *conv=new RDAudioConvert(this);
   conv->setSourceFile(RDEscapeString(evt->tempName()));
   conv->setDestinationFile(RDCut::pathName(evt->cutName()));
   RDSettings *settings=new RDSettings();
@@ -491,14 +476,13 @@ bool MainObject::Import(CatchEvent *evt)
     break;
   }
   settings->setChannels(evt->channels());
-  settings->setSampleRate(catch_system->sampleRate());
+  settings->setSampleRate(rda->system()->sampleRate());
   settings->setBitRate(evt->bitrate());
   settings->setNormalizationLevel(evt->normalizeLevel()/100);
-  LogLine(RDConfig::LogInfo,QString().
-	  sprintf("started import of %s to cut %s, id=%d",
-		  (const char *)evt->tempName(),
-		  (const char *)evt->cutName(),
-		  evt->id()));
+  rda->syslog(LOG_INFO,"started import of %s to cut %s, id=%d",
+	      (const char *)evt->tempName().toUtf8(),
+	      (const char *)evt->cutName().toUtf8(),
+	 evt->id());
   conv->setDestinationSettings(settings);
   switch((conv_err=conv->convert())) {
   case RDAudioConvert::ErrorOk:
@@ -507,10 +491,9 @@ bool MainObject::Import(CatchEvent *evt)
     break;
 
   case RDAudioConvert::ErrorFormatNotSupported:
-    LogLine(RDConfig::LogErr,
-	    QString().sprintf("Import error: %s, id: %d",
-			      (const char *)RDAudioConvert::errorText(conv_err),
-			      evt->id()));
+    rda->syslog(LOG_WARNING,"import error: %s, id: %d",
+		(const char *)RDAudioConvert::errorText(conv_err).toUtf8(),
+		evt->id());
     catch_connect->setExitCode(evt->id(),RDRecording::UnknownFormat,
 			       RDAudioConvert::errorText(conv_err));
     qApp->processEvents();
@@ -518,10 +501,9 @@ bool MainObject::Import(CatchEvent *evt)
     break;
 
   default:
-    LogLine(RDConfig::LogErr,
-	    QString().sprintf("Import error: %s, id: %d",
-			      (const char *)RDAudioConvert::errorText(conv_err),
-			      evt->id()));
+    rda->syslog(LOG_WARNING,"import error: %s, id: %d",
+		(const char *)RDAudioConvert::errorText(conv_err).toUtf8(),
+		evt->id());
     catch_connect->setExitCode(evt->id(),RDRecording::InternalError,
 			       RDAudioConvert::errorText(conv_err));
     qApp->processEvents();
@@ -532,16 +514,14 @@ bool MainObject::Import(CatchEvent *evt)
     cart->setMetadata(conv->sourceWaveData());
     cut->setMetadata(conv->sourceWaveData());
   }
-  LogLine(RDConfig::LogInfo,QString().
-	  sprintf("completed import of %s to cut %s, id=%d",
-		  (const char *)evt->tempName(),
-		  (const char *)evt->cutName(),
-		  evt->id()));
+  rda->syslog(LOG_INFO,"completed import of %s to cut %s, id=%d",
+	      (const char *)evt->tempName().toUtf8(),
+	      (const char *)evt->cutName().toUtf8(),
+	      evt->id());
   if(evt->deleteTempFile()) {
     unlink(evt->tempName());
-    LogLine(RDConfig::LogDebug,QString().
-	    sprintf("deleted file %s",
-		    (const char *)evt->tempName()));
+    rda->syslog(LOG_DEBUG,"deleted file \"%s\"",
+		(const char *)evt->tempName().toUtf8());
   }
   delete settings;
   delete conv;
