@@ -2,7 +2,7 @@
 //
 // List and Generate RDLibrary Reports
 //
-//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,16 +21,13 @@
 #ifndef LIST_REPORTS_H
 #define LIST_REPORTS_H
 
-#include <qdialog.h>
 #include <qcombobox.h>
 #include <qcheckbox.h>
 #include <qlabel.h>
-#include <qsqldatabase.h>
 
-#include <rdsvc.h>
+#include <rddialog.h>
 
-
-class ListReports : public QDialog
+class ListReports : public RDDialog
 {
  Q_OBJECT
  public:
@@ -48,8 +45,8 @@ class ListReports : public QDialog
  private:
   void GenerateCartReport(QString *report);
   void GenerateCutReport(QString *report);
-  void GenerateCartDumpFixed(QString *report,bool prepend_names);
   void GenerateCartDumpCsv(QString *report,bool prepend_names);
+  QString CsvField(QString str) const;
   QLabel *list_reports_label;
   QComboBox *list_reports_box;
   QCheckBox *list_fieldnames_check;
