@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AddMeta</name>
     <message>
@@ -30,35 +32,35 @@
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Start på:</translation>
+        <translation type="obsolete">Start på:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Handling viss den førre hendinga spelar enno</translation>
+        <translation type="obsolete">Handling viss den førre hendinga spelar enno</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Start med ein gong</translation>
+        <translation type="obsolete">Start med ein gong</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Gjer til neste</translation>
+        <translation type="obsolete">Gjer til neste</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Vent opp til</translation>
+        <translation type="obsolete">Vent opp til</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Spel</translation>
+        <translation type="obsolete">Spel</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Krysston</translation>
+        <translation type="obsolete">Krysston</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Stopp</translation>
+        <translation type="obsolete">Stopp</translation>
     </message>
     <message>
         <source>Overlap</source>
@@ -66,7 +68,7 @@
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Overgangstype:</translation>
+        <translation type="obsolete">Overgangstype:</translation>
     </message>
     <message>
         <source>Log Name</source>
@@ -82,15 +84,15 @@
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Avbryt</translation>
+        <translation type="obsolete">&amp;Avbryt</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Overgang viss førre korg endar før</translation>
+        <translation type="obsolete">Overgang viss førre korg endar før</translation>
     </message>
 </context>
 <context>
@@ -149,55 +151,55 @@
     </message>
     <message>
         <source>TIME</source>
-        <translation>TID</translation>
+        <translation type="obsolete">TID</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation>OVERG</translation>
+        <translation type="obsolete">OVERG</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>KORG</translation>
+        <translation type="obsolete">KORG</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPPE</translation>
+        <translation type="obsolete">GRUPPE</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>LENGD</translation>
+        <translation type="obsolete">LENGD</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TITTEL</translation>
+        <translation type="obsolete">TITTEL</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>ARTIST</translation>
+        <translation type="obsolete">ARTIST</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>KLIENT</translation>
+        <translation type="obsolete">KLIENT</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENT</translation>
+        <translation type="obsolete">AGENT</translation>
     </message>
     <message>
         <source>LABEL</source>
-        <translation>SELSKAP</translation>
+        <translation type="obsolete">SELSKAP</translation>
     </message>
     <message>
         <source>SOURCE</source>
-        <translation>KJELDE</translation>
+        <translation type="obsolete">KJELDE</translation>
     </message>
     <message>
         <source>LINE ID</source>
-        <translation>LINE-ID</translation>
+        <translation type="obsolete">LINE-ID</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation>TELLING</translation>
+        <translation type="obsolete">TELLING</translation>
     </message>
     <message>
         <source>Insert
@@ -238,7 +240,7 @@ meta</translation>
     <message>
         <source>Save
 &amp;As</source>
-        <translation>Lagra &amp;som</translation>
+        <translation type="obsolete">Lagra &amp;som</translation>
     </message>
     <message>
         <source>&amp;Reports</source>
@@ -282,11 +284,11 @@ Vil du lagra likevel?</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>Loggen eksisterer</translation>
+        <translation type="obsolete">Loggen eksisterer</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>Loggen finst frå før!</translation>
+        <translation type="obsolete">Loggen finst frå før!</translation>
     </message>
     <message>
         <source>RDLogEdit</source>
@@ -384,10 +386,6 @@ skrudd av for denne tenesta!</translation>
         <source>Select</source>
         <translation type="unfinished">Vel</translation>
     </message>
-    <message>
-        <source>Run Length</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Next Stop:</source>
         <translation type="unfinished"></translation>
@@ -405,7 +403,119 @@ skrudd av for denne tenesta!</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>EXT DATA</source>
+        <source>Link Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Len</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>As</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User</source>
+        <translation type="obsolete">Brukar</translation>
+    </message>
+    <message>
+        <source>Log Locked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished">Korg</translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished">Tittel</translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished">Artist</translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished">Selskap</translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ext Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Line ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Count</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Run Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scheduled</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Start Times As</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sch. Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Estimated</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Est. Time</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -417,35 +527,35 @@ skrudd av for denne tenesta!</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Start på:</translation>
+        <translation type="obsolete">Start på:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Handling viss den førre hendinga spelar enno</translation>
+        <translation type="obsolete">Handling viss den førre hendinga spelar enno</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Start med ein gong</translation>
+        <translation type="obsolete">Start med ein gong</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Gjer til neste</translation>
+        <translation type="obsolete">Gjer til neste</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Vent opp til</translation>
+        <translation type="obsolete">Vent opp til</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Spel</translation>
+        <translation type="obsolete">Spel</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Krysston</translation>
+        <translation type="obsolete">Krysston</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Stopp</translation>
+        <translation type="obsolete">Stopp</translation>
     </message>
     <message>
         <source>Overlap</source>
@@ -453,7 +563,7 @@ skrudd av for denne tenesta!</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Overgangstype:</translation>
+        <translation type="obsolete">Overgangstype:</translation>
     </message>
     <message>
         <source>No Fade When Segueing At End</source>
@@ -478,15 +588,15 @@ Cart</source>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Avbryt</translation>
+        <translation type="obsolete">&amp;Avbryt</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Overgang viss førre korg endar før</translation>
+        <translation type="obsolete">Overgang viss førre korg endar før</translation>
     </message>
     <message>
         <source>Missing Cart</source>
@@ -510,14 +620,6 @@ som er skrudd av for denne tenesta!</translation>
         <source>No Fade on Segue Out</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Duplicate Start Time</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>An event is already scheduled with this start time!</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>EditMarker</name>
@@ -527,35 +629,35 @@ som er skrudd av for denne tenesta!</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Start på:</translation>
+        <translation type="obsolete">Start på:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Handling viss den førre hendinga spelar enno</translation>
+        <translation type="obsolete">Handling viss den førre hendinga spelar enno</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Start med ein gong</translation>
+        <translation type="obsolete">Start med ein gong</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Gjer til neste</translation>
+        <translation type="obsolete">Gjer til neste</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Vent opp til</translation>
+        <translation type="obsolete">Vent opp til</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Spel</translation>
+        <translation type="obsolete">Spel</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Krysston</translation>
+        <translation type="obsolete">Krysston</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Stopp</translation>
+        <translation type="obsolete">Stopp</translation>
     </message>
     <message>
         <source>Overlap</source>
@@ -571,19 +673,19 @@ som er skrudd av for denne tenesta!</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Avbryt</translation>
+        <translation type="obsolete">&amp;Avbryt</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Overgang viss førre korg endar før</translation>
+        <translation type="obsolete">Overgang viss førre korg endar før</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Overgangstype:</translation>
+        <translation type="obsolete">Overgangstype:</translation>
     </message>
 </context>
 <context>
@@ -594,35 +696,35 @@ som er skrudd av for denne tenesta!</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Start på:</translation>
+        <translation type="obsolete">Start på:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Handling viss den førre hendinga spelar enno</translation>
+        <translation type="obsolete">Handling viss den førre hendinga spelar enno</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Start med ein gong</translation>
+        <translation type="obsolete">Start med ein gong</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Gjer til neste</translation>
+        <translation type="obsolete">Gjer til neste</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Vent opp til</translation>
+        <translation type="obsolete">Vent opp til</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Spel</translation>
+        <translation type="obsolete">Spel</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Krysston</translation>
+        <translation type="obsolete">Krysston</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Stopp</translation>
+        <translation type="obsolete">Stopp</translation>
     </message>
     <message>
         <source>Overlap</source>
@@ -634,53 +736,53 @@ som er skrudd av for denne tenesta!</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Avbryt</translation>
+        <translation type="obsolete">&amp;Avbryt</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Overgang viss førre korg endar før</translation>
+        <translation type="obsolete">Overgang viss førre korg endar før</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Overgangstype:</translation>
+        <translation type="obsolete">Overgangstype:</translation>
     </message>
 </context>
 <context>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation>Vel ein logg</translation>
+        <translation type="obsolete">Vel ein logg</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NAMN</translation>
+        <translation type="obsolete">NAMN</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>SKILDRING</translation>
+        <translation type="obsolete">SKILDRING</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>TENEST</translation>
+        <translation type="obsolete">TENEST</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Avbryt</translation>
+        <translation type="obsolete">&amp;Avbryt</translation>
     </message>
 </context>
 <context>
     <name>ListReports</name>
     <message>
         <source>RDLibrary Reports</source>
-        <translation>RDLibrary-rapportar</translation>
+        <translation type="obsolete">RDLibrary-rapportar</translation>
     </message>
     <message>
         <source>Log Listing</source>
@@ -722,6 +824,10 @@ som er skrudd av for denne tenesta!</translation>
         <source>&amp;Select</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Reports</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWidget</name>
@@ -735,55 +841,55 @@ som er skrudd av for denne tenesta!</translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>Greier ikkje kopla til</translation>
+        <translation type="obsolete">Greier ikkje kopla til</translation>
     </message>
     <message>
         <source>LOG NAME</source>
-        <translation>LOGGNAMN</translation>
+        <translation type="obsolete">LOGGNAMN</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>SKILDRING</translation>
+        <translation type="obsolete">SKILDRING</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>TENEST</translation>
+        <translation type="obsolete">TENEST</translation>
     </message>
     <message>
         <source>MUSIC</source>
-        <translation>MUSIKK</translation>
+        <translation type="obsolete">MUSIKK</translation>
     </message>
     <message>
         <source>TRAFFIC</source>
-        <translation>TRAFIKK</translation>
+        <translation type="obsolete">TRAFIKK</translation>
     </message>
     <message>
         <source>TRACKS</source>
-        <translation>SPOR</translation>
+        <translation type="obsolete">SPOR</translation>
     </message>
     <message>
         <source>VALID FROM</source>
-        <translation>GYLDIG FRÅ</translation>
+        <translation type="obsolete">GYLDIG FRÅ</translation>
     </message>
     <message>
         <source>VALID TO</source>
-        <translation>GYLDIG TIL</translation>
+        <translation type="obsolete">GYLDIG TIL</translation>
     </message>
     <message>
         <source>AUTO REFRESH</source>
-        <translation>AUTO-OPPDATER</translation>
+        <translation type="obsolete">AUTO-OPPDATER</translation>
     </message>
     <message>
         <source>ORIGIN</source>
-        <translation>OPPHAV</translation>
+        <translation type="obsolete">OPPHAV</translation>
     </message>
     <message>
         <source>LAST LINKED</source>
-        <translation>SIST LENKA</translation>
+        <translation type="obsolete">SIST LENKA</translation>
     </message>
     <message>
         <source>LAST MODIFIED</source>
-        <translation>SIST ENDRA</translation>
+        <translation type="obsolete">SIST ENDRA</translation>
     </message>
     <message>
         <source>&amp;Add</source>
@@ -823,11 +929,11 @@ rapport</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>Loggen eksisterer</translation>
+        <translation type="obsolete">Loggen eksisterer</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>Loggen finst frå før!</translation>
+        <translation type="obsolete">Loggen finst frå før!</translation>
     </message>
     <message>
         <source>Delete Log</source>
@@ -840,7 +946,7 @@ rapport</translation>
     <message>
         <source>voice tracks associated with this log.
 Continue?</source>
-        <translation>røystspor som er kopla til denne loggen.
+        <translation type="obsolete">røystspor som er kopla til denne loggen.
 Vil du halda fram?</translation>
     </message>
     <message>
@@ -857,20 +963,7 @@ Vil du halda fram?</translation>
     </message>
     <message>
         <source>RDLogEdit</source>
-        <translation type="unfinished">RDLogEdit</translation>
-    </message>
-    <message>
-        <source>Unable to delete log, audio deletion error!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>RDLogEdit -- Database Skew</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>This version of RDLogEdit is incompatible with the version installed on the server.
-See your system administrator for an update!</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">RDLogEdit</translation>
     </message>
     <message>
         <source>Host</source>
@@ -880,24 +973,199 @@ See your system administrator for an update!</source>
         <source>Unknown</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Are you sure you want to delete the</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>log?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>voice tracks associated with this log.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete these</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>logs?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>voice tracks associated with these logs.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to delete log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>audio deletion error!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown command option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log Name</source>
+        <translation type="unfinished">Loggnamn</translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Service</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALL</source>
+        <source>Music</source>
+        <translation type="unfinished">Musikk</translation>
+    </message>
+    <message>
+        <source>Traffic</source>
+        <translation type="unfinished">Trafikk</translation>
+    </message>
+    <message>
+        <source>Tracks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Filter</source>
+        <source>Valid From</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Clear</source>
+        <source>Valid To</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Show Only Recent Logs</source>
+        <source>Auto Refresh</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Origin</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Linked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Modified</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RenderDialog</name>
+    <message>
+        <source>Render Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering Log...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render Progress</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart/Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render To</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select</source>
+        <translation type="unfinished">Vel</translation>
+    </message>
+    <message>
+        <source>Audio Parameters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[now]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>As Specified</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Virtual Start Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Only Selected Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Include</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Stop Rendering</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Treat as PLAY</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>At STOP transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Render</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">&amp;Avbryt</translation>
+    </message>
+    <message>
+        <source>Filename</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering Error</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -967,31 +1235,31 @@ Track</source>
     </message>
     <message>
         <source>TIME</source>
-        <translation type="unfinished">TID</translation>
+        <translation type="obsolete">TID</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation type="unfinished">OVERG</translation>
+        <translation type="obsolete">OVERG</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation type="unfinished">KORG</translation>
+        <translation type="obsolete">KORG</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation type="unfinished">GRUPPE</translation>
+        <translation type="obsolete">GRUPPE</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation type="unfinished">LENGD</translation>
+        <translation type="obsolete">LENGD</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation type="unfinished">TITTEL</translation>
+        <translation type="obsolete">TITTEL</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation type="unfinished">ARTIST</translation>
+        <translation type="obsolete">ARTIST</translation>
     </message>
     <message>
         <source>Do Over</source>
@@ -1121,12 +1389,52 @@ therefore only existing transitions will be editable.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALBUM</source>
+        <source>LABEL</source>
+        <translation type="obsolete">SELSKAP</translation>
+    </message>
+    <message>
+        <source>Log Locked</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>LABEL</source>
-        <translation type="unfinished">SELSKAP</translation>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Talk</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished">Korg</translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished">Tittel</translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished">Artist</translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished">Selskap</translation>
     </message>
 </context>
 </TS>
