@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AddMeta</name>
     <message>
@@ -30,40 +32,40 @@
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Inicie às:</translation>
+        <translation type="obsolete">Inicie às:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>
+        <translation type="obsolete">
 Ação se Evento anterior estiver sendo executado</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Iniciar Imediatamente</translation>
+        <translation type="obsolete">Iniciar Imediatamente</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Ser Próxima</translation>
+        <translation type="obsolete">Ser Próxima</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Esperar até</translation>
+        <translation type="obsolete">Esperar até</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Simples</translation>
+        <translation type="obsolete">Simples</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Sobre</translation>
+        <translation type="obsolete">Sobre</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Pare</translation>
+        <translation type="obsolete">Pare</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Tipo de Transição:</translation>
+        <translation type="obsolete">Tipo de Transição:</translation>
     </message>
     <message>
         <source>Log Name</source>
@@ -79,15 +81,15 @@ Ação se Evento anterior estiver sendo executado</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Cancelar</translation>
+        <translation type="obsolete">&amp;Cancelar</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Transição de Cartão anterior terminar antes</translation>
+        <translation type="obsolete">Transição de Cartão anterior terminar antes</translation>
     </message>
 </context>
 <context>
@@ -154,7 +156,7 @@ Ação se Evento anterior estiver sendo executado</translation>
     </message>
     <message>
         <source>Run Length</source>
-        <translation>Duração </translation>
+        <translation type="unfinished">Duração </translation>
     </message>
     <message>
         <source>Next Stop:</source>
@@ -166,55 +168,55 @@ Ação se Evento anterior estiver sendo executado</translation>
     </message>
     <message>
         <source>TIME</source>
-        <translation>HORA</translation>
+        <translation type="obsolete">HORA</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation>TRANS</translation>
+        <translation type="obsolete">TRANS</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>CARTÃO</translation>
+        <translation type="obsolete">CARTÃO</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPO</translation>
+        <translation type="obsolete">GRUPO</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>DURAÇÃO</translation>
+        <translation type="obsolete">DURAÇÃO</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TÍTULO</translation>
+        <translation type="obsolete">TÍTULO</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>ARTISTA</translation>
+        <translation type="obsolete">ARTISTA</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>CLIENTE</translation>
+        <translation type="obsolete">CLIENTE</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGÊNCIA</translation>
+        <translation type="obsolete">AGÊNCIA</translation>
     </message>
     <message>
         <source>LABEL</source>
-        <translation>SELO</translation>
+        <translation type="obsolete">SELO</translation>
     </message>
     <message>
         <source>SOURCE</source>
-        <translation>FONTE</translation>
+        <translation type="obsolete">FONTE</translation>
     </message>
     <message>
         <source>LINE ID</source>
-        <translation>ID DE LINHA</translation>
+        <translation type="obsolete">ID DE LINHA</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation>CONTADOR</translation>
+        <translation type="obsolete">CONTADOR</translation>
     </message>
     <message>
         <source>Insert
@@ -301,11 +303,11 @@ Você ainda quer salvar?</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>Lista Existente</translation>
+        <translation type="obsolete">Lista Existente</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>Lista já Existe!</translation>
+        <translation type="obsolete">Lista já Existe!</translation>
     </message>
     <message>
         <source>RDLogEdit</source>
@@ -399,10 +401,6 @@ para o serviço selecionado!</translation>
         <source>Unable to save log, audio deletion error!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>EXT DATA</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Link Start</source>
         <translation type="unfinished"></translation>
@@ -413,7 +411,7 @@ para o serviço selecionado!</translation>
     </message>
     <message>
         <source>Save</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Salvar</translation>
     </message>
     <message>
         <source>As</source>
@@ -423,6 +421,98 @@ para o serviço selecionado!</translation>
         <source>Render</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User</source>
+        <translation type="obsolete">Usuário</translation>
+    </message>
+    <message>
+        <source>Log Locked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Time</source>
+        <translation type="unfinished">Tempo</translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished">Cartão</translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished">Título</translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished">Artista</translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished">Selo</translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ext Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Line ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Count</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scheduled</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Start Times As</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sch. Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Estimated</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Est. Time</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditLogLine</name>
@@ -432,39 +522,39 @@ para o serviço selecionado!</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Inicie às:</translation>
+        <translation type="obsolete">Inicie às:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Ação se Evento anterior estiver sendo executado</translation>
+        <translation type="obsolete">Ação se Evento anterior estiver sendo executado</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Iniciar Imediatamente</translation>
+        <translation type="obsolete">Iniciar Imediatamente</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Ser Próxima</translation>
+        <translation type="obsolete">Ser Próxima</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Esperar até</translation>
+        <translation type="obsolete">Esperar até</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Simples</translation>
+        <translation type="obsolete">Simples</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Sobre</translation>
+        <translation type="obsolete">Sobre</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Pare</translation>
+        <translation type="obsolete">Pare</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Tipo de Transição:</translation>
+        <translation type="obsolete">Tipo de Transição:</translation>
     </message>
     <message>
         <source>No Fade on Segue Out</source>
@@ -489,15 +579,15 @@ Cart</source>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Cancelar</translation>
+        <translation type="obsolete">&amp;Cancelar</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Transição de Cartão anterior terminar antes</translation>
+        <translation type="obsolete">Transição de Cartão anterior terminar antes</translation>
     </message>
     <message>
         <source>Missing Cart</source>
@@ -519,11 +609,11 @@ para o Serviço especificado!</translation>
     </message>
     <message>
         <source>Duplicate Start Time</source>
-        <translation>Duplicar Hora de Início</translation>
+        <translation type="obsolete">Duplicar Hora de Início</translation>
     </message>
     <message>
         <source>An event is already scheduled with this start time!</source>
-        <translation>Um evento já foi agendado para esta hora!</translation>
+        <translation type="obsolete">Um evento já foi agendado para esta hora!</translation>
     </message>
 </context>
 <context>
@@ -534,35 +624,35 @@ para o Serviço especificado!</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Inicie às:</translation>
+        <translation type="obsolete">Inicie às:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>Ação se Evento anterior estiver sendo executado</translation>
+        <translation type="obsolete">Ação se Evento anterior estiver sendo executado</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Iniciar Imediatamente</translation>
+        <translation type="obsolete">Iniciar Imediatamente</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Ser Próxima</translation>
+        <translation type="obsolete">Ser Próxima</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Esperar até</translation>
+        <translation type="obsolete">Esperar até</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Simples</translation>
+        <translation type="obsolete">Simples</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Sobre</translation>
+        <translation type="obsolete">Sobre</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Pare</translation>
+        <translation type="obsolete">Pare</translation>
     </message>
     <message>
         <source>Comment</source>
@@ -574,19 +664,19 @@ para o Serviço especificado!</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Cancelar</translation>
+        <translation type="obsolete">&amp;Cancelar</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Transição se Cartão anterior terminar antes</translation>
+        <translation type="obsolete">Transição se Cartão anterior terminar antes</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Tipo de Transição:</translation>
+        <translation type="obsolete">Tipo de Transição:</translation>
     </message>
 </context>
 <context>
@@ -597,36 +687,36 @@ para o Serviço especificado!</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation>Inicie às:</translation>
+        <translation type="obsolete">Inicie às:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation>
+        <translation type="obsolete">
 Ação se Evento anterior estiver sendo executado</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation>Iniciar Imediatamente</translation>
+        <translation type="obsolete">Iniciar Imediatamente</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation>Ser Próxima</translation>
+        <translation type="obsolete">Ser Próxima</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation>Esperar até</translation>
+        <translation type="obsolete">Esperar até</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation>Simples</translation>
+        <translation type="obsolete">Simples</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation>Sobre</translation>
+        <translation type="obsolete">Sobre</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Pare</translation>
+        <translation type="obsolete">Pare</translation>
     </message>
     <message>
         <source>Comment</source>
@@ -634,53 +724,53 @@ Ação se Evento anterior estiver sendo executado</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Cancelar</translation>
+        <translation type="obsolete">&amp;Cancelar</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation>Transição de Cartão anterior terminar antes</translation>
+        <translation type="obsolete">Transição de Cartão anterior terminar antes</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation>Tipo de Transição:</translation>
+        <translation type="obsolete">Tipo de Transição:</translation>
     </message>
 </context>
 <context>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation>Selecionar a Lista</translation>
+        <translation type="obsolete">Selecionar a Lista</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NOME</translation>
+        <translation type="obsolete">NOME</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>DESCRIÇÃO</translation>
+        <translation type="obsolete">DESCRIÇÃO</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SERVIÇO</translation>
+        <translation type="obsolete">SERVIÇO</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Cancelar</translation>
+        <translation type="obsolete">&amp;Cancelar</translation>
     </message>
 </context>
 <context>
     <name>ListReports</name>
     <message>
         <source>RDLibrary Reports</source>
-        <translation>Relatórios da RDBiblio</translation>
+        <translation type="obsolete">Relatórios da RDBiblio</translation>
     </message>
     <message>
         <source>Log Listing</source>
@@ -722,6 +812,10 @@ Ação se Evento anterior estiver sendo executado</translation>
         <source>No exceptions found.</source>
         <translation>Exceções não Encontradas.</translation>
     </message>
+    <message>
+        <source>Reports</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWidget</name>
@@ -735,55 +829,55 @@ Ação se Evento anterior estiver sendo executado</translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>Não foi possível Conectar</translation>
+        <translation type="obsolete">Não foi possível Conectar</translation>
     </message>
     <message>
         <source>LOG NAME</source>
-        <translation>NOME DA LISTA</translation>
+        <translation type="obsolete">NOME DA LISTA</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>DESCRIÇÃO</translation>
+        <translation type="obsolete">DESCRIÇÃO</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SERVIÇO</translation>
+        <translation type="obsolete">SERVIÇO</translation>
     </message>
     <message>
         <source>MUSIC</source>
-        <translation>MÚSICAS</translation>
+        <translation type="obsolete">MÚSICAS</translation>
     </message>
     <message>
         <source>TRAFFIC</source>
-        <translation>TRÁFEGO</translation>
+        <translation type="obsolete">TRÁFEGO</translation>
     </message>
     <message>
         <source>TRACKS</source>
-        <translation>FAIXAS</translation>
+        <translation type="obsolete">FAIXAS</translation>
     </message>
     <message>
         <source>VALID FROM</source>
-        <translation>VÁLIDO A PARTIR DE</translation>
+        <translation type="obsolete">VÁLIDO A PARTIR DE</translation>
     </message>
     <message>
         <source>VALID TO</source>
-        <translation>VÁLIDO ATÉ</translation>
+        <translation type="obsolete">VÁLIDO ATÉ</translation>
     </message>
     <message>
         <source>AUTO REFRESH</source>
-        <translation>AUTO ATUALIZAÇÃO</translation>
+        <translation type="obsolete">AUTO ATUALIZAÇÃO</translation>
     </message>
     <message>
         <source>ORIGIN</source>
-        <translation>ORIGEM</translation>
+        <translation type="obsolete">ORIGEM</translation>
     </message>
     <message>
         <source>LAST LINKED</source>
-        <translation>ÚLTIMO LINKADO</translation>
+        <translation type="obsolete">ÚLTIMO LINKADO</translation>
     </message>
     <message>
         <source>LAST MODIFIED</source>
-        <translation>ÚLTIMO MODIFICADO</translation>
+        <translation type="obsolete">ÚLTIMO MODIFICADO</translation>
     </message>
     <message>
         <source>&amp;Add</source>
@@ -822,11 +916,11 @@ Report</source>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>Lista Existente</translation>
+        <translation type="obsolete">Lista Existente</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>Lista já Existe!</translation>
+        <translation type="obsolete">Lista já Existe!</translation>
     </message>
     <message>
         <source>Delete Log</source>
@@ -839,7 +933,7 @@ Report</source>
     <message>
         <source>voice tracks associated with this log.
 Continue?</source>
-        <translation>faixas de voz associadas a esta Lista.
+        <translation type="obsolete">faixas de voz associadas a esta Lista.
 Continuar?</translation>
     </message>
     <message>
@@ -856,20 +950,7 @@ Continuar?</translation>
     </message>
     <message>
         <source>RDLogEdit</source>
-        <translation type="unfinished">RDListas</translation>
-    </message>
-    <message>
-        <source>Unable to delete log, audio deletion error!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>RDLogEdit -- Database Skew</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>This version of RDLogEdit is incompatible with the version installed on the server.
-See your system administrator for an update!</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">RDListas</translation>
     </message>
     <message>
         <source>Host</source>
@@ -879,24 +960,199 @@ See your system administrator for an update!</source>
         <source>Unknown</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Are you sure you want to delete the</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>log?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>voice tracks associated with this log.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete these</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>logs?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>voice tracks associated with these logs.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to delete log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>audio deletion error!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown command option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log Name</source>
+        <translation type="unfinished">Nome da Lista</translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Service</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALL</source>
+        <source>Music</source>
+        <translation type="unfinished">Músicas</translation>
+    </message>
+    <message>
+        <source>Traffic</source>
+        <translation type="unfinished">Tráfego</translation>
+    </message>
+    <message>
+        <source>Tracks</source>
+        <translation type="unfinished">Faixas</translation>
+    </message>
+    <message>
+        <source>Valid From</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Filter</source>
+        <source>Valid To</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Clear</source>
+        <source>Auto Refresh</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Show Only Recent Logs</source>
+        <source>Origin</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Linked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Modified</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RenderDialog</name>
+    <message>
+        <source>Render Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering Log...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render Progress</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart/Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render To</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio Parameters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[now]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>As Specified</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Virtual Start Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Only Selected Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Include</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Stop Rendering</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Treat as PLAY</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>At STOP transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Render</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">&amp;Cancelar</translation>
+    </message>
+    <message>
+        <source>Filename</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering Error</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -964,31 +1220,31 @@ Faixa</translation>
     </message>
     <message>
         <source>TIME</source>
-        <translation type="unfinished">HORA</translation>
+        <translation type="obsolete">HORA</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation type="unfinished">TRANS</translation>
+        <translation type="obsolete">TRANS</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation type="unfinished">CARTÃO</translation>
+        <translation type="obsolete">CARTÃO</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation type="unfinished">GRUPO</translation>
+        <translation type="obsolete">GRUPO</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation type="unfinished">DURAÇÃO</translation>
+        <translation type="obsolete">DURAÇÃO</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation type="unfinished">TÍTULO</translation>
+        <translation type="obsolete">TÍTULO</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation type="unfinished">ARTISTA</translation>
+        <translation type="obsolete">ARTISTA</translation>
     </message>
     <message>
         <source>Do Over</source>
@@ -1127,12 +1383,52 @@ Assim sendo, somente transições existentes serão editáveis.</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALBUM</source>
+        <source>LABEL</source>
+        <translation type="obsolete">SELO</translation>
+    </message>
+    <message>
+        <source>Log Locked</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>LABEL</source>
-        <translation type="unfinished">SELO</translation>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Talk</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished">Cartão</translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished">Título</translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished">Artista</translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished">Selo</translation>
     </message>
 </context>
 </TS>
