@@ -2,7 +2,7 @@
 //
 // The User Login/Logout Utility for Rivendell.
 //
-//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,25 +21,20 @@
 #ifndef RDLOGIN_H
 #define RDLOGIN_H
 
-#include <qwidget.h>
-#include <qsize.h>
-#include <qsizepolicy.h>
-#include <qsqldatabase.h>
 #include <qcombobox.h>
+#include <qlabel.h>
 #include <qlineedit.h>
 #include <qpushbutton.h>
 
-#include <rduser.h>
-#include <rdstation.h>
-#include <rdripc.h>
-#include <rdconfig.h>
-#include <rdsystem.h>
+#include <rdwidget.h>
 
-class MainWidget : public QWidget
+#define RDLOGIN_USAGE "\n"
+
+class MainWidget : public RDWidget
 {
   Q_OBJECT
  public:
-  MainWidget(QWidget *parent=0);
+  MainWidget(RDConfig *c,QWidget *parent=0);
   ~MainWidget();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -56,11 +51,6 @@ class MainWidget : public QWidget
   void resizeEvent(QResizeEvent *e);
 
  private:
-  RDConfig *login_config;
-  QSqlDatabase *login_db;
-  RDStation *login_station;
-  RDSystem *login_system;
-  RDRipc *login_ripc;
   Q_UINT16 login_ripc_hostport;
   QLabel *login_label;
   QLabel *login_username_label;
@@ -73,6 +63,7 @@ class MainWidget : public QWidget
   QPushButton *logout_button;
   QPushButton *cancel_button;
   int login_user_width;
+  bool login_resize;
 };
 
 
