@@ -191,7 +191,7 @@ horario</translation>
     </message>
     <message>
         <source>Remarks</source>
-        <translation>Comentarios</translation>
+        <translation type="obsolete">Comentarios</translation>
     </message>
     <message>
         <source>&amp;Clone</source>
@@ -218,6 +218,14 @@ horario</translation>
         <source>That event does not exist.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>USER NOTES</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEvent</name>
@@ -303,7 +311,7 @@ horario</translation>
     </message>
     <message>
         <source>Make Post Point</source>
-        <translation>Hacer Post Point</translation>
+        <translation type="obsolete">Hacer Post Point</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
@@ -335,7 +343,7 @@ horario</translation>
     </message>
     <message>
         <source>Transition if previous event ends before start time:</source>
-        <translation>Transición si evento termina antes que éste inicie:</translation>
+        <translation type="obsolete">Transición si evento termina antes que éste inicie:</translation>
     </message>
     <message>
         <source>ENFORCING LENGTH</source>
@@ -387,11 +395,11 @@ horario</translation>
     </message>
     <message>
         <source>Imported carts have a</source>
-        <translation>Transic. cart. importados</translation>
+        <translation type="unfinished">Transic. cart. importados</translation>
     </message>
     <message>
         <source>transition.</source>
-        <translation>.</translation>
+        <translation type="unfinished">.</translation>
     </message>
     <message>
         <source>POST-IMPORT CARTS</source>
@@ -441,27 +449,27 @@ List</source>
     </message>
     <message>
         <source>Cue</source>
-        <translation>Cue</translation>
+        <translation type="obsolete">Cue</translation>
     </message>
     <message>
         <source>SEGUE</source>
-        <translation>SEGUE</translation>
+        <translation type="obsolete">SEGUE</translation>
     </message>
     <message>
         <source>STOP</source>
-        <translation>PARAR</translation>
+        <translation type="obsolete">PARAR</translation>
     </message>
     <message>
         <source>PLAY</source>
-        <translation>REPROD</translation>
+        <translation type="obsolete">REPROD</translation>
     </message>
     <message>
         <source>, Timed(Start)</source>
-        <translation>, Tiempo(Inicio)</translation>
+        <translation type="obsolete">, Tiempo(Inicio)</translation>
     </message>
     <message>
         <source>, Timed(MakeNext)</source>
-        <translation>, Tiempo(HacerSiguiente)</translation>
+        <translation type="obsolete">, Tiempo(HacerSiguiente)</translation>
     </message>
     <message>
         <source>Timed(Wait</source>
@@ -469,23 +477,23 @@ List</source>
     </message>
     <message>
         <source>, Post</source>
-        <translation>, Post</translation>
+        <translation type="obsolete">, Post</translation>
     </message>
     <message>
         <source>, Fill</source>
-        <translation>, Llenar</translation>
+        <translation type="obsolete">, Llenar</translation>
     </message>
     <message>
         <source>, Scale</source>
-        <translation>, Escalar</translation>
+        <translation type="obsolete">, Escalar</translation>
     </message>
     <message>
         <source>, Traffic</source>
-        <translation>, Tráfico</translation>
+        <translation type="obsolete">, Tráfico</translation>
     </message>
     <message>
         <source>, Music</source>
-        <translation>, Música</translation>
+        <translation type="obsolete">, Música</translation>
     </message>
     <message>
         <source>Event already exists!
@@ -507,15 +515,15 @@ Do you want to overwrite it?</source>
     </message>
     <message>
         <source>event.</source>
-        <translation>.</translation>
+        <translation type="obsolete">.</translation>
     </message>
     <message>
         <source>Import inline traffic with the</source>
-        <translation>Importar tráfico con el evento</translation>
+        <translation type="obsolete">Importar tráfico con el evento</translation>
     </message>
     <message>
         <source>, Inline Traffic</source>
-        <translation>, tráfico en línea</translation>
+        <translation type="obsolete">, tráfico en línea</translation>
     </message>
     <message>
         <source>Select from:</source>
@@ -531,11 +539,11 @@ Do you want to overwrite it?</source>
     </message>
     <message>
         <source>, Scheduler</source>
-        <translation>, Programador</translation>
+        <translation type="obsolete">, Programador</translation>
     </message>
     <message>
         <source>REMARKS</source>
-        <translation>COMENTARIOS</translation>
+        <translation type="obsolete">COMENTARIOS</translation>
     </message>
     <message>
         <source>Len:</source>
@@ -553,10 +561,6 @@ Do you want to overwrite it?</source>
         <source>and code</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Timed(Wait)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cart</source>
         <translation type="unfinished"></translation>
@@ -605,6 +609,22 @@ Do you want to overwrite it?</source>
         <source>Search</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>TRANSITIONS</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CART STACK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import inline traffic event</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>USER NOTES</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEventLine</name>
@@ -1243,7 +1263,7 @@ eliminar</translation>
     </message>
     <message>
         <source>Color</source>
-        <translation>Color</translation>
+        <translation type="obsolete">Color</translation>
     </message>
     <message>
         <source>&amp;Add</source>
@@ -1327,6 +1347,10 @@ eliminar</translation>
         <source>is in use in the following clocks</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListGrids</name>
