@@ -167,10 +167,6 @@ Do you want to save?</source>
         <source>That code is already in use!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Remarks</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Clone</source>
         <translation type="unfinished"></translation>
@@ -196,6 +192,14 @@ Do you want to save?</source>
         <source>That event does not exist.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>USER NOTES</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEvent</name>
@@ -247,10 +251,6 @@ Do you want to save?</source>
         <source>Use hard start time</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Make Post Point</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
         <translation type="unfinished"></translation>
@@ -279,10 +279,6 @@ Do you want to save?</source>
         <source>Stop</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Transition if previous event ends before start time:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>ENFORCING LENGTH</source>
         <translation type="unfinished"></translation>
@@ -343,26 +339,10 @@ Do you want to save?</source>
         <source>First cart has a</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Imported carts have a</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>transition.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Import inline traffic with the</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>[none]</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>event.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>POST-IMPORT CARTS</source>
         <translation type="unfinished"></translation>
@@ -413,62 +393,6 @@ Do you want to overwrite it?</source>
         <source>Macro</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Cue</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>SEGUE</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>STOP</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>PLAY</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>, Timed(Start)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>, Timed(MakeNext)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>, Post</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>, Fill</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>, Scale</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>, Traffic</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>, Music</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>, Scheduler</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>, Inline Traffic</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>REMARKS</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Len:</source>
         <translation type="unfinished"></translation>
@@ -485,10 +409,6 @@ Do you want to overwrite it?</source>
         <source>and code</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Timed(Wait)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cart</source>
         <translation type="unfinished"></translation>
@@ -537,6 +457,30 @@ Do you want to overwrite it?</source>
         <source>Search</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Imported carts have a</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>transition.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TRANSITIONS</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CART STACK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import inline traffic event</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>USER NOTES</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEventLine</name>
@@ -1101,10 +1045,6 @@ Do you want to save?</source>
         <source>Properties</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Color</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Add</source>
         <translation type="unfinished"></translation>
@@ -1173,6 +1113,10 @@ Do you want to save?</source>
         <source>is in use in the following clocks</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListGrids</name>
