@@ -2,7 +2,7 @@
 //
 // Virtual base class for replicator methods
 //
-//   (C) Copyright 2010,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2010,2016-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,7 +18,7 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <replfactory.h>
+#include "replfactory.h"
 
 ReplFactory::ReplFactory(ReplConfig *config)
 {
