@@ -2,7 +2,7 @@
 //
 // System Selector for Rivendell
 //
-//   (C) Copyright 2012,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2012-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,30 +21,26 @@
 #ifndef RDSELECT_H
 #define RDSELECT_H
 
-#include <vector>
+#include <q3listbox.h>
 
-#include <qwidget.h>
-#include <qsize.h>
-#include <qsizepolicy.h>
-#include <qlistbox.h>
+#include <q3listbox.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
-#include <qstringlist.h>
-#include <qpixmap.h>
 
 #include <rdconfig.h>
 #include <rdmonitor_config.h>
+#include <rdwidget.h>
 
-class MainWidget : public QWidget
+class MainWidget : public RDWidget
 {
   Q_OBJECT
  public:
-  MainWidget(QWidget *parent=0);
+  MainWidget(RDConfig *c,QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
 
  private slots:
-  void doubleClickedData(QListBoxItem *item);
+  void doubleClickedData(Q3ListBoxItem *item);
   void okData();
   void cancelData();
   
@@ -52,17 +48,14 @@ class MainWidget : public QWidget
   void resizeEvent(QResizeEvent *e);
 
  private:
-  bool Shutdown(int id);
-  bool Startup(int id);
   void SetSystem(int id);
-  bool VerifyShutdown() const;
   void SetCurrentItem(int id);
   std::vector<RDConfig *> select_configs;
   QStringList select_filenames;
   int select_current_id;
   QLabel *select_current_label;
   QLabel *select_label;
-  QListBox *select_box;
+  Q3ListBox *select_box;
   QPixmap *login_rivendell_map;
   QPushButton *ok_button;
   QPushButton *cancel_button;
@@ -72,4 +65,4 @@ class MainWidget : public QWidget
 };
 
 
-#endif  // RDLOGIN_H
+#endif  // RDSELECT_H
