@@ -2,7 +2,7 @@
 //
 // A Rivendell multicast GPIO driver for LiveWire networks.
 //
-//   (C) Copyright 2013,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2013-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,19 +18,20 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <stdlib.h>
-#include <syslog.h>
 #include <errno.h>
 #include <fcntl.h>
+#include <stdlib.h>
+#include <syslog.h>
 #include <time.h>
 #include <netinet/in.h>
 #include <netinet/ip.h>
 
+#include <rdapplication.h>
 #include <rddb.h>
 #include <rdescape_string.h>
 
-#include <globals.h>
-#include <livewire_mcastgpio.h>
+#include "globals.h"
+#include "livewire_mcastgpio.h"
 
 LiveWireMcastGpio::LiveWireMcastGpio(RDMatrix *matrix,QObject *parent)
   : Switcher(matrix,parent)
@@ -45,7 +46,7 @@ LiveWireMcastGpio::LiveWireMcastGpio(RDMatrix *matrix,QObject *parent)
   //
   // Get Matrix Parameters
   //
-  livewire_stationname=rdstation->name();
+  livewire_stationname=rda->station()->name();
   livewire_matrix=matrix->matrix();
   livewire_gpios=matrix->gpis();
   livewire_interface_addr=matrix->ipAddress(RDMatrix::Primary);
@@ -96,7 +97,8 @@ LiveWireMcastGpio::LiveWireMcastGpio(RDMatrix *matrix,QObject *parent)
   // GPIO Write Socket
   //
   if((livewire_gpio_write_socket=socket(PF_INET,SOCK_DGRAM,0))<0) {
-    syslog(LOG_ERR,"unable to create GPIO write socket [%s]",strerror(errno));
+    rda->syslog(LOG_ERR,"unable to create GPIO write socket [%s]",
+		strerror(errno));
     return;
   }
   sockopt=O_NONBLOCK;
@@ -107,7 +109,8 @@ LiveWireMcastGpio::LiveWireMcastGpio(RDMatrix *matrix,QObject *parent)
   sa.sin_addr.s_addr=
     htonl(matrix->ipAddress(RDMatrix::Primary).ip4Addr());
   if(bind(livewire_gpio_write_socket,(struct sockaddr *)&sa,sizeof(sa))<0) {
-    syslog(LOG_ERR,"unable to bind GPIO write socket [%s]",strerror(errno));
+    rda->syslog(LOG_ERR,"unable to bind GPIO write socket [%s]",
+		strerror(errno));
     return;
   }
 
@@ -115,7 +118,8 @@ LiveWireMcastGpio::LiveWireMcastGpio(RDMatrix *matrix,QObject *parent)
   // GPIO Read Socket
   //
   if((livewire_gpio_read_socket=socket(PF_INET,SOCK_DGRAM,0))<0) {
-    syslog(LOG_ERR,"unable to create GPIO read socket [%s]",strerror(errno));
+    rda->syslog(LOG_ERR,"unable to create GPIO read socket [%s]",
+		strerror(errno));
     return;
   }
   sockopt=O_NONBLOCK;
@@ -125,7 +129,7 @@ LiveWireMcastGpio::LiveWireMcastGpio(RDMatrix *matrix,QObject *parent)
   sa.sin_port=htons(RD_LIVEWIRE_GPIO_RECV_PORT);
   sa.sin_addr.s_addr=htonl(INADDR_ANY);
   if(bind(livewire_gpio_read_socket,(struct sockaddr *)&sa,sizeof(sa))<0) {
-    syslog(LOG_ERR,"unable to bind GPIO socket [%s]",strerror(errno));
+    rda->syslog(LOG_ERR,"unable to bind GPIO socket [%s]",strerror(errno));
     return;
   }
   livewire_gpio_notify=
@@ -137,7 +141,11 @@ LiveWireMcastGpio::LiveWireMcastGpio(RDMatrix *matrix,QObject *parent)
   //
   // Source Table
   //
-  sql=QString("select SLOT,SOURCE_NUMBER,IP_ADDRESS from LIVEWIRE_GPIO_SLOTS ")+
+  sql=QString("select ")+
+    "SLOT,"+           // 00
+    "SOURCE_NUMBER,"+  // 01
+    "IP_ADDRESS "+     // 02
+    "from LIVEWIRE_GPIO_SLOTS "+
     "where (STATION_NAME=\""+RDEscapeString(livewire_stationname)+"\")&&"+
     QString().sprintf("(MATRIX=%d) ",livewire_matrix)+
     "order by SLOT";
@@ -212,14 +220,14 @@ void LiveWireMcastGpio::processCommand(RDMacro *cmd)
 	if((cmd->argQuantity()!=5)||
 	   (cmd->arg(2).toInt()<1)||
 	   (cmd->arg(2).toInt()>(int)livewire_gpios)||
-	   ((cmd->arg(1).toString().lower()!="i")&&
-	    (cmd->arg(1).toString().lower()!="o"))) {
+	   ((cmd->arg(1).lower()!="i")&&
+	    (cmd->arg(1).lower()!="o"))) {
 	  cmd->acknowledge(false);
 	  emit rmlEcho(cmd);
 	  return;
 	}
 
-	if(cmd->arg(1).toString().lower()=="i") {
+	if(cmd->arg(1).lower()=="i") {
 	  slot=(cmd->arg(2).toInt()-1)/5;
 	  line=(cmd->arg(2).toInt()-1)%5;
 	  if(livewire_source_numbers[slot]<=0) {
@@ -234,7 +242,7 @@ void LiveWireMcastGpio::processCommand(RDMacro *cmd)
 	  ProcessGpoIn(livewire_source_numbers[slot],line,cmd->arg(3).toInt());
 	  livewire_gpo_in_states[cmd->arg(2).toInt()-1]=cmd->arg(3).toInt();
 	}
-	if(cmd->arg(1).toString().lower()=="o") {
+	if(cmd->arg(1).lower()=="o") {
 	  slot=(cmd->arg(2).toInt()-1)/5;
 	  line=(cmd->arg(2).toInt()-1)%5;
 	  if(livewire_source_numbers[slot]<=0) {
@@ -404,7 +412,7 @@ void LiveWireMcastGpio::ProcessGpoOut(int chan,unsigned line,bool state)
 	htonl(livewire_surface_addresses[it->first].toIPv4Address());
     }
   }
-  syslog(LOG_NOTICE,"using %s",
+  rda->syslog(LOG_DEBUG,"using %s",
 	 (const char *)QHostAddress(ntohl(sa.sin_addr.s_addr)).toString());
   */
 
@@ -460,10 +468,10 @@ void LiveWireMcastGpio::subscribe(const uint32_t addr) const
   if(setsockopt(livewire_gpio_read_socket,SOL_IP,IP_ADD_MEMBERSHIP,&mreq,
 		sizeof(mreq))!=0) {
     if(errno!=EADDRINUSE) {
-      syslog(LOG_WARNING,"unable to subscribe to %s on %s [%s]",
-	     (const char *)AddressString(addr),
-	     (const char *)livewire_interface_addr.toString(),
-	     strerror(errno));
+      rda->syslog(LOG_WARNING,"unable to subscribe to %s on %s [%s]",
+		  (const char *)AddressString(addr),
+		  (const char *)livewire_interface_addr.toString(),
+		  strerror(errno));
     }
   }
 }
@@ -486,10 +494,10 @@ void LiveWireMcastGpio::unsubscribe(const uint32_t addr) const
   if(setsockopt(livewire_gpio_read_socket,SOL_IP,IP_DROP_MEMBERSHIP,&mreq,
 		sizeof(mreq))!=0) {
     if(errno!=ENODEV) {
-      syslog(LOG_WARNING,"unable to unsubscribe from %s on %s [%s]",
-	     (const char *)AddressString(addr),
-	     (const char *)livewire_interface_addr.toString(),
-	     strerror(errno));
+      rda->syslog(LOG_WARNING,"unable to unsubscribe from %s on %s [%s]",
+		  (const char *)AddressString(addr),
+		  (const char *)livewire_interface_addr.toString(),
+		  strerror(errno));
     }
   }
 }
