@@ -2,7 +2,7 @@
 //
 // A Qt-based application for importing Dial Global CDN downloads
 //
-//   (C) Copyright 2012,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2012-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,41 +21,29 @@
 #ifndef RDDGIMPORT_H
 #define RDDGIMPORT_H
 
-#include <vector>
-#include <map>
+#include <q3datetimeedit.h>
+#include <q3textedit.h>
 
-#include <qwidget.h>
-#include <qsize.h>
-#include <qsizepolicy.h>
-#include <qlabel.h>
 #include <qcombobox.h>
 #include <qlineedit.h>
 #include <qpushbutton.h>
-#include <qdatetime.h>
-#include <qdatetimeedit.h>
-#include <qtextedit.h>
 
-#include <rdconfig.h>
-#include <rddb.h>
-#include <rdgroup.h>
-#include <rdlibrary_conf.h>
-#include <rdstation.h>
 #include <rdbusybar.h>
+#include <rdgroup.h>
 #include <rdsvc.h>
-#include <rduser.h>
-#include <rdripc.h>
+#include <rdwidget.h>
 
-#include <event.h>
+#include "event.h"
 
 #define RDDGIMPORT_USAGE "\n"
 #define RDDGIMPORT_KILLDATE_OFFSET 7
 #define RDDGIMPORT_FILE_EXTENSION "mp3"
 
-class MainWidget : public QWidget
+class MainWidget : public RDWidget
 {
   Q_OBJECT
  public:
-   MainWidget(QWidget *parent=0);
+  MainWidget(RDConfig *c,QWidget *parent=0);
    QSize sizeHint() const;
 
  private slots:
@@ -89,10 +77,10 @@ class MainWidget : public QWidget
   QLineEdit *dg_filename_edit;
   QPushButton *dg_filename_button;
   QLabel *dg_date_label;
-  QDateEdit *dg_date_edit;
+  Q3DateEdit *dg_date_edit;
   QPushButton *dg_date_button;
   QLabel *dg_messages_label;
-  QTextEdit *dg_messages_text;
+  Q3TextEdit *dg_messages_text;
   RDBusyBar *dg_bar;
   QPushButton *dg_process_button;
   QPushButton *dg_close_button;
@@ -100,12 +88,6 @@ class MainWidget : public QWidget
   std::vector<Event *> dg_events;
   RDGroup *dg_group;
   RDSvc *dg_svc;
-  RDRipc *dg_ripc;
-  RDUser *dg_user;
-  RDStation *dg_station;
-  RDLibraryConf *dg_library_conf;
-  RDConfig *dg_config;
-  QSqlDatabase *dg_db;
 };
 
 
