@@ -2,7 +2,7 @@
 //
 // A Batch Importer for Rivendell.
 //
-//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -41,6 +41,7 @@
 #include <rdconf.h>
 #include <rdcut.h>
 #include <rddatedecode.h>
+#include <rddisclookup.h>
 #include <rdescape_string.h>
 #include <rdlibrary_conf.h>
 #include <rdtempdirectory.h>
@@ -381,6 +382,28 @@ MainObject::MainObject(QObject *parent)
       import_string_outcue=rda->cmdSwitch()->value(i);
       rda->cmdSwitch()->setProcessed(i,true);
     }
+    if(rda->cmdSwitch()->key(i)=="--set-string-isci") {
+      import_string_isci=rda->cmdSwitch()->value(i);
+      rda->cmdSwitch()->setProcessed(i,true);
+    }
+    if(rda->cmdSwitch()->key(i)=="--set-string-isrc") {
+      if(RDDiscLookup::isrcIsValid(rda->cmdSwitch()->value(i))) {
+	import_string_isrc=rda->cmdSwitch()->value(i);
+	rda->cmdSwitch()->setProcessed(i,true);
+      }
+      else {
+	Log(LOG_ERR,"invalid ISRC \""+rda->cmdSwitch()->value(i)+"\"\n");
+	exit(1);
+      }
+    }
+    if(rda->cmdSwitch()->key(i)=="--set-string-recording-mbid") {
+      import_string_recording_mbid=rda->cmdSwitch()->value(i);
+      rda->cmdSwitch()->setProcessed(i,true);
+    }
+    if(rda->cmdSwitch()->key(i)=="--set-string-release-mbid") {
+      import_string_release_mbid=rda->cmdSwitch()->value(i);
+      rda->cmdSwitch()->setProcessed(i,true);
+    }
     if(rda->cmdSwitch()->key(i)=="--set-string-publisher") {
       import_string_publisher=rda->cmdSwitch()->value(i);
       rda->cmdSwitch()->setProcessed(i,true);
@@ -723,6 +746,18 @@ MainObject::MainObject(QObject *parent)
   if(!import_string_outcue.isNull()) {
     Log(LOG_INFO,QString().sprintf(" Outcue set to: %s\n",(const char *)import_string_outcue));
   }
+  if(!import_string_isci.isNull()) {
+    Log(LOG_INFO,QString().sprintf(" ISCI set to: %s\n",(const char *)import_string_isci));
+  }
+  if(!import_string_isrc.isNull()) {
+    Log(LOG_INFO,QString().sprintf(" ISRC set to: %s\n",(const char *)import_string_isrc));
+  }
+  if(!import_string_recording_mbid.isNull()) {
+    Log(LOG_INFO,QString().sprintf(" MusicBrainz recording ID set to: %s\n",(const char *)import_string_recording_mbid));
+  }
+  if(!import_string_release_mbid.isNull()) {
+    Log(LOG_INFO,QString().sprintf(" MusicBrainz release ID set to: %s\n",(const char *)import_string_release_mbid));
+  }
   if(!import_string_publisher.isNull()) {
     Log(LOG_INFO,QString().sprintf(" Publisher set to: %s\n",(const char *)import_string_publisher));
   }
@@ -1214,6 +1249,18 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
   if(!import_string_outcue.isNull()) {
     cut->setOutcue(import_string_outcue);
   }
+  if(!import_string_isci.isNull()) {
+    cut->setIsci(import_string_isci);
+  }
+  if(!import_string_isrc.isNull()) {
+    cut->setIsrc(RDDiscLookup::normalizedIsrc(import_string_isrc));
+  }
+  if(!import_string_recording_mbid.isNull()) {
+    cut->setRecordingMbId(import_string_recording_mbid);
+  }
+  if(!import_string_release_mbid.isNull()) {
+    cut->setReleaseMbId(import_string_release_mbid);
+  }
   if(!import_string_publisher.isNull()) {
     cart->setPublisher(import_string_publisher);
   }
@@ -1579,6 +1626,7 @@ bool MainObject::RunPattern(const QString &pattern,const QString &filename,
   bool macro_active=false;
   int ptr=0;
   QChar field;
+  QChar subfield;
   QString value;
   QChar delimiter;
   bool found_cartnum=false;
@@ -1601,12 +1649,31 @@ bool MainObject::RunPattern(const QString &pattern,const QString &filename,
   if((pattern.at(0)=='%')&&(pattern.at(1)!='%')) {
     field=pattern.at(1);
     value="";
-    if(pattern.length()>=3) {
-      delimiter=pattern.at(2);
-      ptr=3;
+    if(field==QChar('w')) {
+      if(pattern.length()>=4) {
+	subfield=pattern.at(2);
+	delimiter=pattern.at(3);
+	ptr=4;
+      }
+      else {
+	if(pattern.length()>=3) {
+	  subfield=pattern.at(2);
+	  delimiter=QChar();
+	  ptr=3;
+	}
+	else {
+	  ptr=2;
+	}
+      }
     }
     else {
-      ptr=2;
+      if(pattern.length()>=3) {
+	delimiter=pattern.at(2);
+	ptr=3;
+      }
+      else {
+	ptr=2;
+      }
     }
     macro_active=true;
   }
@@ -1617,14 +1684,14 @@ bool MainObject::RunPattern(const QString &pattern,const QString &filename,
 
   for(int i=0;i<=filename.length();i++) {
     if(macro_active) {
-      if(((!delimiter.isNull())&&(filename.at(i)==delimiter))||
-	 (i==filename.length())) {
+      if((i==filename.length())||
+	 ((!delimiter.isNull())&&(filename.at(i)==delimiter))) {
 	switch(field.toAscii()) {
 	case 'a':
 	  wavedata->setArtist(value);
 	  wavedata->setMetadataFound(true);
 	  break;
-  
+
 	case 'b':
 	  wavedata->setLabel(value);
 	  wavedata->setMetadataFound(true);
@@ -1742,6 +1809,36 @@ bool MainObject::RunPattern(const QString &pattern,const QString &filename,
 	  wavedata->setMetadataFound(true);
 	  break;
 
+	case 'w':
+	  switch(subfield.toAscii()) {
+	  case 'c':
+	    wavedata->setIsci(value);
+	    wavedata->setMetadataFound(true);
+	    break;
+
+	  case 'i':
+	    if(RDDiscLookup::isrcIsValid(value)) {
+	      wavedata->setIsrc(RDDiscLookup::normalizedIsrc(value));
+	      wavedata->setMetadataFound(true);
+	    }
+	    else {
+	      Log(LOG_ERR,"invalid ISRC \""+value+"\"\n");
+	      exit(1);
+	    }
+	    break;
+
+	  case 'm':
+	    wavedata->setRecordingMbId(value);
+	    wavedata->setMetadataFound(true);
+	    break;
+
+	  case 'r':
+	    wavedata->setReleaseMbId(value);
+	    wavedata->setMetadataFound(true);
+	    break;
+	  }
+	  break;
+
 	case 'y':
 	  wavedata->setReleaseYear(value.toInt());
 	  wavedata->setMetadataFound(true);
@@ -1753,12 +1850,35 @@ bool MainObject::RunPattern(const QString &pattern,const QString &filename,
 	}
 	if((pattern.at(ptr)=='%')&&(pattern.at(ptr+1)!='%')) {
 	  field=pattern.at(ptr+1);
-	  delimiter=pattern.at(ptr+2);
-	  ptr+=3;
-	  macro_active=true;
+	  if(field==QChar('w')) {
+	    if(pattern.length()>(ptr+3)) {
+	      delimiter=pattern.at(ptr+3);
+	    }
+	    else {
+	      delimiter=QChar();
+	    }
+	    subfield=pattern.at(ptr+2);
+	    ptr+=4;
+	    macro_active=true;
+	  }
+	  else {
+	    if(pattern.length()>(ptr+2)) {
+	      delimiter=pattern.at(ptr+2);
+	    }
+	    else {
+	      delimiter=QChar();
+	    }
+	    ptr+=3;
+	    macro_active=true;
+	  }
 	}
 	else {
-	  delimiter=pattern.at(ptr);
+	  if(pattern.length()>ptr) {
+	    delimiter=pattern.at(ptr);
+	  }
+	  else {
+	    delimiter=QChar();
+	  }
 	  ptr++;
 	  macro_active=false;
 	}
@@ -1776,9 +1896,17 @@ bool MainObject::RunPattern(const QString &pattern,const QString &filename,
       }
       if((pattern.at(ptr)=='%')&&(pattern.at(ptr+1)!='%')) {
 	field=pattern.at(ptr+1);
-	delimiter=pattern.at(ptr+2);
-	ptr+=3;
-	macro_active=true;
+	if(field==QChar('w')) {
+	  delimiter=pattern.at(ptr+3);
+	  subfield=pattern.at(ptr+2);
+	  ptr+=4;
+	  macro_active=true;
+	}
+	else {
+	  delimiter=pattern.at(ptr+2);
+	  ptr+=3;
+	  macro_active=true;
+	}
       }
       else {
 	delimiter=pattern.at(ptr);
@@ -1801,6 +1929,9 @@ bool MainObject::VerifyPattern(const QString &pattern)
 	return false;
       }
       macro_active=true;
+      if(i>=(pattern.length()-1)) {
+	return false;
+      }
       switch(pattern.at(++i).toAscii()) {
       case 'a':
       case 'b':
@@ -1825,6 +1956,18 @@ bool MainObject::VerifyPattern(const QString &pattern)
       case '%':
 	break;
 
+      case 'w':
+	if(i>=(pattern.length()-1)) {
+	  return false;
+	}
+	switch(pattern.at(++i).toAscii()) {
+	case 'i':
+	case 'm':
+	case 'r':
+	  break;
+	}
+	break;
+
       default:
 	return false;
       }
