@@ -2,7 +2,7 @@
 //
 // An RSS Feed Generator for Rivendell.
 //
-//   (C) Copyright 2002-2009,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2009,2016-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,25 +28,25 @@
 #include <qdatetime.h>
 
 #include <rd.h>
+#include <rdapplication.h>
+#include <rdcastsearch.h>
 #include <rdconf.h>
 #include <rdconfig.h>
-#include <rdpodcast.h>
 #include <rddb.h>
-#include <rdweb.h>
 #include <rdescape_string.h>
 #include <rdfeed.h>
-#include <rdcastsearch.h>
-#include <rdsystem.h>
-#include <rdstation.h>
-#include <dbversion.h>
+#include <rdpodcast.h>
+#include <rdweb.h>
 
-#include <rdcastmanager.h>
+#include "rdcastmanager.h"
 
 char server_name[PATH_MAX];
 
 MainObject::MainObject(QObject *parent)
   :QObject(parent)
 {
+  QString err_msg;
+
   //
   // Initialize Variables
   //
@@ -59,47 +59,30 @@ MainObject::MainObject(QObject *parent)
   cast_post=NULL;
 
   //
-  // Read Configuration
+  // Open the Database
   //
-  cast_config=new RDConfig();
-  cast_config->load();
-  cast_config->setModuleName("rdcastmanager.cgi");
+  rda=new RDApplication("rdcastmanager.cgi","rdcastmanager.cgi",RDCASTMANAGER_CGI_USAGE,this);
+  if(!rda->open(&err_msg)) {
+    printf("Content-type: text/html\n");
+    printf("Status: 500\n");
+    printf("\n");
+    printf("rdcastmanager.cgi: %s\n",(const char *)err_msg.utf8());
+    Exit(0);
+  }
 
   //
-  // Open Database
+  // Read Command Options
   //
-  QSqlDatabase *db=QSqlDatabase::addDatabase(cast_config->mysqlDriver());
-  if(!db) {
-    printf("Content-type: text/html\n\n");
-    printf("rdcastmanager: unable to initialize connection to database\n");
-    Exit(0);
+  for(unsigned i=0;i<rda->cmdSwitch()->keys();i++) {
+    if(!rda->cmdSwitch()->processed(i)) {
+      printf("Content-type: text/html\n");
+      printf("Status: 500\n");
+      printf("\n");
+      printf("rdcastmanager.cgi: unknown command option \"%s\"\n",
+	     (const char *)rda->cmdSwitch()->key(i).utf8());
+      Exit(0);
+    }
   }
-  db->setDatabaseName(cast_config->mysqlDbname());
-  db->setUserName(cast_config->mysqlUsername());
-  db->setPassword(cast_config->mysqlPassword());
-  db->setHostName(cast_config->mysqlHostname());
-  if(!db->open()) {
-    printf("Content-type: text/html\n\n");
-    printf("rdcastmanager: unable to connect to database\n");
-    db->removeDatabase(cast_config->mysqlDbname());
-    Exit(0);
-  }
-  RDSqlQuery *q=new RDSqlQuery("select DB from VERSION");
-  if(!q->first()) {
-    printf("Content-type: text/html\n");
-    printf("Status: 500\n\n");
-    printf("rdcastmanager: missing/invalid database version!\n");
-    db->removeDatabase(cast_config->mysqlDbname());
-    Exit(0);
-  }
-  if(q->value(0).toUInt()!=RD_VERSION_DATABASE) {
-    printf("Content-type: text/html\n");
-    printf("Status: 500\n\n");
-    printf("rdcastmanager: skewed database version!\n");
-    db->removeDatabase(cast_config->mysqlDbname());
-    Exit(0);
-  }
-  delete q;
 
   //
   // Determine Connection Type
@@ -107,7 +90,6 @@ MainObject::MainObject(QObject *parent)
   if(getenv("REQUEST_METHOD")==NULL) {
     printf("Content-type: text/html\n\n");
     printf("rdcastmanager: missing REQUEST_METHOD\n");
-    db->removeDatabase(cast_config->mysqlDbname());
     Exit(0);
   }
   if(QString(getenv("REQUEST_METHOD")).lower()!="post") {
@@ -137,65 +119,65 @@ MainObject::MainObject(QObject *parent)
     Exit(0);
   }
   switch(AuthenticatePost()) {
-    case RDCASTMANAGER_COMMAND_LOGIN:
-      ServeLogin();
-      break;
+  case RDCASTMANAGER_COMMAND_LOGIN:
+    ServeLogin();
+    break;
 
-    case RDCASTMANAGER_COMMAND_LOGOUT:
-      ServeLogout();
-      break;
+  case RDCASTMANAGER_COMMAND_LOGOUT:
+    ServeLogout();
+    break;
 
-    case RDCASTMANAGER_COMMAND_LIST_FEEDS:
-      ServeListFeeds();
-      break;
+  case RDCASTMANAGER_COMMAND_LIST_FEEDS:
+    ServeListFeeds();
+    break;
 
-    case RDCASTMANAGER_COMMAND_LIST_CASTS:
-      ServeListCasts();
-      break;
+  case RDCASTMANAGER_COMMAND_LIST_CASTS:
+    ServeListCasts();
+    break;
 
-    case RDCASTMANAGER_COMMAND_EDIT_CAST:
-      ServeEditCast();
-      break;
+  case RDCASTMANAGER_COMMAND_EDIT_CAST:
+    ServeEditCast();
+    break;
 
-    case RDCASTMANAGER_COMMAND_COMMIT_CAST:
-      CommitCast();
-      break;
+  case RDCASTMANAGER_COMMAND_COMMIT_CAST:
+    CommitCast();
+    break;
 
-    case RDCASTMANAGER_COMMAND_CONFIRM_DELETE_CAST:
-      ConfirmDeleteCast();
-      break;
+  case RDCASTMANAGER_COMMAND_CONFIRM_DELETE_CAST:
+    ConfirmDeleteCast();
+    break;
 
-    case RDCASTMANAGER_COMMAND_DELETE_CAST:
-      DeleteCast();
-      break;
+  case RDCASTMANAGER_COMMAND_DELETE_CAST:
+    DeleteCast();
+    break;
 
-    case RDCASTMANAGER_COMMAND_SUBSCRIPTION_PICK_DATES:
-      ServeDatePicker(RDCASTMANAGER_COMMAND_SUBSCRIPTION_REPORT);
-      break;
+  case RDCASTMANAGER_COMMAND_SUBSCRIPTION_PICK_DATES:
+    ServeDatePicker(RDCASTMANAGER_COMMAND_SUBSCRIPTION_REPORT);
+    break;
 
-    case RDCASTMANAGER_COMMAND_SUBSCRIPTION_REPORT:
-      ServeSubscriptionReport();
-      break;
+  case RDCASTMANAGER_COMMAND_SUBSCRIPTION_REPORT:
+    ServeSubscriptionReport();
+    break;
 
-    case RDCASTMANAGER_COMMAND_EPISODE_PICK_DATES:
-      ServeDatePicker(RDCASTMANAGER_COMMAND_EPISODE_REPORT);
-      break;
+  case RDCASTMANAGER_COMMAND_EPISODE_PICK_DATES:
+    ServeDatePicker(RDCASTMANAGER_COMMAND_EPISODE_REPORT);
+    break;
 
-    case RDCASTMANAGER_COMMAND_EPISODE_REPORT:
-      ServeEpisodeReport();
-      break;
+  case RDCASTMANAGER_COMMAND_EPISODE_REPORT:
+    ServeEpisodeReport();
+    break;
 
-    case RDCASTMANAGER_COMMAND_PLAY_CAST:
-      ServePlay();
-      break;
+  case RDCASTMANAGER_COMMAND_PLAY_CAST:
+    ServePlay();
+    break;
 
-    case RDCASTMANAGER_COMMAND_POST_EPISODE:
-      PostEpisode();
-      break;
+  case RDCASTMANAGER_COMMAND_POST_EPISODE:
+    PostEpisode();
+    break;
 
-    default:
-      RDCgiError("Invalid post data!");
-      break;
+  default:
+    RDCgiError("Invalid post data!");
+    break;
   }
 
   Exit(0);
@@ -359,17 +341,19 @@ void MainObject::ServeListFeeds()
   line_colors[1]=RD_WEB_LINE_COLOR2;
   int current_color=0;
 
-  sql=QString().sprintf("select FEED_PERMS.KEY_NAME from \
-                         FEED_PERMS left join WEB_CONNECTIONS \
-                         on(FEED_PERMS.USER_NAME=WEB_CONNECTIONS.LOGIN_NAME) \
-                         where WEB_CONNECTIONS.SESSION_ID=%ld",
-			cast_session_id);
+  sql=QString("select ")+
+    "FEED_PERMS.KEY_NAME "+  // 00
+    "from FEED_PERMS left join WEB_CONNECTIONS "+
+    "on(FEED_PERMS.USER_NAME=WEB_CONNECTIONS.LOGIN_NAME) where "+
+    QString().sprintf("WEB_CONNECTIONS.SESSION_ID=%ld",cast_session_id);
   q=new RDSqlQuery(sql);
-  sql=QString().sprintf("select ID,KEY_NAME,CHANNEL_TITLE from FEEDS \
-                         where ");
+  sql=QString("select ")+
+    "ID,"+             // 00
+    "KEY_NAME,"+       // 01
+    "CHANNEL_TITLE "+  // 02
+    "from FEEDS where ";
   while(q->next()) {
-    sql+=QString().sprintf("(KEY_NAME=\"%s\")||",
-			   (const char *)q->value(0).toString());
+    sql+=QString("(KEY_NAME=\"")+RDEscapeString(q->value(0).toString())+"\")||";
   }
   delete q;
   if(sql.right(2)=="||") {
@@ -380,8 +364,8 @@ void MainObject::ServeListFeeds()
       total=0;
       active=0;
       printf("<tr>\n");
-      sql=QString().sprintf("select STATUS from PODCASTS where FEED_ID=%u",
-			    q->value(0).toUInt());
+      sql=QString("select STATUS from PODCASTS where ")+
+	QString().sprintf("FEED_ID=%u",q->value(0).toUInt());
       q1=new RDSqlQuery(sql);
       while(q1->next()) {
 	total++;
@@ -405,10 +389,10 @@ void MainObject::ServeListFeeds()
       }
       printf("<td align=\"center\" bgcolor=\"%s\">%s</td>\n"
 	     ,(const char *)line_colors[current_color],
-	     (const char *)q->value(1).toString());
+	     (const char *)q->value(1).toString().utf8());
       printf("<td bgcolor=\"%s\">%s</td>\n",
 	     (const char *)line_colors[current_color],
-	     (const char *)q->value(2).toString());
+	     (const char *)q->value(2).toString().utf8());
       printf("<td align=\"center\" bgcolor=\"%s\">%d / %d</td>\n",
 	     (const char *)line_colors[current_color],active,total);
       printf("<form action=\"rdcastmanager.cgi\" method=\"post\" enctype=\"multipart/form-data\">\n");
@@ -417,7 +401,7 @@ void MainObject::ServeListFeeds()
       printf("<input type=\"hidden\" name=\"FEED_ID\" value=\"%d\">\n",
 	     q->value(0).toInt());
       printf("<input type=\"hidden\" name=\"KEY_NAME\" value=\"%s\">\n",
-	     (const char *)q->value(1).toString());
+	     (const char *)q->value(1).toString().utf8());
       printf("<input type=\"submit\" value=\"View Feed\">\n");
       printf("</td>\n");
       printf("</form>\n");
@@ -460,7 +444,7 @@ void MainObject::ServeListCasts()
 {
   QString sql;
   RDSqlQuery *q;
-  QString filter;
+  QString filter="";
   bool unexp_only;
   bool active_only;
 
@@ -477,7 +461,6 @@ void MainObject::ServeListCasts()
 
   GetUserPerms();
 
-  filter[0]=0;
   cast_post->getValue("FILTER",&filter);
   unexp_only=(cast_post->value("ONLY_NOT_EXPIRED").toString().lower()=="yes");
   active_only=(cast_post->value("ONLY_ACTIVE").toString().lower()=="yes");
@@ -503,7 +486,7 @@ void MainObject::ServeListCasts()
   // Title Section
   //
   printf("<form action=\"rdcastmanager.cgi\" method=\"post\" enctype=\"multipart/form-data\">\n");
-  printf("<tr><td align=\"center\" colspan=\"9\"><big><big>%s Podcasts</big></big></td></tr>\n",(const char *)cast_key_name);
+  printf("<tr><td align=\"center\" colspan=\"9\"><big><big>%s Podcasts</big></big></td></tr>\n",(const char *)cast_key_name.utf8());
   SetContext(RDCASTMANAGER_COMMAND_LIST_CASTS);
 
   //
@@ -512,7 +495,7 @@ void MainObject::ServeListCasts()
   printf("<tr>\n");
   printf("<td bgcolor=\"%s\">&nbsp;</td>\n",RD_WEB_LINE_COLOR2);
   printf("<td colspan=\"7\" align=\"left\" bgcolor=\"%s\"><strong>Filter:</strong>\n",RD_WEB_LINE_COLOR2);
-  printf("<input type=\"text\" name=\"FILTER\" value=\"%s\" size=\"70\" maxlength=\"255\">\n",(const char *)filter);
+  printf("<input type=\"text\" name=\"FILTER\" value=\"%s\" size=\"70\" maxlength=\"255\">\n",(const char *)filter.utf8());
   printf("</td>\n");
   printf("<td bgcolor=\"%s\"><input type=\"submit\" value=\"Refresh\"></td>\n",RD_WEB_LINE_COLOR2);
   printf("</tr>\n");
@@ -568,11 +551,17 @@ void MainObject::ServeListCasts()
   line_colors[0]=RD_WEB_LINE_COLOR1;
   line_colors[1]=RD_WEB_LINE_COLOR2;
   int current_color=0;
-  sql="select ID,STATUS,ITEM_TITLE,ORIGIN_DATETIME,SHELF_LIFE,ITEM_CATEGORY,\
-       AUDIO_TIME from PODCASTS "+
+  sql=QString("select ")+
+    "ID,"+               // 00
+    "STATUS,"+           // 01
+    "ITEM_TITLE,"+       // 02
+    "ORIGIN_DATETIME,"+  // 03
+    "SHELF_LIFE,"+       // 04
+    "ITEM_CATEGORY,"+    // 05
+    "AUDIO_TIME "+       // 06
+    "from PODCASTS "+
     RDCastSearch(cast_feed_id,filter,unexp_only,active_only)+
     " order by ORIGIN_DATETIME desc";
-
   q=new RDSqlQuery(sql);
   while(q->next()) {
     printf("<tr>\n");
@@ -591,7 +580,7 @@ void MainObject::ServeListCasts()
     }
     printf("<td bgcolor=\"%s\">%s</td>\n",
 	   (const char *)line_colors[current_color],
-	   (const char *)q->value(2).toString());
+	   (const char *)q->value(2).toString().utf8());
     printf("<td align=\"center\" bgcolor=\"%s\">%s</td>\n",
 	   (const char *)line_colors[current_color],
 	   (const char *)RDUtcToLocal(q->value(3).toDateTime()).
@@ -804,13 +793,13 @@ void MainObject::ServeEditCast(int cast_id)
   QDateTime origin_datetime=RDUtcToLocal(q->value(10).toDateTime());
   QDateTime effective_datetime=RDUtcToLocal(q->value(12).toDateTime());
 
-  RDFeed *feed=new RDFeed(cast_feed_id,cast_config);
+  RDFeed *feed=new RDFeed(cast_feed_id,rda->config());
 
   printf("Content-type: text/html\n\n");
   printf("<html>\n");
   printf("<head>\n");
   printf("<title>Rivendell RDCastManager -- Editing \"%s\"</title>\n",
-	 (const char *)q->value(0).toString());
+	 (const char *)q->value(0).toString().utf8());
   printf("</head>\n");
 
   printf("<body bgcolor=\"%s\">\n",RD_WEB_BACKGROUND_COLOR);
@@ -831,7 +820,7 @@ void MainObject::ServeEditCast(int cast_id)
     printf("<td bgcolor=\"%s\" align=\"left\" colspan=\"2\">\n",
 	   RD_WEB_LINE_COLOR1);
     printf("%s\n",(const char *)feed->audioUrl(feed->mediaLinkMode(),
-					       server_name,cast_cast_id));
+					       server_name,cast_cast_id).utf8());
     printf("</td>\n");
     printf("</tr>\n");
     
@@ -854,7 +843,7 @@ void MainObject::ServeEditCast(int cast_id)
 	 RD_WEB_LINE_COLOR1);
   printf("<td bgcolor=\"%s\" align=\"left\" colspan=\"2\">\n",
 	 RD_WEB_LINE_COLOR1);
-  printf("<input type=\"text\" name=\"ITEM_TITLE\" value=\"%s\" size=\"50\" maxlength=\"255\">\n",(const char *)q->value(0).toString());
+  printf("<input type=\"text\" name=\"ITEM_TITLE\" value=\"%s\" size=\"50\" maxlength=\"255\">\n",(const char *)q->value(0).toString().utf8());
   printf("</td>\n");
   printf("</tr>\n");
 
@@ -866,7 +855,7 @@ void MainObject::ServeEditCast(int cast_id)
 	 RD_WEB_LINE_COLOR1);
   printf("<td bgcolor=\"%s\" align=\"left\" colspan=\"2\">\n",
 	 RD_WEB_LINE_COLOR1);
-  printf("<input type=\"text\" name=\"ITEM_AUTHOR\" value=\"%s\" size=\"50\" maxlength=\"255\">\n",(const char *)q->value(1).toString());
+  printf("<input type=\"text\" name=\"ITEM_AUTHOR\" value=\"%s\" size=\"50\" maxlength=\"255\">\n",(const char *)q->value(1).toString().utf8());
   printf("</td>\n");
   printf("</tr>\n");
 
@@ -878,7 +867,7 @@ void MainObject::ServeEditCast(int cast_id)
 	 RD_WEB_LINE_COLOR1);
   printf("<td bgcolor=\"%s\" align=\"left\" colspan=\"2\">\n",
 	 RD_WEB_LINE_COLOR1);
-  printf("<input type=\"text\" name=\"ITEM_CATEGORY\" value=\"%s\" size=\"50\" maxlength=\"255\">\n",(const char *)q->value(2).toString());
+  printf("<input type=\"text\" name=\"ITEM_CATEGORY\" value=\"%s\" size=\"50\" maxlength=\"255\">\n",(const char *)q->value(2).toString().utf8());
   printf("</td>\n");
   printf("</tr>\n");
 
@@ -890,7 +879,7 @@ void MainObject::ServeEditCast(int cast_id)
 	 RD_WEB_LINE_COLOR1);
   printf("<td bgcolor=\"%s\" align=\"left\" colspan=\"2\">\n",
 	 RD_WEB_LINE_COLOR1);
-  printf("<input type=\"text\" name=\"ITEM_LINK\" value=\"%s\" size=\"50\" maxlength=\"255\">\n",(const char *)q->value(3).toString());
+  printf("<input type=\"text\" name=\"ITEM_LINK\" value=\"%s\" size=\"50\" maxlength=\"255\">\n",(const char *)q->value(3).toString().utf8());
   printf("</td>\n");
   printf("</tr>\n");
 
@@ -902,7 +891,7 @@ void MainObject::ServeEditCast(int cast_id)
 	 RD_WEB_LINE_COLOR1);
   printf("<td bgcolor=\"%s\" align=\"left\" colspan=\"2\">\n",
 	 RD_WEB_LINE_COLOR1);
-  printf("<textarea name=\"ITEM_DESCRIPTION\" rows=\"4\" cols=\"50\">%s</textarea>\n",(const char *)q->value(4).toString());
+  printf("<textarea name=\"ITEM_DESCRIPTION\" rows=\"4\" cols=\"50\">%s</textarea>\n",(const char *)q->value(4).toString().utf8());
   printf("</td>\n");
   printf("</tr>\n");
 
@@ -915,7 +904,7 @@ void MainObject::ServeEditCast(int cast_id)
   printf("<td bgcolor=\"%s\" align=\"left\" colspan=\"2\">\n",
 	 RD_WEB_LINE_COLOR1);
   printf("<input type=\"text\" name=\"ITEM_SOURCE_TEXT\" value=\"%s\" size=\"50\" maxlength=\"255\">\n",
-	 (const char *)q->value(6).toString());
+	 (const char *)q->value(6).toString().utf8());
   printf("</td>\n");
   printf("</tr>\n");
 
@@ -928,7 +917,7 @@ void MainObject::ServeEditCast(int cast_id)
   printf("<td bgcolor=\"%s\" align=\"left\" colspan=\"2\">\n",
 	 RD_WEB_LINE_COLOR1);
   printf("<input type=\"text\" name=\"ITEM_SOURCE_URL\" value=\"%s\" size=\"50\" maxlength=\"255\">\n",
-	 (const char *)q->value(7).toString());
+	 (const char *)q->value(7).toString().utf8());
   printf("</td>\n");
   printf("</tr>\n");
 
@@ -940,7 +929,7 @@ void MainObject::ServeEditCast(int cast_id)
 	 RD_WEB_LINE_COLOR1);
   printf("<td bgcolor=\"%s\" align=\"left\" colspan=\"2\">\n",
 	 RD_WEB_LINE_COLOR1);
-  printf("<input type=\"text\" name=\"ITEM_COMMENTS\" value=\"%s\" size=\"50\" maxlength=\"255\">\n",(const char *)q->value(5).toString());
+  printf("<input type=\"text\" name=\"ITEM_COMMENTS\" value=\"%s\" size=\"50\" maxlength=\"255\">\n",(const char *)q->value(5).toString().utf8());
   printf("</td>\n");
   printf("</tr>\n");
 
@@ -1145,15 +1134,17 @@ void MainObject::ServePlay()
     Exit(0);
   }
 
-  sql=QString().sprintf("select FEEDS.BASE_URL,PODCASTS.AUDIO_FILENAME \
-                         from FEEDS left join PODCASTS \
-                         on FEEDS.ID=PODCASTS.FEED_ID \
-                         where PODCASTS.ID=%d",cast_cast_id);
+  sql=QString("select ")+
+    "FEEDS.BASE_URL,"+           // 00
+    "PODCASTS.AUDIO_FILENAME "+  // 01
+    "from FEEDS left join PODCASTS "+
+    "on FEEDS.ID=PODCASTS.FEED_ID where "+
+    QString().sprintf("PODCASTS.ID=%d",cast_cast_id);
   q=new RDSqlQuery(sql);
   if(q->first()) {
     printf("Content-type: audio/x-mpeg\n");
-    printf("Location: %s/%s\n\n",(const char *)q->value(0).toString(),
-	   (const char *)q->value(1).toString());
+    printf("Location: %s/%s\n\n",(const char *)q->value(0).toString().utf8(),
+	   (const char *)q->value(1).toString().utf8());
   }
   else {
     printf("Status: 500 Internal Server Error\n");
@@ -1300,37 +1291,27 @@ void MainObject::CommitCast()
   QDateTime 
     effective_datetime(QDate(effective_year,effective_month,effective_day),
 		      QTime(effective_hour,effective_minute,effective_second));
-  sql=QString().sprintf("update PODCASTS set \
-                         STATUS=%d,\
-                         ITEM_TITLE=\"%s\",\
-                         ITEM_DESCRIPTION=\"%s\",\
-                         ITEM_CATEGORY=\"%s\",\
-                         ITEM_LINK=\"%s\",\
-                         ITEM_COMMENTS=\"%s\",\
-                         ITEM_AUTHOR=\"%s\",\
-                         ITEM_SOURCE_TEXT=\"%s\",\
-                         ITEM_SOURCE_URL=\"%s\",\
-                         SHELF_LIFE=%d,\
-                         EFFECTIVE_DATETIME=%s \
-                         where ID=%d",
-			status,
-			(const char *)RDEscapeString(item_title),
-			(const char *)RDEscapeString(item_description),
-			(const char *)RDEscapeString(item_category),
-			(const char *)RDEscapeString(item_link),
-			(const char *)RDEscapeString(item_comments),
-			(const char *)RDEscapeString(item_author),
-			(const char *)RDEscapeString(item_source_text),
-			(const char *)RDEscapeString(item_source_url),
-			shelf_life,
-			(const char *)RDCheckDateTime(RDLocalToUtc(effective_datetime),
-			    "yyyy-MM-dd hh:mm:ss"),
-			cast_cast_id);
+  sql=QString("update PODCASTS set ")+
+    QString().sprintf("STATUS=%d,",status)+
+    "ITEM_TITLE=\""+RDEscapeString(item_title)+"\","+
+    "ITEM_DESCRIPTION=\""+RDEscapeString(item_description)+"\","+
+    "ITEM_CATEGORY=\""+RDEscapeString(item_category)+"\","+
+    "ITEM_LINK=\""+RDEscapeString(item_link)+"\","+
+    "ITEM_COMMENTS=\""+RDEscapeString(item_comments)+"\","+
+    "ITEM_AUTHOR=\""+RDEscapeString(item_author)+"\","+
+    "ITEM_SOURCE_TEXT=\""+RDEscapeString(item_source_text)+"\","+
+    "ITEM_SOURCE_URL=\""+RDEscapeString(item_source_url)+"\","+
+    QString().sprintf("SHELF_LIFE=%d,",shelf_life)+
+    "EFFECTIVE_DATETIME="+
+    RDCheckDateTime(RDLocalToUtc(effective_datetime),"yyyy-MM-dd hh:mm:ss")+
+    " where "+
+    QString().sprintf("ID=%d",cast_cast_id);
   q=new RDSqlQuery(sql);
   delete q;
 
-  sql=QString().sprintf("update FEEDS set LAST_BUILD_DATETIME=UTC_TIMESTAMP()\
-                         where ID=%d",cast_feed_id);
+  sql=QString("update FEEDS set ")+
+    "LAST_BUILD_DATETIME=UTC_TIMESTAMP() where "+
+    QString().sprintf("ID=%d",cast_feed_id);
   q=new RDSqlQuery(sql);
   delete q;
 
@@ -1381,7 +1362,7 @@ void MainObject::ConfirmDeleteCast()
   printf("<tr>\n");
   printf("<td bgcolor=\"%s\" >Are you sure you want to delete cast \"%s\", posted on %s at %s?</td>\n",
 	 RD_WEB_LINE_COLOR2,
-	 (const char *)q->value(0).toString(),
+	 (const char *)q->value(0).toString().utf8(),
 	 (const char *)q->value(1).toDateTime().toString("MM/dd/yyyy"),
 	 (const char *)q->value(1).toDateTime().toString("hh:mm:ss"));
   printf("</tr>\n");
@@ -1451,9 +1432,9 @@ void MainObject::DeleteCast()
     Exit(0);
   }
 
-  RDFeed *feed=new RDFeed(cast_feed_id,cast_config);
-  RDPodcast *cast=new RDPodcast(cast_config,cast_cast_id);
-  cast->removeAudio(feed,&errs,cast_config->logXloadDebugData());
+  RDFeed *feed=new RDFeed(cast_feed_id,rda->config());
+  RDPodcast *cast=new RDPodcast(rda->config(),cast_cast_id);
+  cast->removeAudio(feed,&errs,rda->config()->logXloadDebugData());
   delete cast;
   delete feed;
 
@@ -1483,7 +1464,7 @@ void MainObject::ServeSubscriptionReport()
     Exit(0);
   }
   cast_cast_id=-1;
-  RDFeed *feed=new RDFeed(cast_key_name,cast_config,this);
+  RDFeed *feed=new RDFeed(cast_key_name,rda->config(),this);
 
   printf("Content-type: text/html\n\n");
   printf("<html>\n");
@@ -1500,7 +1481,7 @@ void MainObject::ServeSubscriptionReport()
   printf("<tr>\n");
   printf("<td align=\"center\" colspan=\"2\">\n");
   printf("<big><big><strong>Subscription Report for \"%s\"</strong></big></big>\n",
-	 (const char *)feed->channelTitle());
+	 (const char *)feed->channelTitle().utf8());
   printf("</td></tr>\n");
 
   //
@@ -1520,15 +1501,16 @@ void MainObject::ServeSubscriptionReport()
   line_colors[0]=RD_WEB_LINE_COLOR1;
   line_colors[1]=RD_WEB_LINE_COLOR2;
   int current_color=0;
-  QString keyname_esc=cast_key_name;
-  keyname_esc.replace(" ","_");
-  sql=QString().sprintf("select ACCESS_DATE,ACCESS_COUNT,CAST_ID from %s_FLG \
-                         where (ACCESS_DATE>=\"%s\")&&\
-                         (ACCESS_DATE<=\"%s\") \
-                         order by ACCESS_DATE,CAST_ID desc",
-			(const char *)keyname_esc,
-			(const char *)cast_start_date.toString("yyyy-MM-dd"),
-			(const char *)cast_end_date.toString("yyyy-MM-dd"));
+  sql=QString("select ")+
+    "ACCESS_DATE,"+   // 00
+    "ACCESS_COUNT,"+  // 01
+    "CAST_ID "+       // 02
+    "from CAST_DOWNLOADS where "+
+    "(ACCESS_DATE>=\""+
+    RDEscapeString(cast_start_date.toString("yyyy-MM-dd"))+"\")&&"+
+    "(ACCESS_DATE<=\""+
+    RDEscapeString(cast_end_date.toString("yyyy-MM-dd"))+"\" "+
+    "order by ACCESS_DATE,CAST_ID desc";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     if(q->value(2).toUInt()==0) {
@@ -1611,15 +1593,15 @@ void MainObject::PostEpisode()
     RDCgiError("No MEDIA_FILE submitted!");
     Exit(0);
   }
-  RDStation *station=new RDStation(cast_config->stationName(),0);
+  RDStation *station=new RDStation(rda->config()->stationName(),0);
   if(!station->exists()) {
     RDCgiError("Server station entry not found!");
     Exit(0);
   }
   RDFeed::Error err;
-  RDFeed *feed=new RDFeed(cast_feed_id,cast_config,this);
+  RDFeed *feed=new RDFeed(cast_feed_id,rda->config(),this);
   int cast_id=feed->postFile(station,media_file,&err,
-			     cast_config->logXloadDebugData(),cast_config);
+			     rda->config()->logXloadDebugData(),rda->config());
   delete feed;
   delete station;
   if(err!=RDFeed::ErrorOk) {
@@ -1651,7 +1633,7 @@ void MainObject::ServeEpisodeReport()
     RDCgiError("Missing CAST_ID");
     Exit(0);
   }
-  RDPodcast *cast=new RDPodcast(cast_config,cast_cast_id);
+  RDPodcast *cast=new RDPodcast(rda->config(),cast_cast_id);
 
   printf("Content-type: text/html\n\n");
   printf("<html>\n");
@@ -1687,16 +1669,17 @@ void MainObject::ServeEpisodeReport()
   line_colors[0]=RD_WEB_LINE_COLOR1;
   line_colors[1]=RD_WEB_LINE_COLOR2;
   int current_color=0;
-  QString keyname_esc=cast_key_name;
-  keyname_esc.replace(" ","_");
-  sql=QString().sprintf("select ACCESS_DATE,ACCESS_COUNT from %s_FLG \
-                         where (ACCESS_DATE>=\"%s\")&&\
-                         (ACCESS_DATE<=\"%s\")&& \
-                         (CAST_ID=%d) order by ACCESS_DATE",
-			(const char *)keyname_esc,
-			(const char *)cast_start_date.toString("yyyy-MM-dd"),
-			(const char *)cast_end_date.toString("yyyy-MM-dd"),
-			cast_cast_id);
+  sql=QString("select ")+
+    "ACCESS_DATE,"+   // 00
+    "ACCESS_COUNT "+  // 01
+    "from CAST_DOWNLOADS where "+
+    "FEED_KEY_NAME=\""+RDEscapeString(cast_key_name)+"\" && "+
+    "(ACCESS_DATE>=\""+
+    RDEscapeString(cast_start_date.toString("yyyy-MM-dd"))+"\")&&"+
+    "(ACCESS_DATE<=\""+
+    RDEscapeString(cast_end_date.toString("yyyy-MM-dd"))+"\")&&"+
+    QString().sprintf("(CAST_ID=%d) ",cast_cast_id)+
+    "order by ACCESS_DATE";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     printf("<tr><td align=\"center\" bgcolor=\"%s\">%s</td>\n",
@@ -1813,7 +1796,7 @@ void MainObject::TitleSection(const QString &title,int cmd,int colspan) const
   printf("<tr>\n");
   printf("<td>&nbsp;</td>\n");
   printf("<td align=\"center\" colspan=\"%d\"><big><big>%s</big></big></td>\n",
-	 colspan,(const char *)title);
+	 colspan,(const char *)title.utf8());
   printf("<td><table cellpadding=\"3\" cellspacing=\"3\" border=\"0\">\n");
   //
   // Refresh Button
@@ -1897,7 +1880,7 @@ void MainObject::SetContext(int cmd) const
 	 cast_session_id);
   if(!cast_key_name.isEmpty()) {
     printf("<input type=\"hidden\" name=\"KEY_NAME\" value=\"%s\">\n",
-	   (const char *)cast_key_name);
+	   (const char *)cast_key_name.utf8());
   }
   if(cast_feed_id>=0) {
     printf("<input type=\"hidden\" name=\"FEED_ID\" value=\"%d\">\n",
